@@ -23,6 +23,9 @@
 #include <ccode/valaccodecastexpression.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeCastExpressionPrivate {
 	ValaCCodeExpression* _inner;
 	char* _type_name;
@@ -38,6 +41,7 @@ static gpointer vala_ccode_cast_expression_parent_class = NULL;
 static void vala_ccode_cast_expression_dispose (GObject * obj);
 
 
+
 ValaCCodeCastExpression* vala_ccode_cast_expression_new (ValaCCodeExpression* expr, const char* type) {
 	GParameter * __params;
 	GParameter * __params_it;
@@ -45,8 +49,14 @@ ValaCCodeCastExpression* vala_ccode_cast_expression_new (ValaCCodeExpression* ex
 	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
-	(__params_it->name = "type-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, type), __params_it++);
+	__params_it->name = "inner";
+	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
+	g_value_set_object (&__params_it->value, expr);
+	__params_it++;
+	__params_it->name = "type-name";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, type);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_CAST_EXPRESSION, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -62,9 +72,9 @@ static void vala_ccode_cast_expression_real_write (ValaCCodeNode* base, ValaCCod
 	self = VALA_CCODE_CAST_EXPRESSION (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "((");
-	vala_ccode_writer_write_string (writer, vala_ccode_cast_expression_get_type_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_type_name);
 	vala_ccode_writer_write_string (writer, ") ");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_cast_expression_get_inner (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_inner), writer);
 	vala_ccode_writer_write_string (writer, ")");
 }
 
@@ -156,7 +166,7 @@ static void vala_ccode_cast_expression_dispose (GObject * obj) {
 	ValaCCodeCastExpression * self;
 	self = VALA_CCODE_CAST_EXPRESSION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	(self->priv->_type_name = (g_free (self->priv->_type_name), NULL));
+	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
 	G_OBJECT_CLASS (vala_ccode_cast_expression_parent_class)->dispose (obj);
 }
 
