@@ -1,6 +1,6 @@
 /* valaccodecommaexpression.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,11 +23,14 @@
 #include <ccode/valaccodecommaexpression.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
-#include <gee/collection.h>
+#include <gee/readonlycollection.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeCommaExpressionPrivate {
 	GeeList* inner;
 };
@@ -40,6 +43,7 @@ static gpointer vala_ccode_comma_expression_parent_class = NULL;
 static void vala_ccode_comma_expression_dispose (GObject * obj);
 
 
+
 /**
  * Appends the specified expression to the expression list.
  *
@@ -52,6 +56,12 @@ void vala_ccode_comma_expression_append_expression (ValaCCodeCommaExpression* se
 }
 
 
+GeeCollection* vala_ccode_comma_expression_get_inner (ValaCCodeCommaExpression* self) {
+	g_return_val_if_fail (VALA_IS_CCODE_COMMA_EXPRESSION (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->inner)));
+}
+
+
 static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeCommaExpression * self;
 	gboolean first;
@@ -66,7 +76,7 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
 		while (gee_iterator_next (expr_it)) {
 			ValaCCodeExpression* expr;
-			expr = gee_iterator_get (expr_it);
+			expr = ((ValaCCodeExpression*) gee_iterator_get (expr_it));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
