@@ -25,6 +25,9 @@
 #include <string.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeConditionalExpressionPrivate {
 	ValaCCodeExpression* _condition;
 	ValaCCodeExpression* _true_expression;
@@ -42,6 +45,7 @@ static gpointer vala_ccode_conditional_expression_parent_class = NULL;
 static void vala_ccode_conditional_expression_dispose (GObject * obj);
 
 
+
 ValaCCodeConditionalExpression* vala_ccode_conditional_expression_new (ValaCCodeExpression* cond, ValaCCodeExpression* true_expr, ValaCCodeExpression* false_expr) {
 	GParameter * __params;
 	GParameter * __params_it;
@@ -78,11 +82,11 @@ static void vala_ccode_conditional_expression_real_write (ValaCCodeNode* base, V
 	self = VALA_CCODE_CONDITIONAL_EXPRESSION (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "(");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_conditional_expression_get_condition (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_condition), writer);
 	vala_ccode_writer_write_string (writer, " ? ");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_conditional_expression_get_true_expression (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_true_expression), writer);
 	vala_ccode_writer_write_string (writer, " : ");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_conditional_expression_get_false_expression (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_false_expression), writer);
 	vala_ccode_writer_write_string (writer, ")");
 }
 
