@@ -22,6 +22,9 @@
 
 #include <ccode/valaccodeconstant.h>
 
+
+
+
 struct _ValaCCodeConstantPrivate {
 	char* _name;
 };
@@ -35,6 +38,7 @@ static gpointer vala_ccode_constant_parent_class = NULL;
 static void vala_ccode_constant_dispose (GObject * obj);
 
 
+
 ValaCCodeConstant* vala_ccode_constant_new (const char* _name) {
 	GParameter * __params;
 	GParameter * __params_it;
@@ -59,7 +63,7 @@ static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter
 	ValaCCodeConstant * self;
 	self = VALA_CCODE_CONSTANT (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_writer_write_string (writer, vala_ccode_constant_get_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_name);
 }
 
 
