@@ -27,6 +27,9 @@
 #include <ccode/valaccodelinedirective.h>
 #include <ccode/valaccodeblock.h>
 
+
+
+
 struct _ValaCCodeDoStatementPrivate {
 	ValaCCodeStatement* _body;
 	ValaCCodeExpression* _condition;
@@ -42,6 +45,7 @@ static gpointer vala_ccode_do_statement_parent_class = NULL;
 static void vala_ccode_do_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeDoStatement* vala_ccode_do_statement_new (ValaCCodeStatement* stmt, ValaCCodeExpression* cond) {
 	GParameter * __params;
 	GParameter * __params_it;
@@ -72,17 +76,17 @@ static void vala_ccode_do_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "do");
 	/* while shouldn't be on a separate line */
-	if (VALA_IS_CCODE_BLOCK (vala_ccode_do_statement_get_body (self))) {
+	if (VALA_IS_CCODE_BLOCK (self->priv->_body)) {
 		ValaCCodeBlock* _tmp0;
 		ValaCCodeBlock* cblock;
 		_tmp0 = NULL;
-		cblock = (_tmp0 = VALA_CCODE_BLOCK (vala_ccode_do_statement_get_body (self)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+		cblock = (_tmp0 = VALA_CCODE_BLOCK (self->priv->_body), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 		vala_ccode_block_set_suppress_newline (cblock, TRUE);
 		(cblock == NULL ? NULL : (cblock = (g_object_unref (cblock), NULL)));
 	}
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_do_statement_get_body (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_body), writer);
 	vala_ccode_writer_write_string (writer, " while (");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_do_statement_get_condition (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_condition), writer);
 	vala_ccode_writer_write_string (writer, ");");
 }
 
