@@ -18,7 +18,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- * 	Raffaele Sandrini <rasa@gmx.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
  *	Jürg Billeter <j@bitron.ch>
  */
 
@@ -27,6 +27,9 @@
 #include <string.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeElementAccessPrivate {
 	ValaCCodeExpression* _container;
 	ValaCCodeExpression* _index;
@@ -42,6 +45,7 @@ static gpointer vala_ccode_element_access_parent_class = NULL;
 static void vala_ccode_element_access_dispose (GObject * obj);
 
 
+
 ValaCCodeElementAccess* vala_ccode_element_access_new (ValaCCodeExpression* cont, ValaCCodeExpression* i) {
 	GParameter * __params;
 	GParameter * __params_it;
@@ -50,8 +54,14 @@ ValaCCodeElementAccess* vala_ccode_element_access_new (ValaCCodeExpression* cont
 	g_return_val_if_fail (i == NULL || VALA_IS_CCODE_EXPRESSION (i), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	(__params_it->name = "container", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, cont), __params_it++);
-	(__params_it->name = "index", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, i), __params_it++);
+	__params_it->name = "container";
+	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
+	g_value_set_object (&__params_it->value, cont);
+	__params_it++;
+	__params_it->name = "index";
+	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
+	g_value_set_object (&__params_it->value, i);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_ELEMENT_ACCESS, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -66,9 +76,9 @@ static void vala_ccode_element_access_real_write (ValaCCodeNode* base, ValaCCode
 	ValaCCodeElementAccess * self;
 	self = VALA_CCODE_ELEMENT_ACCESS (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_element_access_get_container (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_container), writer);
 	vala_ccode_writer_write_string (writer, "[");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_element_access_get_index (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_index), writer);
 	vala_ccode_writer_write_string (writer, "]");
 }
 
