@@ -26,6 +26,9 @@
 #include <gee/collection.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeEnumPrivate {
 	char* _name;
 	GeeList* values;
@@ -40,6 +43,7 @@ static gpointer vala_ccode_enum_parent_class = NULL;
 static void vala_ccode_enum_dispose (GObject * obj);
 
 
+
 ValaCCodeEnum* vala_ccode_enum_new (const char* name) {
 	ValaCCodeEnum * self;
 	self = g_object_newv (VALA_TYPE_CCODE_ENUM, 0, NULL);
@@ -66,7 +70,7 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 	gboolean first;
 	self = VALA_CCODE_ENUM (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	if (vala_ccode_enum_get_name (self) != NULL) {
+	if (self->priv->_name != NULL) {
 		vala_ccode_writer_write_string (writer, "typedef ");
 	}
 	vala_ccode_writer_write_string (writer, "enum ");
@@ -79,7 +83,7 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 		value_it = gee_iterable_iterator (GEE_ITERABLE (value_collection));
 		while (gee_iterator_next (value_it)) {
 			ValaCCodeEnumValue* value;
-			value = gee_iterator_get (value_it);
+			value = ((ValaCCodeEnumValue*) gee_iterator_get (value_it));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ",");
@@ -97,9 +101,9 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 		vala_ccode_writer_write_newline (writer);
 	}
 	vala_ccode_writer_write_end_block (writer);
-	if (vala_ccode_enum_get_name (self) != NULL) {
+	if (self->priv->_name != NULL) {
 		vala_ccode_writer_write_string (writer, " ");
-		vala_ccode_writer_write_string (writer, vala_ccode_enum_get_name (self));
+		vala_ccode_writer_write_string (writer, self->priv->_name);
 	}
 	vala_ccode_writer_write_string (writer, ";");
 	vala_ccode_writer_write_newline (writer);
@@ -170,7 +174,7 @@ static void vala_ccode_enum_init (ValaCCodeEnum * self) {
 static void vala_ccode_enum_dispose (GObject * obj) {
 	ValaCCodeEnum * self;
 	self = VALA_CCODE_ENUM (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->values == NULL ? NULL : (self->priv->values = (g_object_unref (self->priv->values), NULL)));
 	G_OBJECT_CLASS (vala_ccode_enum_parent_class)->dispose (obj);
 }
