@@ -28,6 +28,9 @@
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeExpressionStatementPrivate {
 	ValaCCodeExpression* _expression;
 };
@@ -42,6 +45,7 @@ static gpointer vala_ccode_expression_statement_parent_class = NULL;
 static void vala_ccode_expression_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpression* expr) {
 	GParameter * __params;
 	GParameter * __params_it;
@@ -67,7 +71,7 @@ static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, Val
 	ValaCCodeExpressionStatement * self;
 	self = VALA_CCODE_EXPRESSION_STATEMENT (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	if (VALA_IS_CCODE_COMMA_EXPRESSION (vala_ccode_expression_statement_get_expression (self))) {
+	if (VALA_IS_CCODE_COMMA_EXPRESSION (self->priv->_expression)) {
 		ValaCCodeCommaExpression* _tmp1;
 		ValaCCodeExpression* _tmp0;
 		ValaCCodeCommaExpression* ccomma;
@@ -75,7 +79,7 @@ static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, Val
 		 to improve code readability*/
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		ccomma = (_tmp1 = (_tmp0 = vala_ccode_expression_statement_get_expression (self), (VALA_IS_CCODE_COMMA_EXPRESSION (_tmp0) ? ((ValaCCodeCommaExpression*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+		ccomma = (_tmp1 = (_tmp0 = self->priv->_expression, (VALA_IS_CCODE_COMMA_EXPRESSION (_tmp0) ? ((ValaCCodeCommaExpression*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 		{
 			GeeCollection* expr_collection;
 			GeeIterator* expr_it;
@@ -94,17 +98,17 @@ static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, Val
 		}
 		(ccomma == NULL ? NULL : (ccomma = (g_object_unref (ccomma), NULL)));
 	} else {
-		if (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (vala_ccode_expression_statement_get_expression (self))) {
+		if (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (self->priv->_expression)) {
 			ValaCCodeParenthesizedExpression* _tmp3;
 			ValaCCodeExpression* _tmp2;
 			ValaCCodeParenthesizedExpression* cpar;
 			_tmp3 = NULL;
 			_tmp2 = NULL;
-			cpar = (_tmp3 = (_tmp2 = vala_ccode_expression_statement_get_expression (self), (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (_tmp2) ? ((ValaCCodeParenthesizedExpression*) _tmp2) : NULL)), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
+			cpar = (_tmp3 = (_tmp2 = self->priv->_expression, (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (_tmp2) ? ((ValaCCodeParenthesizedExpression*) _tmp2) : NULL)), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
 			vala_ccode_expression_statement_write_expression (self, writer, vala_ccode_parenthesized_expression_get_inner (cpar));
 			(cpar == NULL ? NULL : (cpar = (g_object_unref (cpar), NULL)));
 		} else {
-			vala_ccode_expression_statement_write_expression (self, writer, vala_ccode_expression_statement_get_expression (self));
+			vala_ccode_expression_statement_write_expression (self, writer, self->priv->_expression);
 		}
 	}
 }
