@@ -29,6 +29,9 @@
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeForStatementPrivate {
 	ValaCCodeExpression* _condition;
 	ValaCCodeStatement* _body;
@@ -46,6 +49,7 @@ static gpointer vala_ccode_for_statement_parent_class = NULL;
 static void vala_ccode_for_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condition, ValaCCodeStatement* body) {
 	ValaCCodeForStatement * self;
 	g_return_val_if_fail (condition == NULL || VALA_IS_CCODE_EXPRESSION (condition), NULL);
@@ -97,7 +101,7 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 		init_expr_it = gee_iterable_iterator (GEE_ITERABLE (init_expr_collection));
 		while (gee_iterator_next (init_expr_it)) {
 			ValaCCodeExpression* init_expr;
-			init_expr = gee_iterator_get (init_expr_it);
+			init_expr = ((ValaCCodeExpression*) gee_iterator_get (init_expr_it));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -113,8 +117,8 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 		(init_expr_it == NULL ? NULL : (init_expr_it = (g_object_unref (init_expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, "; ");
-	if (vala_ccode_for_statement_get_condition (self) != NULL) {
-		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_for_statement_get_condition (self)), writer);
+	if (self->priv->_condition != NULL) {
+		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_condition), writer);
 	}
 	vala_ccode_writer_write_string (writer, "; ");
 	first = TRUE;
@@ -125,7 +129,7 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 		it_expr_it = gee_iterable_iterator (GEE_ITERABLE (it_expr_collection));
 		while (gee_iterator_next (it_expr_it)) {
 			ValaCCodeExpression* it_expr;
-			it_expr = gee_iterator_get (it_expr_it);
+			it_expr = ((ValaCCodeExpression*) gee_iterator_get (it_expr_it));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -141,7 +145,7 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 		(it_expr_it == NULL ? NULL : (it_expr_it = (g_object_unref (it_expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, ")");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_for_statement_get_body (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_body), writer);
 }
 
 
