@@ -25,6 +25,9 @@
 #include <gee/list.h>
 #include <gee/collection.h>
 
+
+
+
 struct _ValaCCodeFunctionDeclaratorPrivate {
 	char* _name;
 	GeeList* parameters;
@@ -40,6 +43,7 @@ static gpointer vala_ccode_function_declarator_parent_class = NULL;
 static void vala_ccode_function_declarator_dispose (GObject * obj);
 
 
+
 ValaCCodeFunctionDeclarator* vala_ccode_function_declarator_new (const char* name) {
 	ValaCCodeFunctionDeclarator * self;
 	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION_DECLARATOR, 0, NULL);
@@ -74,7 +78,7 @@ static void vala_ccode_function_declarator_real_write_declaration (ValaCCodeNode
 	self = VALA_CCODE_FUNCTION_DECLARATOR (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "(*");
-	vala_ccode_writer_write_string (writer, vala_ccode_function_declarator_get_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_name);
 	vala_ccode_writer_write_string (writer, ") (");
 	first = TRUE;
 	{
@@ -84,7 +88,7 @@ static void vala_ccode_function_declarator_real_write_declaration (ValaCCodeNode
 		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
 		while (gee_iterator_next (param_it)) {
 			ValaCCodeFormalParameter* param;
-			param = gee_iterator_get (param_it);
+			param = ((ValaCCodeFormalParameter*) gee_iterator_get (param_it));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -166,7 +170,7 @@ static void vala_ccode_function_declarator_init (ValaCCodeFunctionDeclarator * s
 static void vala_ccode_function_declarator_dispose (GObject * obj) {
 	ValaCCodeFunctionDeclarator * self;
 	self = VALA_CCODE_FUNCTION_DECLARATOR (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
 	G_OBJECT_CLASS (vala_ccode_function_declarator_parent_class)->dispose (obj);
 }
