@@ -23,6 +23,9 @@
 #include <ccode/valaccodegotostatement.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeGotoStatementPrivate {
 	char* _name;
 };
@@ -36,13 +39,17 @@ static gpointer vala_ccode_goto_statement_parent_class = NULL;
 static void vala_ccode_goto_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeGotoStatement* vala_ccode_goto_statement_new (const char* name) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeGotoStatement * self;
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, name), __params_it++);
+	__params_it->name = "name";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, name);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_GOTO_STATEMENT, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -59,7 +66,7 @@ static void vala_ccode_goto_statement_real_write (ValaCCodeNode* base, ValaCCode
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "goto ");
-	vala_ccode_writer_write_string (writer, vala_ccode_goto_statement_get_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_name);
 	vala_ccode_writer_write_string (writer, ";");
 	vala_ccode_writer_write_newline (writer);
 }
@@ -128,7 +135,7 @@ static void vala_ccode_goto_statement_init (ValaCCodeGotoStatement * self) {
 static void vala_ccode_goto_statement_dispose (GObject * obj) {
 	ValaCCodeGotoStatement * self;
 	self = VALA_CCODE_GOTO_STATEMENT (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	self->priv->_name = (g_free (self->priv->_name), NULL);
 	G_OBJECT_CLASS (vala_ccode_goto_statement_parent_class)->dispose (obj);
 }
 
