@@ -23,6 +23,9 @@
 #include <ccode/valaccodeincludedirective.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeIncludeDirectivePrivate {
 	char* _filename;
 	gboolean _local;
@@ -38,14 +41,17 @@ static gpointer vala_ccode_include_directive_parent_class = NULL;
 static void vala_ccode_include_directive_dispose (GObject * obj);
 
 
+
 ValaCCodeIncludeDirective* vala_ccode_include_directive_new (const char* _filename, gboolean _local) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeIncludeDirective * self;
-	g_return_val_if_fail (_filename != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "filename", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _filename), __params_it++);
+	__params_it->name = "filename";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, _filename);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_INCLUDE_DIRECTIVE, __params_it - __params, __params);
 	vala_ccode_include_directive_set_local (self, _local);
 	while (__params_it > __params) {
@@ -60,18 +66,16 @@ ValaCCodeIncludeDirective* vala_ccode_include_directive_new (const char* _filena
 static void vala_ccode_include_directive_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeIncludeDirective * self;
 	self = VALA_CCODE_INCLUDE_DIRECTIVE (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#include ");
-	if (vala_ccode_include_directive_get_local (self)) {
+	if (self->priv->_local) {
+		vala_ccode_writer_write_string (writer, "\"");
+		vala_ccode_writer_write_string (writer, self->priv->_filename);
 		vala_ccode_writer_write_string (writer, "\"");
 	} else {
 		vala_ccode_writer_write_string (writer, "<");
-	}
-	vala_ccode_writer_write_string (writer, vala_ccode_include_directive_get_filename (self));
-	if (vala_ccode_include_directive_get_local (self)) {
-		vala_ccode_writer_write_string (writer, "\"");
-	} else {
+		vala_ccode_writer_write_string (writer, self->priv->_filename);
 		vala_ccode_writer_write_string (writer, ">");
 	}
 	vala_ccode_writer_write_newline (writer);
@@ -85,10 +89,12 @@ char* vala_ccode_include_directive_get_filename (ValaCCodeIncludeDirective* self
 
 
 void vala_ccode_include_directive_set_filename (ValaCCodeIncludeDirective* self, const char* value) {
-	char* _tmp1;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_INCLUDE_DIRECTIVE (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_filename = (_tmp1 = g_strdup (value), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp1);
+	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp2);
 }
 
 
@@ -158,7 +164,7 @@ static void vala_ccode_include_directive_init (ValaCCodeIncludeDirective * self)
 static void vala_ccode_include_directive_dispose (GObject * obj) {
 	ValaCCodeIncludeDirective * self;
 	self = VALA_CCODE_INCLUDE_DIRECTIVE (obj);
-	(self->priv->_filename = (g_free (self->priv->_filename), NULL));
+	self->priv->_filename = (g_free (self->priv->_filename), NULL);
 	G_OBJECT_CLASS (vala_ccode_include_directive_parent_class)->dispose (obj);
 }
 
