@@ -23,6 +23,9 @@
 #include <ccode/valaccodemacroreplacement.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeMacroReplacementPrivate {
 	char* _name;
 	char* _replacement;
@@ -40,13 +43,17 @@ static gpointer vala_ccode_macro_replacement_parent_class = NULL;
 static void vala_ccode_macro_replacement_dispose (GObject * obj);
 
 
+
 ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* name, const char* replacement) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeMacroReplacement * self;
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, name), __params_it++);
+	__params_it->name = "name";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, name);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_MACRO_REPLACEMENT, __params_it - __params, __params);
 	vala_ccode_macro_replacement_set_replacement (self, replacement);
 	while (__params_it > __params) {
@@ -65,7 +72,10 @@ ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new_with_expression (con
 	g_return_val_if_fail (replacement_expression == NULL || VALA_IS_CCODE_EXPRESSION (replacement_expression), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, name), __params_it++);
+	__params_it->name = "name";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, name);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_MACRO_REPLACEMENT, __params_it - __params, __params);
 	vala_ccode_macro_replacement_set_replacement_expression (self, replacement_expression);
 	while (__params_it > __params) {
@@ -83,12 +93,12 @@ static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCC
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#define ");
-	vala_ccode_writer_write_string (writer, vala_ccode_macro_replacement_get_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_name);
 	vala_ccode_writer_write_string (writer, " ");
-	if (vala_ccode_macro_replacement_get_replacement (self) != NULL) {
-		vala_ccode_writer_write_string (writer, vala_ccode_macro_replacement_get_replacement (self));
+	if (self->priv->_replacement != NULL) {
+		vala_ccode_writer_write_string (writer, self->priv->_replacement);
 	} else {
-		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_macro_replacement_get_replacement_expression (self)), writer);
+		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_replacement_expression), writer);
 	}
 	vala_ccode_writer_write_newline (writer);
 }
@@ -203,8 +213,8 @@ static void vala_ccode_macro_replacement_init (ValaCCodeMacroReplacement * self)
 static void vala_ccode_macro_replacement_dispose (GObject * obj) {
 	ValaCCodeMacroReplacement * self;
 	self = VALA_CCODE_MACRO_REPLACEMENT (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
-	(self->priv->_replacement = (g_free (self->priv->_replacement), NULL));
+	self->priv->_name = (g_free (self->priv->_name), NULL);
+	self->priv->_replacement = (g_free (self->priv->_replacement), NULL);
 	(self->priv->_replacement_expression == NULL ? NULL : (self->priv->_replacement_expression = (g_object_unref (self->priv->_replacement_expression), NULL)));
 	G_OBJECT_CLASS (vala_ccode_macro_replacement_parent_class)->dispose (obj);
 }
