@@ -23,6 +23,9 @@
 #include <ccode/valaccodememberaccess.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeMemberAccessPrivate {
 	ValaCCodeExpression* _inner;
 	char* _member_name;
@@ -40,6 +43,7 @@ static gpointer vala_ccode_member_access_parent_class = NULL;
 static void vala_ccode_member_access_dispose (GObject * obj);
 
 
+
 ValaCCodeMemberAccess* vala_ccode_member_access_new (ValaCCodeExpression* container, const char* member, gboolean pointer) {
 	GParameter * __params;
 	GParameter * __params_it;
@@ -96,13 +100,13 @@ static void vala_ccode_member_access_real_write (ValaCCodeNode* base, ValaCCodeW
 	ValaCCodeMemberAccess * self;
 	self = VALA_CCODE_MEMBER_ACCESS (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_member_access_get_inner (self)), writer);
-	if (vala_ccode_member_access_get_is_pointer (self)) {
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_inner), writer);
+	if (self->priv->_is_pointer) {
 		vala_ccode_writer_write_string (writer, "->");
 	} else {
 		vala_ccode_writer_write_string (writer, ".");
 	}
-	vala_ccode_writer_write_string (writer, vala_ccode_member_access_get_member_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_member_name);
 }
 
 
