@@ -1,11 +1,11 @@
 /* valaccodemodifiers.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,11 +18,11 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
-#ifndef __VALACCODEMODIFIERS_H__
-#define __VALACCODEMODIFIERS_H__
+#ifndef __CCODE_VALACCODEMODIFIERS_H__
+#define __CCODE_VALACCODEMODIFIERS_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -30,14 +30,20 @@
 G_BEGIN_DECLS
 
 
+#define VALA_TYPE_CCODE_MODIFIERS (vala_ccode_modifiers_get_type ())
+
 typedef enum  {
-	VALA_CCODE_MODIFIERS_NONE,
-	VALA_CCODE_MODIFIERS_STATIC,
-	VALA_CCODE_MODIFIERS_REGISTER,
-	VALA_CCODE_MODIFIERS_EXTERN
+	VALA_CCODE_MODIFIERS_NONE = 0,
+	VALA_CCODE_MODIFIERS_STATIC = 1 << 0,
+	VALA_CCODE_MODIFIERS_REGISTER = 1 << 1,
+	VALA_CCODE_MODIFIERS_EXTERN = 1 << 2,
+	VALA_CCODE_MODIFIERS_INLINE = 1 << 3
 } ValaCCodeModifiers;
 
 
+GType vala_ccode_modifiers_get_type (void);
+
+
 G_END_DECLS
 
 #endif
