@@ -24,6 +24,9 @@
 #include <ccode/valaccodelinedirective.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeOnceSectionPrivate {
 	char* _define;
 };
@@ -38,13 +41,17 @@ static gpointer vala_ccode_once_section_parent_class = NULL;
 static void vala_ccode_once_section_dispose (GObject * obj);
 
 
+
 ValaCCodeOnceSection* vala_ccode_once_section_new (const char* def) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeOnceSection * self;
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "define", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, def), __params_it++);
+	__params_it->name = "define";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, def);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_ONCE_SECTION, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -61,10 +68,10 @@ static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWr
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#ifndef ");
-	vala_ccode_writer_write_string (writer, vala_ccode_once_section_get_define (self));
+	vala_ccode_writer_write_string (writer, self->priv->_define);
 	vala_ccode_writer_write_newline (writer);
 	vala_ccode_writer_write_string (writer, "#define ");
-	vala_ccode_writer_write_string (writer, vala_ccode_once_section_get_define (self));
+	vala_ccode_writer_write_string (writer, self->priv->_define);
 	vala_ccode_writer_write_newline (writer);
 	{
 		GeeCollection* node_collection;
@@ -73,7 +80,7 @@ static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWr
 		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
 		while (gee_iterator_next (node_it)) {
 			ValaCCodeNode* node;
-			node = gee_iterator_get (node_it);
+			node = ((ValaCCodeNode*) gee_iterator_get (node_it));
 			{
 				vala_ccode_node_write_combined (node, writer);
 				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
@@ -159,7 +166,7 @@ static void vala_ccode_once_section_init (ValaCCodeOnceSection * self) {
 static void vala_ccode_once_section_dispose (GObject * obj) {
 	ValaCCodeOnceSection * self;
 	self = VALA_CCODE_ONCE_SECTION (obj);
-	(self->priv->_define = (g_free (self->priv->_define), NULL));
+	self->priv->_define = (g_free (self->priv->_define), NULL);
 	G_OBJECT_CLASS (vala_ccode_once_section_parent_class)->dispose (obj);
 }
 
