@@ -29,6 +29,9 @@
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeSwitchStatementPrivate {
 	ValaCCodeExpression* _expression;
 	GeeList* case_statements;
@@ -44,6 +47,7 @@ static gpointer vala_ccode_switch_statement_parent_class = NULL;
 static void vala_ccode_switch_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression) {
 	ValaCCodeSwitchStatement * self;
 	g_return_val_if_fail (expression == NULL || VALA_IS_CCODE_EXPRESSION (expression), NULL);
@@ -83,7 +87,7 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "switch (");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_switch_statement_get_expression (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_expression), writer);
 	vala_ccode_writer_write_string (writer, ")");
 	vala_ccode_writer_write_begin_block (writer);
 	{
