@@ -23,6 +23,9 @@
 #include <ccode/valaccodetypedefinition.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeTypeDefinitionPrivate {
 	char* _type_name;
 	ValaCCodeDeclarator* _declarator;
@@ -39,6 +42,7 @@ static gpointer vala_ccode_type_definition_parent_class = NULL;
 static void vala_ccode_type_definition_dispose (GObject * obj);
 
 
+
 ValaCCodeTypeDefinition* vala_ccode_type_definition_new (const char* type, ValaCCodeDeclarator* decl) {
 	ValaCCodeTypeDefinition * self;
 	g_return_val_if_fail (decl == NULL || VALA_IS_CCODE_DECLARATOR (decl), NULL);
@@ -62,9 +66,9 @@ static void vala_ccode_type_definition_real_write_declaration (ValaCCodeNode* ba
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "typedef ");
-	vala_ccode_writer_write_string (writer, vala_ccode_type_definition_get_type_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_type_name);
 	vala_ccode_writer_write_string (writer, " ");
-	vala_ccode_node_write_declaration (VALA_CCODE_NODE (vala_ccode_type_definition_get_declarator (self)), writer);
+	vala_ccode_node_write_declaration (VALA_CCODE_NODE (self->priv->_declarator), writer);
 	vala_ccode_writer_write_string (writer, ";");
 	vala_ccode_writer_write_newline (writer);
 }
@@ -157,7 +161,7 @@ static void vala_ccode_type_definition_init (ValaCCodeTypeDefinition * self) {
 static void vala_ccode_type_definition_dispose (GObject * obj) {
 	ValaCCodeTypeDefinition * self;
 	self = VALA_CCODE_TYPE_DEFINITION (obj);
-	(self->priv->_type_name = (g_free (self->priv->_type_name), NULL));
+	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
 	(self->priv->_declarator == NULL ? NULL : (self->priv->_declarator = (g_object_unref (self->priv->_declarator), NULL)));
 	G_OBJECT_CLASS (vala_ccode_type_definition_parent_class)->dispose (obj);
 }
