@@ -1,6 +1,6 @@
 /* valaccodevariabledeclarator.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,8 +22,12 @@
 
 #include <ccode/valaccodevariabledeclarator.h>
 #include <ccode/valaccodenode.h>
+#include <ccode/valaccodeinitializerlist.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeVariableDeclaratorPrivate {
 	char* _name;
 	ValaCCodeExpression* _initializer;
@@ -41,13 +45,17 @@ static gpointer vala_ccode_variable_declarator_parent_class = NULL;
 static void vala_ccode_variable_declarator_dispose (GObject * obj);
 
 
+
 ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* _name) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeVariableDeclarator * self;
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
+	__params_it->name = "name";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, _name);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_VARIABLE_DECLARATOR, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -65,7 +73,10 @@ ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new_with_initializer
 	g_return_val_if_fail (init == NULL || VALA_IS_CCODE_EXPRESSION (init), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
+	__params_it->name = "name";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, _name);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_VARIABLE_DECLARATOR, __params_it - __params, __params);
 	vala_ccode_variable_declarator_set_initializer (self, init);
 	while (__params_it > __params) {
@@ -81,10 +92,10 @@ static void vala_ccode_variable_declarator_real_write (ValaCCodeNode* base, Vala
 	ValaCCodeVariableDeclarator * self;
 	self = VALA_CCODE_VARIABLE_DECLARATOR (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_writer_write_string (writer, vala_ccode_variable_declarator_get_name (self));
-	if (vala_ccode_variable_declarator_get_initializer (self) != NULL) {
+	vala_ccode_writer_write_string (writer, self->priv->_name);
+	if (self->priv->_initializer != NULL) {
 		vala_ccode_writer_write_string (writer, " = ");
-		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_variable_declarator_get_initializer (self)), writer);
+		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_initializer), writer);
 	}
 }
 
@@ -93,7 +104,12 @@ static void vala_ccode_variable_declarator_real_write_declaration (ValaCCodeNode
 	ValaCCodeVariableDeclarator * self;
 	self = VALA_CCODE_VARIABLE_DECLARATOR (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_writer_write_string (writer, vala_ccode_variable_declarator_get_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_name);
+	/* initializer lists can't be moved to a separate statement*/
+	if (VALA_IS_CCODE_INITIALIZER_LIST (self->priv->_initializer)) {
+		vala_ccode_writer_write_string (writer, " = ");
+		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_initializer), writer);
+	}
 }
 
 
@@ -101,11 +117,11 @@ static void vala_ccode_variable_declarator_real_write_initialization (ValaCCodeD
 	ValaCCodeVariableDeclarator * self;
 	self = VALA_CCODE_VARIABLE_DECLARATOR (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	if (vala_ccode_variable_declarator_get_initializer (self) != NULL) {
+	if (self->priv->_initializer != NULL && !(VALA_IS_CCODE_INITIALIZER_LIST (self->priv->_initializer))) {
 		vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
-		vala_ccode_writer_write_string (writer, vala_ccode_variable_declarator_get_name (self));
+		vala_ccode_writer_write_string (writer, self->priv->_name);
 		vala_ccode_writer_write_string (writer, " = ");
-		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_variable_declarator_get_initializer (self)), writer);
+		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_initializer), writer);
 		vala_ccode_writer_write_string (writer, ";");
 		vala_ccode_writer_write_newline (writer);
 	}
@@ -200,7 +216,7 @@ static void vala_ccode_variable_declarator_init (ValaCCodeVariableDeclarator * s
 static void vala_ccode_variable_declarator_dispose (GObject * obj) {
 	ValaCCodeVariableDeclarator * self;
 	self = VALA_CCODE_VARIABLE_DECLARATOR (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
 	G_OBJECT_CLASS (vala_ccode_variable_declarator_parent_class)->dispose (obj);
 }
