@@ -25,6 +25,9 @@
 #include <glib/gstdio.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeWriterPrivate {
 	gboolean _line_directives;
 	char* _filename;
@@ -47,13 +50,17 @@ static void vala_ccode_writer_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
+
 ValaCCodeWriter* vala_ccode_writer_new (const char* _filename) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeWriter * self;
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "filename", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _filename), __params_it++);
+	__params_it->name = "filename";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, _filename);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_WRITER, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -101,7 +108,7 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 			}
 			len = g_mapped_file_get_length (old_file);
 			if (len == g_mapped_file_get_length (new_file)) {
-				if (memcmp (g_mapped_file_get_contents (old_file), g_mapped_file_get_contents (new_file), len) == 0) {
+				if (memcmp (((gpointer) g_mapped_file_get_contents (old_file)), ((gpointer) g_mapped_file_get_contents (new_file)), ((gsize) len)) == 0) {
 					changed = FALSE;
 				}
 			}
@@ -139,7 +146,7 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line) {
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
 	g_return_if_fail (line == NULL || VALA_IS_CCODE_LINE_DIRECTIVE (line));
-	if (vala_ccode_writer_get_line_directives (self) && line != NULL) {
+	if (self->priv->_line_directives && line != NULL) {
 		vala_ccode_node_write (VALA_CCODE_NODE (line), self);
 	}
 	if (!vala_ccode_writer_get_bol (self)) {
@@ -239,13 +246,13 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 					first = FALSE;
 				}
 				fprintf (self->priv->stream, "%s", line);
-				(line = (g_free (line), NULL));
+				line = (g_free (line), NULL);
 			}
 		}
 	}
 	fprintf (self->priv->stream, "*/");
 	vala_ccode_writer_write_newline (self);
-	(lines = (_vala_array_free (lines, lines_length1, ((GDestroyNotify) g_free)), NULL));
+	lines = (_vala_array_free (lines, lines_length1, ((GDestroyNotify) g_free)), NULL);
 }
 
 
@@ -354,8 +361,8 @@ static void vala_ccode_writer_init (ValaCCodeWriter * self) {
 static void vala_ccode_writer_dispose (GObject * obj) {
 	ValaCCodeWriter * self;
 	self = VALA_CCODE_WRITER (obj);
-	(self->priv->_filename = (g_free (self->priv->_filename), NULL));
-	(self->priv->temp_filename = (g_free (self->priv->temp_filename), NULL));
+	self->priv->_filename = (g_free (self->priv->_filename), NULL);
+	self->priv->temp_filename = (g_free (self->priv->temp_filename), NULL);
 	(self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)));
 	G_OBJECT_CLASS (vala_ccode_writer_parent_class)->dispose (obj);
 }
