@@ -2,7 +2,7 @@
  *
  * Copyright (C) 2004-2005  Novell, Inc
  * Copyright (C) 2005  David Waite
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,39 +25,6 @@
 #include <gee/arraylist.h>
 #include <string.h>
 
-typedef struct _GeeArrayListIterator GeeArrayListIterator;
-typedef struct _GeeArrayListIteratorClass GeeArrayListIteratorClass;
-typedef struct _GeeArrayListIteratorPrivate GeeArrayListIteratorPrivate;
-struct _GeeArrayListPrivate {
-	gpointer* _items;
-	gint _items_length1;
-	gint _size;
-	GEqualFunc _equal_func;
-	gint _stamp;
-	GBoxedCopyFunc g_dup_func;
-	GDestroyNotify g_destroy_func;
-};
-#define GEE_ARRAY_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_ARRAY_LIST, GeeArrayListPrivate))
-enum  {
-	GEE_ARRAY_LIST_DUMMY_PROPERTY,
-	GEE_ARRAY_LIST_SIZE,
-	GEE_ARRAY_LIST_EQUAL_FUNC,
-	GEE_ARRAY_LIST_G_DUP_FUNC,
-	GEE_ARRAY_LIST_G_DESTROY_FUNC
-};
-static GeeIterator* gee_array_list_real_iterator (GeeIterable* base);
-static gboolean gee_array_list_real_contains (GeeCollection* base, gpointer item);
-static gint gee_array_list_real_index_of (GeeList* base, gpointer item);
-static gpointer gee_array_list_real_get (GeeList* base, gint index);
-static void gee_array_list_real_set (GeeList* base, gint index, gpointer item);
-static gboolean gee_array_list_real_add (GeeCollection* base, gpointer item);
-static void gee_array_list_real_insert (GeeList* base, gint index, gpointer item);
-static gboolean gee_array_list_real_remove (GeeCollection* base, gpointer item);
-static void gee_array_list_real_remove_at (GeeList* base, gint index);
-static void gee_array_list_real_clear (GeeCollection* base);
-static void gee_array_list_shift (GeeArrayList* self, gint start, gint delta);
-static void gee_array_list_grow_if_needed (GeeArrayList* self, gint new_count);
-static void gee_array_list_set_capacity (GeeArrayList* self, gint value);
 
 #define GEE_ARRAY_LIST_TYPE_ITERATOR (gee_array_list_iterator_get_type ())
 #define GEE_ARRAY_LIST_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIterator))
@@ -66,17 +33,57 @@ static void gee_array_list_set_capacity (GeeArrayList* self, gint value);
 #define GEE_ARRAY_LIST_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_ARRAY_LIST_TYPE_ITERATOR))
 #define GEE_ARRAY_LIST_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIteratorClass))
 
+typedef struct _GeeArrayListIterator GeeArrayListIterator;
+typedef struct _GeeArrayListIteratorClass GeeArrayListIteratorClass;
+typedef struct _GeeArrayListIteratorPrivate GeeArrayListIteratorPrivate;
+
 struct _GeeArrayListIterator {
-	GObject parent;
+	GObject parent_instance;
 	GeeArrayListIteratorPrivate * priv;
 	gint _stamp;
 };
 struct _GeeArrayListIteratorClass {
-	GObjectClass parent;
+	GObjectClass parent_class;
 };
+
+
+struct _GeeArrayListPrivate {
+	gpointer* _items;
+	gint _items_length1;
+	gint _size;
+	GEqualFunc _equal_func;
+	gint _stamp;
+	GType g_type;
+	GBoxedCopyFunc g_dup_func;
+	GDestroyNotify g_destroy_func;
+};
+#define GEE_ARRAY_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_ARRAY_LIST, GeeArrayListPrivate))
+enum  {
+	GEE_ARRAY_LIST_DUMMY_PROPERTY,
+	GEE_ARRAY_LIST_SIZE,
+	GEE_ARRAY_LIST_EQUAL_FUNC,
+	GEE_ARRAY_LIST_G_TYPE,
+	GEE_ARRAY_LIST_G_DUP_FUNC,
+	GEE_ARRAY_LIST_G_DESTROY_FUNC
+};
+static GType gee_array_list_real_get_element_type (GeeIterable* base);
+static GeeIterator* gee_array_list_real_iterator (GeeIterable* base);
+static gboolean gee_array_list_real_contains (GeeCollection* base, gconstpointer item);
+static gint gee_array_list_real_index_of (GeeList* base, gconstpointer item);
+static gpointer gee_array_list_real_get (GeeList* base, gint index);
+static void gee_array_list_real_set (GeeList* base, gint index, gconstpointer item);
+static gboolean gee_array_list_real_add (GeeCollection* base, gconstpointer item);
+static void gee_array_list_real_insert (GeeList* base, gint index, gconstpointer item);
+static gboolean gee_array_list_real_remove (GeeCollection* base, gconstpointer item);
+static void gee_array_list_real_remove_at (GeeList* base, gint index);
+static void gee_array_list_real_clear (GeeCollection* base);
+static void gee_array_list_shift (GeeArrayList* self, gint start, gint delta);
+static void gee_array_list_grow_if_needed (GeeArrayList* self, gint new_count);
+static void gee_array_list_set_capacity (GeeArrayList* self, gint value);
 struct _GeeArrayListIteratorPrivate {
 	GeeArrayList* _list;
 	gint _index;
+	GType g_type;
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
@@ -84,10 +91,11 @@ struct _GeeArrayListIteratorPrivate {
 enum  {
 	GEE_ARRAY_LIST_ITERATOR_DUMMY_PROPERTY,
 	GEE_ARRAY_LIST_ITERATOR_LIST,
+	GEE_ARRAY_LIST_ITERATOR_G_TYPE,
 	GEE_ARRAY_LIST_ITERATOR_G_DUP_FUNC,
 	GEE_ARRAY_LIST_ITERATOR_G_DESTROY_FUNC
 };
-static GeeArrayListIterator* gee_array_list_iterator_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list);
+static GeeArrayListIterator* gee_array_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list);
 static gboolean gee_array_list_iterator_real_next (GeeIterator* base);
 static gpointer gee_array_list_iterator_real_get (GeeIterator* base);
 static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArrayList* value);
@@ -104,31 +112,40 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 static void _vala_array_move (gpointer array, gsize element_size, gint src, gint dest, gint length);
 
 
-GeeArrayList* gee_array_list_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func) {
+
+GeeArrayList* gee_array_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func) {
 	GeeArrayList * self;
 	self = g_object_newv (GEE_TYPE_ARRAY_LIST, 0, NULL);
 	gee_array_list_set_equal_func (self, equal_func);
+	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
 	return self;
 }
 
 
-static GeeIterator* gee_array_list_real_iterator (GeeIterable* base) {
+static GType gee_array_list_real_get_element_type (GeeIterable* base) {
 	GeeArrayList * self;
 	self = GEE_ARRAY_LIST (base);
-	return GEE_ITERATOR (gee_array_list_iterator_new (self->priv->g_dup_func, self->priv->g_destroy_func, self));
+	return self->priv->g_type;
 }
 
 
-static gboolean gee_array_list_real_contains (GeeCollection* base, gpointer item) {
+static GeeIterator* gee_array_list_real_iterator (GeeIterable* base) {
+	GeeArrayList * self;
+	self = GEE_ARRAY_LIST (base);
+	return GEE_ITERATOR (gee_array_list_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) self->priv->g_dup_func), self->priv->g_destroy_func, self));
+}
+
+
+static gboolean gee_array_list_real_contains (GeeCollection* base, gconstpointer item) {
 	GeeArrayList * self;
 	self = GEE_ARRAY_LIST (base);
 	return (gee_list_index_of (GEE_LIST (self), item) != -1);
 }
 
 
-static gint gee_array_list_real_index_of (GeeList* base, gpointer item) {
+static gint gee_array_list_real_index_of (GeeList* base, gconstpointer item) {
 	GeeArrayList * self;
 	self = GEE_ARRAY_LIST (base);
 	{
@@ -146,54 +163,62 @@ static gint gee_array_list_real_index_of (GeeList* base, gpointer item) {
 
 static gpointer gee_array_list_real_get (GeeList* base, gint index) {
 	GeeArrayList * self;
-	gpointer _tmp0;
+	gconstpointer _tmp0;
 	self = GEE_ARRAY_LIST (base);
 	g_assert (index >= 0 && index < self->priv->_size);
-	return (_tmp0 = self->priv->_items[index], (_tmp0 == NULL || self->priv->g_dup_func == NULL ? _tmp0 : self->priv->g_dup_func (_tmp0)));
+	_tmp0 = NULL;
+	return (_tmp0 = self->priv->_items[index], (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0))));
 }
 
 
-static void gee_array_list_real_set (GeeList* base, gint index, gpointer item) {
+static void gee_array_list_real_set (GeeList* base, gint index, gconstpointer item) {
 	GeeArrayList * self;
 	gpointer _tmp1;
-	gpointer _tmp0;
+	gconstpointer _tmp0;
 	self = GEE_ARRAY_LIST (base);
 	g_assert (index >= 0 && index < self->priv->_size);
-	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? _tmp0 : self->priv->g_dup_func (_tmp0))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0)))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
 }
 
 
-static gboolean gee_array_list_real_add (GeeCollection* base, gpointer item) {
+static gboolean gee_array_list_real_add (GeeCollection* base, gconstpointer item) {
 	GeeArrayList * self;
 	gint _tmp2;
 	gpointer _tmp1;
-	gpointer _tmp0;
+	gconstpointer _tmp0;
 	self = GEE_ARRAY_LIST (base);
 	if (self->priv->_size == self->priv->_items_length1) {
 		gee_array_list_grow_if_needed (self, 1);
 	}
-	(_tmp2 = self->priv->_size++, self->priv->_items[_tmp2] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? _tmp0 : self->priv->g_dup_func (_tmp0))), (self->priv->_items[_tmp2] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[_tmp2] = (self->priv->g_destroy_func (self->priv->_items[_tmp2]), NULL))), _tmp1));
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	_tmp2 = self->priv->_size++;
+	self->priv->_items[_tmp2] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0)))), (self->priv->_items[_tmp2] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[_tmp2] = (self->priv->g_destroy_func (self->priv->_items[_tmp2]), NULL))), _tmp1);
 	self->priv->_stamp++;
 	return TRUE;
 }
 
 
-static void gee_array_list_real_insert (GeeList* base, gint index, gpointer item) {
+static void gee_array_list_real_insert (GeeList* base, gint index, gconstpointer item) {
 	GeeArrayList * self;
 	gpointer _tmp1;
-	gpointer _tmp0;
+	gconstpointer _tmp0;
 	self = GEE_ARRAY_LIST (base);
 	g_assert (index >= 0 && index <= self->priv->_size);
 	if (self->priv->_size == self->priv->_items_length1) {
 		gee_array_list_grow_if_needed (self, 1);
 	}
 	gee_array_list_shift (self, index, 1);
-	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? _tmp0 : self->priv->g_dup_func (_tmp0))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0)))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
 	self->priv->_stamp++;
 }
 
 
-static gboolean gee_array_list_real_remove (GeeCollection* base, gpointer item) {
+static gboolean gee_array_list_real_remove (GeeCollection* base, gconstpointer item) {
 	GeeArrayList * self;
 	self = GEE_ARRAY_LIST (base);
 	{
@@ -215,6 +240,7 @@ static void gee_array_list_real_remove_at (GeeList* base, gint index) {
 	gpointer _tmp0;
 	self = GEE_ARRAY_LIST (base);
 	g_assert (index >= 0 && index < self->priv->_size);
+	_tmp0 = NULL;
 	self->priv->_items[index] = (_tmp0 = NULL, (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp0);
 	gee_array_list_shift (self, index + 1, -1);
 	self->priv->_stamp++;
@@ -229,6 +255,7 @@ static void gee_array_list_real_clear (GeeCollection* base) {
 		index = 0;
 		for (index = 0; index < self->priv->_size; index++) {
 			gpointer _tmp0;
+			_tmp0 = NULL;
 			self->priv->_items[index] = (_tmp0 = NULL, (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp0);
 		}
 	}
@@ -261,7 +288,10 @@ static void gee_array_list_set_capacity (GeeArrayList* self, gint value) {
 	gint _tmp0;
 	g_return_if_fail (GEE_IS_ARRAY_LIST (self));
 	g_assert (value >= self->priv->_size);
-	(_tmp0 = value, self->priv->_items = g_renew (gpointer, self->priv->_items, value), (_tmp0 > self->priv->_items_length1 ? memset (self->priv->_items + self->priv->_items_length1, 0, sizeof (gpointer) * (_tmp0 - self->priv->_items_length1)) : NULL), self->priv->_items_length1 = _tmp0);
+	_tmp0 = value;
+	self->priv->_items = g_renew (gpointer, self->priv->_items, value);
+	(_tmp0 > self->priv->_items_length1 ? memset (self->priv->_items + self->priv->_items_length1, 0, sizeof (gpointer) * (_tmp0 - self->priv->_items_length1)) : NULL);
+	self->priv->_items_length1 = _tmp0;
 }
 
 
@@ -277,11 +307,12 @@ void gee_array_list_set_equal_func (GeeArrayList* self, GEqualFunc value) {
 }
 
 
-static GeeArrayListIterator* gee_array_list_iterator_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list) {
+static GeeArrayListIterator* gee_array_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list) {
 	GeeArrayListIterator * self;
-	g_return_val_if_fail (GEE_IS_ARRAY_LIST (list), NULL);
+	g_return_val_if_fail (list == NULL || GEE_IS_ARRAY_LIST (list), NULL);
 	self = g_object_newv (GEE_ARRAY_LIST_TYPE_ITERATOR, 0, NULL);
 	gee_array_list_iterator_set_list (self, list);
+	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
 	return self;
@@ -339,6 +370,12 @@ static void gee_array_list_iterator_set_property (GObject * object, guint proper
 		case GEE_ARRAY_LIST_ITERATOR_LIST:
 		gee_array_list_iterator_set_list (self, g_value_get_object (value));
 		break;
+		case GEE_ARRAY_LIST_ITERATOR_G_TYPE:
+		self->priv->g_type = g_value_get_gtype (value);
+		break;
+		case GEE_ARRAY_LIST_ITERATOR_G_DUP_FUNC:
+		self->priv->g_dup_func = g_value_get_pointer (value);
+		break;
 		case GEE_ARRAY_LIST_ITERATOR_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
@@ -355,6 +392,7 @@ static void gee_array_list_iterator_class_init (GeeArrayListIteratorClass * klas
 	G_OBJECT_CLASS (klass)->get_property = gee_array_list_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_array_list_iterator_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_array_list_iterator_dispose;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_LIST, g_param_spec_object ("list", "list", "list", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
@@ -416,6 +454,12 @@ static void gee_array_list_set_property (GObject * object, guint property_id, co
 		case GEE_ARRAY_LIST_EQUAL_FUNC:
 		gee_array_list_set_equal_func (self, g_value_get_pointer (value));
 		break;
+		case GEE_ARRAY_LIST_G_TYPE:
+		self->priv->g_type = g_value_get_gtype (value);
+		break;
+		case GEE_ARRAY_LIST_G_DUP_FUNC:
+		self->priv->g_dup_func = g_value_get_pointer (value);
+		break;
 		case GEE_ARRAY_LIST_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
@@ -432,6 +476,7 @@ static void gee_array_list_class_init (GeeArrayListClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = gee_array_list_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_array_list_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_array_list_dispose;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_SIZE, "size");
@@ -441,6 +486,7 @@ static void gee_array_list_class_init (GeeArrayListClass * klass) {
 
 static void gee_array_list_gee_iterable_interface_init (GeeIterableIface * iface) {
 	gee_array_list_gee_iterable_parent_iface = g_type_interface_peek_parent (iface);
+	iface->get_element_type = gee_array_list_real_get_element_type;
 	iface->iterator = gee_array_list_real_iterator;
 }
 
@@ -475,7 +521,7 @@ static void gee_array_list_init (GeeArrayList * self) {
 static void gee_array_list_dispose (GObject * obj) {
 	GeeArrayList * self;
 	self = GEE_ARRAY_LIST (obj);
-	(self->priv->_items = (_vala_array_free (self->priv->_items, self->priv->_items_length1, ((GDestroyNotify) self->priv->g_destroy_func)), NULL));
+	self->priv->_items = (_vala_array_free (self->priv->_items, self->priv->_items_length1, ((GDestroyNotify) self->priv->g_destroy_func)), NULL);
 	G_OBJECT_CLASS (gee_array_list_parent_class)->dispose (obj);
 }
 
@@ -516,9 +562,9 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 static void _vala_array_move (gpointer array, gsize element_size, gint src, gint dest, gint length) {
 	g_memmove (array + dest * element_size, array + src * element_size, length * element_size);
 	if (src < dest) {
-		memset (array + src * element_size, 0, (dest - src) * element_size);
+		memset (((char *) array + src * element_size), 0, (dest - src) * element_size);
 	} else {
-		memset (array + (dest + length) * element_size, 0, (src - dest) * element_size);
+		memset (((char *) array + (dest + length) * element_size), 0, (src - dest) * element_size);
 	}
 }
 
