@@ -1,6 +1,6 @@
 /* iterable.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -44,12 +44,15 @@ typedef struct _GeeIterableIface GeeIterableIface;
  */
 struct _GeeIterableIface {
 	GTypeInterface parent_iface;
+	GType (*get_element_type) (GeeIterable* self);
 	GeeIterator* (*iterator) (GeeIterable* self);
 };
 
+GType gee_iterable_get_element_type (GeeIterable* self);
 GeeIterator* gee_iterable_iterator (GeeIterable* self);
 GType gee_iterable_get_type (void);
 
+
 G_END_DECLS
 
 #endif
