@@ -1,6 +1,6 @@
 /* readonlycollection.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,9 +22,27 @@
 
 #include <gee/readonlycollection.h>
 
+
+#define GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR (gee_read_only_collection_iterator_get_type ())
+#define GEE_READ_ONLY_COLLECTION_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, GeeReadOnlyCollectionIterator))
+#define GEE_READ_ONLY_COLLECTION_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, GeeReadOnlyCollectionIteratorClass))
+#define GEE_READ_ONLY_COLLECTION_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR))
+#define GEE_READ_ONLY_COLLECTION_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR))
+#define GEE_READ_ONLY_COLLECTION_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, GeeReadOnlyCollectionIteratorClass))
+
 typedef struct _GeeReadOnlyCollectionIterator GeeReadOnlyCollectionIterator;
 typedef struct _GeeReadOnlyCollectionIteratorClass GeeReadOnlyCollectionIteratorClass;
 typedef struct _GeeReadOnlyCollectionIteratorPrivate GeeReadOnlyCollectionIteratorPrivate;
+
+struct _GeeReadOnlyCollectionIterator {
+	GObject parent_instance;
+	GeeReadOnlyCollectionIteratorPrivate * priv;
+};
+struct _GeeReadOnlyCollectionIteratorClass {
+	GObjectClass parent_class;
+};
+
+
 struct _GeeReadOnlyCollectionPrivate {
 	GeeCollection* _collection;
 	GType g_type;
@@ -40,26 +58,12 @@ enum  {
 	GEE_READ_ONLY_COLLECTION_G_DUP_FUNC,
 	GEE_READ_ONLY_COLLECTION_G_DESTROY_FUNC
 };
+static GType gee_read_only_collection_real_get_element_type (GeeIterable* base);
 static GeeIterator* gee_read_only_collection_real_iterator (GeeIterable* base);
 static gboolean gee_read_only_collection_real_contains (GeeCollection* base, gconstpointer item);
 static gboolean gee_read_only_collection_real_add (GeeCollection* base, gconstpointer item);
 static gboolean gee_read_only_collection_real_remove (GeeCollection* base, gconstpointer item);
 static void gee_read_only_collection_real_clear (GeeCollection* base);
-
-#define GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR (gee_read_only_collection_iterator_get_type ())
-#define GEE_READ_ONLY_COLLECTION_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, GeeReadOnlyCollectionIterator))
-#define GEE_READ_ONLY_COLLECTION_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, GeeReadOnlyCollectionIteratorClass))
-#define GEE_READ_ONLY_COLLECTION_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR))
-#define GEE_READ_ONLY_COLLECTION_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR))
-#define GEE_READ_ONLY_COLLECTION_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, GeeReadOnlyCollectionIteratorClass))
-
-struct _GeeReadOnlyCollectionIterator {
-	GObject parent_instance;
-	GeeReadOnlyCollectionIteratorPrivate * priv;
-};
-struct _GeeReadOnlyCollectionIteratorClass {
-	GObjectClass parent_class;
-};
 struct _GeeReadOnlyCollectionIteratorPrivate {
 	GType g_type;
 	GBoxedCopyFunc g_dup_func;
@@ -84,6 +88,7 @@ static GeeCollectionIface* gee_read_only_collection_gee_collection_parent_iface
 static void gee_read_only_collection_dispose (GObject * obj);
 
 
+
 GeeReadOnlyCollection* gee_read_only_collection_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeCollection* collection) {
 	GeeReadOnlyCollection * self;
 	g_return_val_if_fail (collection == NULL || GEE_IS_COLLECTION (collection), NULL);
@@ -96,6 +101,13 @@ GeeReadOnlyCollection* gee_read_only_collection_new (GType g_type, GBoxedCopyFun
 }
 
 
+static GType gee_read_only_collection_real_get_element_type (GeeIterable* base) {
+	GeeReadOnlyCollection * self;
+	self = GEE_READ_ONLY_COLLECTION (base);
+	return self->priv->g_type;
+}
+
+
 static GeeIterator* gee_read_only_collection_real_iterator (GeeIterable* base) {
 	GeeReadOnlyCollection * self;
 	self = GEE_READ_ONLY_COLLECTION (base);
@@ -120,7 +132,6 @@ static gboolean gee_read_only_collection_real_add (GeeCollection* base, gconstpo
 	GeeReadOnlyCollection * self;
 	self = GEE_READ_ONLY_COLLECTION (base);
 	g_assert_not_reached ();
-	return FALSE;
 }
 
 
@@ -128,7 +139,6 @@ static gboolean gee_read_only_collection_real_remove (GeeCollection* base, gcons
 	GeeReadOnlyCollection * self;
 	self = GEE_READ_ONLY_COLLECTION (base);
 	g_assert_not_reached ();
-	return FALSE;
 }
 
 
@@ -298,6 +308,7 @@ static void gee_read_only_collection_class_init (GeeReadOnlyCollectionClass * kl
 
 static void gee_read_only_collection_gee_iterable_interface_init (GeeIterableIface * iface) {
 	gee_read_only_collection_gee_iterable_parent_iface = g_type_interface_peek_parent (iface);
+	iface->get_element_type = gee_read_only_collection_real_get_element_type;
 	iface->iterator = gee_read_only_collection_real_iterator;
 }
 
