@@ -1,6 +1,6 @@
 /* readonlyset.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,9 +22,27 @@
 
 #include <gee/readonlyset.h>
 
+
+#define GEE_READ_ONLY_SET_TYPE_ITERATOR (gee_read_only_set_iterator_get_type ())
+#define GEE_READ_ONLY_SET_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIterator))
+#define GEE_READ_ONLY_SET_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIteratorClass))
+#define GEE_READ_ONLY_SET_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR))
+#define GEE_READ_ONLY_SET_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_READ_ONLY_SET_TYPE_ITERATOR))
+#define GEE_READ_ONLY_SET_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIteratorClass))
+
 typedef struct _GeeReadOnlySetIterator GeeReadOnlySetIterator;
 typedef struct _GeeReadOnlySetIteratorClass GeeReadOnlySetIteratorClass;
 typedef struct _GeeReadOnlySetIteratorPrivate GeeReadOnlySetIteratorPrivate;
+
+struct _GeeReadOnlySetIterator {
+	GObject parent_instance;
+	GeeReadOnlySetIteratorPrivate * priv;
+};
+struct _GeeReadOnlySetIteratorClass {
+	GObjectClass parent_class;
+};
+
+
 struct _GeeReadOnlySetPrivate {
 	GeeSet* _set;
 	GType g_type;
@@ -40,26 +58,12 @@ enum  {
 	GEE_READ_ONLY_SET_G_DUP_FUNC,
 	GEE_READ_ONLY_SET_G_DESTROY_FUNC
 };
+static GType gee_read_only_set_real_get_element_type (GeeIterable* base);
 static GeeIterator* gee_read_only_set_real_iterator (GeeIterable* base);
 static gboolean gee_read_only_set_real_contains (GeeCollection* base, gconstpointer item);
 static gboolean gee_read_only_set_real_add (GeeCollection* base, gconstpointer item);
 static gboolean gee_read_only_set_real_remove (GeeCollection* base, gconstpointer item);
 static void gee_read_only_set_real_clear (GeeCollection* base);
-
-#define GEE_READ_ONLY_SET_TYPE_ITERATOR (gee_read_only_set_iterator_get_type ())
-#define GEE_READ_ONLY_SET_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIterator))
-#define GEE_READ_ONLY_SET_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIteratorClass))
-#define GEE_READ_ONLY_SET_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR))
-#define GEE_READ_ONLY_SET_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_READ_ONLY_SET_TYPE_ITERATOR))
-#define GEE_READ_ONLY_SET_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIteratorClass))
-
-struct _GeeReadOnlySetIterator {
-	GObject parent_instance;
-	GeeReadOnlySetIteratorPrivate * priv;
-};
-struct _GeeReadOnlySetIteratorClass {
-	GObjectClass parent_class;
-};
 struct _GeeReadOnlySetIteratorPrivate {
 	GType g_type;
 	GBoxedCopyFunc g_dup_func;
@@ -85,6 +89,7 @@ static GeeSetIface* gee_read_only_set_gee_set_parent_iface = NULL;
 static void gee_read_only_set_dispose (GObject * obj);
 
 
+
 GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set) {
 	GeeReadOnlySet * self;
 	g_return_val_if_fail (set == NULL || GEE_IS_SET (set), NULL);
@@ -97,6 +102,13 @@ GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func,
 }
 
 
+static GType gee_read_only_set_real_get_element_type (GeeIterable* base) {
+	GeeReadOnlySet * self;
+	self = GEE_READ_ONLY_SET (base);
+	return self->priv->g_type;
+}
+
+
 static GeeIterator* gee_read_only_set_real_iterator (GeeIterable* base) {
 	GeeReadOnlySet * self;
 	self = GEE_READ_ONLY_SET (base);
@@ -121,7 +133,6 @@ static gboolean gee_read_only_set_real_add (GeeCollection* base, gconstpointer i
 	GeeReadOnlySet * self;
 	self = GEE_READ_ONLY_SET (base);
 	g_assert_not_reached ();
-	return FALSE;
 }
 
 
@@ -129,7 +140,6 @@ static gboolean gee_read_only_set_real_remove (GeeCollection* base, gconstpointe
 	GeeReadOnlySet * self;
 	self = GEE_READ_ONLY_SET (base);
 	g_assert_not_reached ();
-	return FALSE;
 }
 
 
@@ -299,6 +309,7 @@ static void gee_read_only_set_class_init (GeeReadOnlySetClass * klass) {
 
 static void gee_read_only_set_gee_iterable_interface_init (GeeIterableIface * iface) {
 	gee_read_only_set_gee_iterable_parent_iface = g_type_interface_peek_parent (iface);
+	iface->get_element_type = gee_read_only_set_real_get_element_type;
 	iface->iterator = gee_read_only_set_real_iterator;
 }
 
