@@ -1,6 +1,6 @@
 /* valaccodecompiler.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,11 +27,16 @@
 #include <vala/valasourcefile.h>
 #include <glib/gstdio.h>
 
+
+
+
 enum  {
 	VALA_CCODE_COMPILER_DUMMY_PROPERTY
 };
 static gboolean vala_ccode_compiler_package_exists (const char* package_name);
 static gpointer vala_ccode_compiler_parent_class = NULL;
+static int _vala_strcmp0 (const char * str1, const char * str2);
+
 
 
 ValaCCodeCompiler* vala_ccode_compiler_new (void) {
@@ -74,7 +79,7 @@ static gboolean vala_ccode_compiler_package_exists (const char* package_name) {
 	}
 	__finally0:
 	;
-	(pc = (g_free (pc), NULL));
+	pc = (g_free (pc), NULL);
 }
 
 
@@ -90,16 +95,14 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	char* _tmp1;
 	char* pkgflags;
 	gint exit_status;
-	const char* _tmp6;
+	const char* _tmp8;
 	char* cmdline;
-	char* _tmp9;
-	char* _tmp8;
 	char* _tmp17;
 	char* _tmp16;
 	GeeCollection* source_files;
 	GeeCollection* c_source_files;
 	g_return_if_fail (VALA_IS_CCODE_COMPILER (self));
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
+	g_return_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context));
 	inner_error = NULL;
 	pc = g_strdup ("pkg-config --cflags");
 	if (!vala_code_context_get_compile_only (context)) {
@@ -121,7 +124,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		pkg_it = gee_iterable_iterator (GEE_ITERABLE (pkg_collection));
 		while (gee_iterator_next (pkg_it)) {
 			char* pkg;
-			pkg = gee_iterator_get (pkg_it);
+			pkg = ((char*) gee_iterator_get (pkg_it));
 			{
 				if (vala_ccode_compiler_package_exists (pkg)) {
 					char* _tmp4;
@@ -129,9 +132,9 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 					_tmp4 = NULL;
 					_tmp3 = NULL;
 					pc = (_tmp4 = g_strconcat (pc, (_tmp3 = (g_strconcat (" ", pkg, NULL))), NULL), (pc = (g_free (pc), NULL)), _tmp4);
-					(_tmp3 = (g_free (_tmp3), NULL));
+					_tmp3 = (g_free (_tmp3), NULL);
 				}
-				(pkg = (g_free (pkg), NULL));
+				pkg = (g_free (pkg), NULL);
 			}
 		}
 		(pkg_collection == NULL ? NULL : (pkg_collection = (g_object_unref (pkg_collection), NULL)));
@@ -140,7 +143,13 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	pkgflags = NULL;
 	exit_status = 0;
 	{
-		g_spawn_command_line_sync (pc, &pkgflags, NULL, &exit_status, &inner_error);
+		gboolean _tmp6;
+		char* _tmp5;
+		_tmp5 = NULL;
+		_tmp6 = g_spawn_command_line_sync (pc, &_tmp5, NULL, &exit_status, &inner_error);
+		(pkgflags = (g_free (pkgflags), NULL));
+		pkgflags = _tmp5;
+		_tmp6;
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_SPAWN_ERROR) {
 				goto __catch1_g_spawn_error;
@@ -149,12 +158,12 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			g_clear_error (&inner_error);
 		}
 		if (exit_status != 0) {
-			char* _tmp5;
-			_tmp5 = NULL;
-			vala_report_error (NULL, (_tmp5 = g_strdup_printf ("pkg-config exited with status %d", exit_status)));
-			(_tmp5 = (g_free (_tmp5), NULL));
-			(pc = (g_free (pc), NULL));
-			(pkgflags = (g_free (pkgflags), NULL));
+			char* _tmp7;
+			_tmp7 = NULL;
+			vala_report_error (NULL, (_tmp7 = g_strdup_printf ("pkg-config exited with status %d", exit_status)));
+			_tmp7 = (g_free (_tmp7), NULL);
+			pc = (g_free (pc), NULL);
+			pkgflags = (g_free (pkgflags), NULL);
 			return;
 		}
 	}
@@ -166,8 +175,8 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		inner_error = NULL;
 		{
 			vala_report_error (NULL, e->message);
-			(pc = (g_free (pc), NULL));
-			(pkgflags = (g_free (pkgflags), NULL));
+			pc = (g_free (pc), NULL);
+			pkgflags = (g_free (pkgflags), NULL);
 			return;
 		}
 	}
@@ -177,17 +186,13 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	if (cc_command == NULL) {
 		cc_command = "cc";
 	}
-	_tmp6 = NULL;
-	cmdline = (_tmp6 = cc_command, (_tmp6 == NULL ? NULL : g_strdup (_tmp6)));
-	if (vala_code_context_get_debug (context)) {
-		char* _tmp7;
-		_tmp7 = NULL;
-		cmdline = (_tmp7 = g_strconcat (cmdline, (" -g"), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp7);
-	}
-	_tmp9 = NULL;
 	_tmp8 = NULL;
-	cmdline = (_tmp9 = g_strconcat (cmdline, (_tmp8 = (g_strdup_printf (" -O%d", vala_code_context_get_optlevel (context)))), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp9);
-	(_tmp8 = (g_free (_tmp8), NULL));
+	cmdline = (_tmp8 = cc_command, (_tmp8 == NULL ? NULL : g_strdup (_tmp8)));
+	if (vala_code_context_get_debug (context)) {
+		char* _tmp9;
+		_tmp9 = NULL;
+		cmdline = (_tmp9 = g_strconcat (cmdline, (" -g"), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp9);
+	}
 	if (vala_code_context_get_compile_only (context)) {
 		char* _tmp10;
 		_tmp10 = NULL;
@@ -201,7 +206,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			char* _tmp13;
 			_tmp11 = NULL;
 			output = (_tmp11 = vala_code_context_get_output (context), (_tmp11 == NULL ? NULL : g_strdup (_tmp11)));
-			if (vala_code_context_get_directory (context) != NULL && g_utf8_collate (vala_code_context_get_directory (context), "") != 0) {
+			if (vala_code_context_get_directory (context) != NULL && _vala_strcmp0 (vala_code_context_get_directory (context), "") != 0) {
 				char* _tmp12;
 				_tmp12 = NULL;
 				output = (_tmp12 = g_strdup_printf ("%s/%s", vala_code_context_get_directory (context), vala_code_context_get_output (context)), (output = (g_free (output), NULL)), _tmp12);
@@ -210,15 +215,15 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			_tmp14 = NULL;
 			_tmp13 = NULL;
 			cmdline = (_tmp15 = g_strconcat (cmdline, (_tmp14 = (g_strconcat (" -o ", (_tmp13 = g_shell_quote (output)), NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp15);
-			(_tmp14 = (g_free (_tmp14), NULL));
-			(_tmp13 = (g_free (_tmp13), NULL));
-			(output = (g_free (output), NULL));
+			_tmp14 = (g_free (_tmp14), NULL);
+			_tmp13 = (g_free (_tmp13), NULL);
+			output = (g_free (output), NULL);
 		}
 	}
 	_tmp17 = NULL;
 	_tmp16 = NULL;
 	cmdline = (_tmp17 = g_strconcat (cmdline, (_tmp16 = (g_strconcat (" ", pkgflags, NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp17);
-	(_tmp16 = (g_free (_tmp16), NULL));
+	_tmp16 = (g_free (_tmp16), NULL);
 	if (cc_options != NULL) {
 		{
 			char** cc_option_collection;
@@ -237,14 +242,14 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 					_tmp19 = NULL;
 					_tmp18 = NULL;
 					cmdline = (_tmp19 = g_strconcat (cmdline, (_tmp18 = (g_strconcat (" ", cc_option, NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp19);
-					(_tmp18 = (g_free (_tmp18), NULL));
-					(cc_option = (g_free (cc_option), NULL));
+					_tmp18 = (g_free (_tmp18), NULL);
+					cc_option = (g_free (cc_option), NULL);
 				}
 			}
 		}
 	}
 	/* make sure include files can be found if -d is used */
-	if (vala_code_context_get_directory (context) != NULL && g_utf8_collate (vala_code_context_get_directory (context), "") != 0) {
+	if (vala_code_context_get_directory (context) != NULL && _vala_strcmp0 (vala_code_context_get_directory (context), "") != 0) {
 		char* _tmp23;
 		char* _tmp22;
 		char* _tmp21;
@@ -252,8 +257,8 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		_tmp22 = NULL;
 		_tmp21 = NULL;
 		cmdline = (_tmp23 = g_strconcat (cmdline, (_tmp22 = (g_strconcat (" -I", (_tmp21 = g_shell_quote (vala_code_context_get_directory (context))), NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp23);
-		(_tmp22 = (g_free (_tmp22), NULL));
-		(_tmp21 = (g_free (_tmp21), NULL));
+		_tmp22 = (g_free (_tmp22), NULL);
+		_tmp21 = (g_free (_tmp21), NULL);
 	}
 	/* we're only interested in non-pkg source files */
 	source_files = vala_code_context_get_source_files (context);
@@ -264,7 +269,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		file_it = gee_iterable_iterator (GEE_ITERABLE (file_collection));
 		while (gee_iterator_next (file_it)) {
 			ValaSourceFile* file;
-			file = gee_iterator_get (file_it);
+			file = ((ValaSourceFile*) gee_iterator_get (file_it));
 			{
 				if (!vala_source_file_get_pkg (file)) {
 					char* _tmp27;
@@ -276,9 +281,9 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 					_tmp25 = NULL;
 					_tmp24 = NULL;
 					cmdline = (_tmp27 = g_strconcat (cmdline, (_tmp26 = (g_strconcat (" ", (_tmp25 = g_shell_quote ((_tmp24 = vala_source_file_get_csource_filename (file)))), NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp27);
-					(_tmp26 = (g_free (_tmp26), NULL));
-					(_tmp25 = (g_free (_tmp25), NULL));
-					(_tmp24 = (g_free (_tmp24), NULL));
+					_tmp26 = (g_free (_tmp26), NULL);
+					_tmp25 = (g_free (_tmp25), NULL);
+					_tmp24 = (g_free (_tmp24), NULL);
 				}
 				(file == NULL ? NULL : (file = (g_object_unref (file), NULL)));
 			}
@@ -293,7 +298,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		file_it = gee_iterable_iterator (GEE_ITERABLE (file_collection));
 		while (gee_iterator_next (file_it)) {
 			char* file;
-			file = gee_iterator_get (file_it);
+			file = ((char*) gee_iterator_get (file_it));
 			{
 				char* _tmp30;
 				char* _tmp29;
@@ -302,9 +307,9 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 				_tmp29 = NULL;
 				_tmp28 = NULL;
 				cmdline = (_tmp30 = g_strconcat (cmdline, (_tmp29 = (g_strconcat (" ", (_tmp28 = g_shell_quote (file)), NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp30);
-				(_tmp29 = (g_free (_tmp29), NULL));
-				(_tmp28 = (g_free (_tmp28), NULL));
-				(file = (g_free (file), NULL));
+				_tmp29 = (g_free (_tmp29), NULL);
+				_tmp28 = (g_free (_tmp28), NULL);
+				file = (g_free (file), NULL);
 			}
 		}
 		(file_it == NULL ? NULL : (file_it = (g_object_unref (file_it), NULL)));
@@ -322,7 +327,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			char* _tmp31;
 			_tmp31 = NULL;
 			vala_report_error (NULL, (_tmp31 = g_strdup_printf ("cc exited with status %d", exit_status)));
-			(_tmp31 = (g_free (_tmp31), NULL));
+			_tmp31 = (g_free (_tmp31), NULL);
 		}
 	}
 	goto __finally2;
@@ -344,7 +349,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		file_it = gee_iterable_iterator (GEE_ITERABLE (file_collection));
 		while (gee_iterator_next (file_it)) {
 			ValaSourceFile* file;
-			file = gee_iterator_get (file_it);
+			file = ((ValaSourceFile*) gee_iterator_get (file_it));
 			{
 				/* remove generated C source and header files */
 				if (!vala_source_file_get_pkg (file)) {
@@ -352,13 +357,13 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 						char* _tmp32;
 						_tmp32 = NULL;
 						g_unlink ((_tmp32 = vala_source_file_get_csource_filename (file)));
-						(_tmp32 = (g_free (_tmp32), NULL));
+						_tmp32 = (g_free (_tmp32), NULL);
 					}
 					if (!vala_code_context_get_save_cheaders (context)) {
 						char* _tmp33;
 						_tmp33 = NULL;
 						g_unlink ((_tmp33 = vala_source_file_get_cheader_filename (file)));
-						(_tmp33 = (g_free (_tmp33), NULL));
+						_tmp33 = (g_free (_tmp33), NULL);
 					}
 				}
 				(file == NULL ? NULL : (file = (g_object_unref (file), NULL)));
@@ -366,9 +371,9 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		}
 		(file_it == NULL ? NULL : (file_it = (g_object_unref (file_it), NULL)));
 	}
-	(pc = (g_free (pc), NULL));
-	(pkgflags = (g_free (pkgflags), NULL));
-	(cmdline = (g_free (cmdline), NULL));
+	pc = (g_free (pc), NULL);
+	pkgflags = (g_free (pkgflags), NULL);
+	cmdline = (g_free (cmdline), NULL);
 	(source_files == NULL ? NULL : (source_files = (g_object_unref (source_files), NULL)));
 	(c_source_files == NULL ? NULL : (c_source_files = (g_object_unref (c_source_files), NULL)));
 }
@@ -393,5 +398,16 @@ GType vala_ccode_compiler_get_type (void) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
