@@ -1,6 +1,6 @@
 /* valaccodeelementaccessbinding.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,10 +29,13 @@
 #include <vala/valatypesymbol.h>
 #include <vala/valacodenode.h>
 #include <ccode/valaccodeexpression.h>
-#include <ccode/valaccodefunctioncall.h>
-#include <ccode/valaccodeidentifier.h>
+#include <vala/valaarraylengthfield.h>
+#include <vala/valaintegerliteral.h>
+#include <vala/valamemberaccess.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ccode/valaccodefunctioncall.h>
+#include <ccode/valaccodeidentifier.h>
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
 #include <vala/valamethod.h>
@@ -47,6 +50,9 @@
 #include <gobject/valaccodebinding.h>
 #include <gobject/valaccodegenerator.h>
 
+
+
+
 struct _ValaCCodeElementAccessBindingPrivate {
 	ValaElementAccess* _element_access;
 };
@@ -60,6 +66,7 @@ static gpointer vala_ccode_element_access_binding_parent_class = NULL;
 static void vala_ccode_element_access_binding_dispose (GObject * obj);
 
 
+
 ValaCCodeElementAccessBinding* vala_ccode_element_access_binding_new (ValaCodeGenerator* codegen, ValaElementAccess* element_access) {
 	ValaCCodeElementAccessBinding * self;
 	g_return_val_if_fail (codegen == NULL || VALA_IS_CODE_GENERATOR (codegen), NULL);
@@ -87,7 +94,7 @@ static void vala_ccode_element_access_binding_real_emit (ValaCodeBinding* base)
 	ValaCCodeExpression* cindex;
 	self = VALA_CCODE_ELEMENT_ACCESS_BINDING (base);
 	_tmp0 = NULL;
-	expr = (_tmp0 = vala_ccode_element_access_binding_get_element_access (self), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	expr = (_tmp0 = self->priv->_element_access, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 	indices = vala_element_access_get_indices (expr);
 	rank = gee_collection_get_size (GEE_COLLECTION (indices));
 	_tmp1 = NULL;
@@ -97,104 +104,128 @@ static void vala_ccode_element_access_binding_real_emit (ValaCodeBinding* base)
 	_tmp4 = NULL;
 	_tmp3 = NULL;
 	_tmp5 = NULL;
-	cindex = (_tmp5 = (_tmp4 = VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE ((_tmp3 = gee_list_get (((GeeList*) indices), 0))))), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4))), (_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL))), _tmp5);
-	if (container_type == vala_data_type_get_data_type (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->string_type)) {
-		ValaCCodeIdentifier* _tmp6;
-		ValaCCodeFunctionCall* _tmp7;
-		ValaCCodeFunctionCall* coffsetcall;
-		ValaCCodeIdentifier* _tmp8;
-		ValaCCodeFunctionCall* _tmp9;
-		ValaCCodeFunctionCall* ccall;
-		/* access to unichar in a string*/
+	cindex = (_tmp5 = (_tmp4 = VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE ((_tmp3 = ((ValaExpression*) gee_list_get (((GeeList*) indices), 0)))))), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4))), (_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL))), _tmp5);
+	if (VALA_IS_ARRAY_LENGTH_FIELD (vala_expression_get_symbol_reference (vala_element_access_get_container (expr)))) {
+		ValaExpression* _tmp6;
+		ValaIntegerLiteral* lit;
+		ValaMemberAccess* _tmp8;
+		ValaExpression* _tmp7;
+		ValaMemberAccess* memberaccess;
+		/* Figure if cindex is a constant expression and calculate dim...*/
 		_tmp6 = NULL;
-		_tmp7 = NULL;
-		coffsetcall = (_tmp7 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp6 = vala_ccode_identifier_new ("g_utf8_offset_to_pointer")))), (_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL))), _tmp7);
-		vala_ccode_function_call_add_argument (coffsetcall, ccontainer);
-		vala_ccode_function_call_add_argument (coffsetcall, cindex);
+		lit = (_tmp6 = ((ValaExpression*) gee_list_get (((GeeList*) indices), 0)), (VALA_IS_INTEGER_LITERAL (_tmp6) ? ((ValaIntegerLiteral*) _tmp6) : NULL));
 		_tmp8 = NULL;
-		_tmp9 = NULL;
-		ccall = (_tmp9 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp8 = vala_ccode_identifier_new ("g_utf8_get_char")))), (_tmp8 == NULL ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL))), _tmp9);
-		vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (coffsetcall));
-		vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), VALA_CCODE_EXPRESSION (ccall));
-		(coffsetcall == NULL ? NULL : (coffsetcall = (g_object_unref (coffsetcall), NULL)));
-		(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
+		_tmp7 = NULL;
+		memberaccess = (_tmp8 = (_tmp7 = vala_element_access_get_container (expr), (VALA_IS_MEMBER_ACCESS (_tmp7) ? ((ValaMemberAccess*) _tmp7) : NULL)), (_tmp8 == NULL ? NULL : g_object_ref (_tmp8)));
+		if (lit != NULL && memberaccess != NULL) {
+			gint dim;
+			ValaCCodeExpression* _tmp9;
+			dim = atoi (vala_integer_literal_get_value (lit));
+			_tmp9 = NULL;
+			vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), (_tmp9 = vala_ccode_generator_get_array_length_cexpression (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_member_access_get_inner (memberaccess), dim + 1)));
+			(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
+		}
+		(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
+		(memberaccess == NULL ? NULL : (memberaccess = (g_object_unref (memberaccess), NULL)));
 	} else {
-		if (container_type != NULL && vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type != NULL && vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type != NULL && (vala_typesymbol_is_subtype_of (container_type, vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type) || vala_typesymbol_is_subtype_of (container_type, vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type))) {
-			ValaMethod* get_method;
-			GeeCollection* get_params;
-			GeeIterator* get_params_it;
-			ValaFormalParameter* get_param;
+		if (container_type == vala_data_type_get_data_type (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->string_type)) {
+			ValaCCodeIdentifier* _tmp10;
+			ValaCCodeFunctionCall* _tmp11;
+			ValaCCodeFunctionCall* coffsetcall;
 			ValaCCodeIdentifier* _tmp12;
-			char* _tmp11;
 			ValaCCodeFunctionCall* _tmp13;
-			ValaCCodeFunctionCall* get_ccall;
-			ValaCCodeCastExpression* _tmp16;
-			char* _tmp15;
-			char* _tmp14;
-			ValaCCodeExpression* _tmp17;
-			get_method = VALA_METHOD (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (container_type)), "get"));
-			get_params = vala_method_get_parameters (get_method);
-			get_params_it = gee_iterable_iterator (GEE_ITERABLE (get_params));
-			gee_iterator_next (get_params_it);
-			get_param = gee_iterator_get (get_params_it);
-			if (vala_data_type_get_type_parameter (vala_formal_parameter_get_type_reference (get_param)) != NULL) {
-				ValaDataType* index_type;
-				ValaCCodeExpression* _tmp10;
-				index_type = vala_semantic_analyzer_get_actual_type (vala_expression_get_static_type (vala_element_access_get_container (expr)), VALA_SYMBOL (get_method), vala_formal_parameter_get_type_reference (get_param), VALA_CODE_NODE (expr));
-				_tmp10 = NULL;
-				cindex = (_tmp10 = vala_ccode_generator_convert_to_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), cindex, index_type), (cindex == NULL ? NULL : (cindex = (g_object_unref (cindex), NULL))), _tmp10);
-				(index_type == NULL ? NULL : (index_type = (g_object_unref (index_type), NULL)));
-			}
-			_tmp12 = NULL;
+			ValaCCodeFunctionCall* ccall;
+			/* access to unichar in a string*/
+			_tmp10 = NULL;
 			_tmp11 = NULL;
+			coffsetcall = (_tmp11 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp10 = vala_ccode_identifier_new ("g_utf8_offset_to_pointer")))), (_tmp10 == NULL ? NULL : (_tmp10 = (g_object_unref (_tmp10), NULL))), _tmp11);
+			vala_ccode_function_call_add_argument (coffsetcall, ccontainer);
+			vala_ccode_function_call_add_argument (coffsetcall, cindex);
+			_tmp12 = NULL;
 			_tmp13 = NULL;
-			get_ccall = (_tmp13 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp12 = vala_ccode_identifier_new ((_tmp11 = vala_method_get_cname (get_method)))))), (_tmp12 == NULL ? NULL : (_tmp12 = (g_object_unref (_tmp12), NULL))), (_tmp11 = (g_free (_tmp11), NULL)), _tmp13);
-			_tmp16 = NULL;
-			_tmp15 = NULL;
-			_tmp14 = NULL;
-			vala_ccode_function_call_add_argument (get_ccall, VALA_CCODE_EXPRESSION ((_tmp16 = vala_ccode_cast_expression_new (ccontainer, (_tmp15 = g_strconcat ((_tmp14 = vala_typesymbol_get_cname (container_type, FALSE)), "*", NULL))))));
-			(_tmp16 == NULL ? NULL : (_tmp16 = (g_object_unref (_tmp16), NULL)));
-			(_tmp15 = (g_free (_tmp15), NULL));
-			(_tmp14 = (g_free (_tmp14), NULL));
-			vala_ccode_function_call_add_argument (get_ccall, cindex);
-			_tmp17 = NULL;
-			vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), (_tmp17 = vala_ccode_generator_convert_from_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_CCODE_EXPRESSION (get_ccall), vala_expression_get_static_type (VALA_EXPRESSION (expr)))));
-			(_tmp17 == NULL ? NULL : (_tmp17 = (g_object_unref (_tmp17), NULL)));
-			(get_method == NULL ? NULL : (get_method = (g_object_unref (get_method), NULL)));
-			(get_params == NULL ? NULL : (get_params = (g_object_unref (get_params), NULL)));
-			(get_params_it == NULL ? NULL : (get_params_it = (g_object_unref (get_params_it), NULL)));
-			(get_param == NULL ? NULL : (get_param = (g_object_unref (get_param), NULL)));
-			(get_ccall == NULL ? NULL : (get_ccall = (g_object_unref (get_ccall), NULL)));
+			ccall = (_tmp13 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp12 = vala_ccode_identifier_new ("g_utf8_get_char")))), (_tmp12 == NULL ? NULL : (_tmp12 = (g_object_unref (_tmp12), NULL))), _tmp13);
+			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (coffsetcall));
+			vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), VALA_CCODE_EXPRESSION (ccall));
+			(coffsetcall == NULL ? NULL : (coffsetcall = (g_object_unref (coffsetcall), NULL)));
+			(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
 		} else {
-			ValaCCodeElementAccess* _tmp24;
-			{
-				gint i;
-				i = 0;
-				for (i = 1; i < rank; i++) {
-					ValaCCodeExpression* _tmp19;
-					ValaCCodeParenthesizedExpression* _tmp18;
-					ValaCCodeBinaryExpression* _tmp20;
-					ValaCCodeBinaryExpression* cmul;
-					ValaCCodeExpression* _tmp23;
-					ValaCCodeParenthesizedExpression* _tmp22;
-					ValaExpression* _tmp21;
-					/* access to element in an array*/
-					_tmp19 = NULL;
-					_tmp18 = NULL;
-					_tmp20 = NULL;
-					cmul = (_tmp20 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_MUL, VALA_CCODE_EXPRESSION ((_tmp18 = vala_ccode_parenthesized_expression_new (cindex))), (_tmp19 = vala_ccode_generator_get_array_length_cexpression (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_element_access_get_container (expr), i + 1))), (_tmp19 == NULL ? NULL : (_tmp19 = (g_object_unref (_tmp19), NULL))), (_tmp18 == NULL ? NULL : (_tmp18 = (g_object_unref (_tmp18), NULL))), _tmp20);
-					_tmp23 = NULL;
-					_tmp22 = NULL;
-					_tmp21 = NULL;
-					cindex = (_tmp23 = VALA_CCODE_EXPRESSION (vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_PLUS, VALA_CCODE_EXPRESSION (cmul), VALA_CCODE_EXPRESSION ((_tmp22 = vala_ccode_parenthesized_expression_new (VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE ((_tmp21 = gee_list_get (((GeeList*) indices), i)))))))))), (cindex == NULL ? NULL : (cindex = (g_object_unref (cindex), NULL))), _tmp23);
-					(_tmp22 == NULL ? NULL : (_tmp22 = (g_object_unref (_tmp22), NULL)));
-					(_tmp21 == NULL ? NULL : (_tmp21 = (g_object_unref (_tmp21), NULL)));
-					(cmul == NULL ? NULL : (cmul = (g_object_unref (cmul), NULL)));
+			if (container_type != NULL && vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type != NULL && vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type != NULL && (vala_typesymbol_is_subtype_of (container_type, vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type) || vala_typesymbol_is_subtype_of (container_type, vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type))) {
+				ValaMethod* get_method;
+				GeeCollection* get_params;
+				GeeIterator* get_params_it;
+				ValaFormalParameter* get_param;
+				ValaCCodeIdentifier* _tmp16;
+				char* _tmp15;
+				ValaCCodeFunctionCall* _tmp17;
+				ValaCCodeFunctionCall* get_ccall;
+				ValaCCodeCastExpression* _tmp20;
+				char* _tmp19;
+				char* _tmp18;
+				ValaCCodeExpression* _tmp21;
+				get_method = VALA_METHOD (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (container_type)), "get"));
+				get_params = vala_method_get_parameters (get_method);
+				get_params_it = gee_iterable_iterator (GEE_ITERABLE (get_params));
+				gee_iterator_next (get_params_it);
+				get_param = ((ValaFormalParameter*) gee_iterator_get (get_params_it));
+				if (vala_data_type_get_type_parameter (vala_formal_parameter_get_type_reference (get_param)) != NULL) {
+					ValaDataType* index_type;
+					ValaCCodeExpression* _tmp14;
+					index_type = vala_semantic_analyzer_get_actual_type (vala_expression_get_static_type (vala_element_access_get_container (expr)), VALA_SYMBOL (get_method), vala_formal_parameter_get_type_reference (get_param), VALA_CODE_NODE (expr));
+					_tmp14 = NULL;
+					cindex = (_tmp14 = vala_ccode_generator_convert_to_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), cindex, index_type), (cindex == NULL ? NULL : (cindex = (g_object_unref (cindex), NULL))), _tmp14);
+					(index_type == NULL ? NULL : (index_type = (g_object_unref (index_type), NULL)));
 				}
+				_tmp16 = NULL;
+				_tmp15 = NULL;
+				_tmp17 = NULL;
+				get_ccall = (_tmp17 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp16 = vala_ccode_identifier_new ((_tmp15 = vala_method_get_cname (get_method)))))), (_tmp16 == NULL ? NULL : (_tmp16 = (g_object_unref (_tmp16), NULL))), (_tmp15 = (g_free (_tmp15), NULL)), _tmp17);
+				_tmp20 = NULL;
+				_tmp19 = NULL;
+				_tmp18 = NULL;
+				vala_ccode_function_call_add_argument (get_ccall, VALA_CCODE_EXPRESSION ((_tmp20 = vala_ccode_cast_expression_new (ccontainer, (_tmp19 = g_strconcat ((_tmp18 = vala_typesymbol_get_cname (container_type, FALSE)), "*", NULL))))));
+				(_tmp20 == NULL ? NULL : (_tmp20 = (g_object_unref (_tmp20), NULL)));
+				_tmp19 = (g_free (_tmp19), NULL);
+				_tmp18 = (g_free (_tmp18), NULL);
+				vala_ccode_function_call_add_argument (get_ccall, cindex);
+				_tmp21 = NULL;
+				vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), (_tmp21 = vala_ccode_generator_convert_from_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_CCODE_EXPRESSION (get_ccall), vala_expression_get_static_type (VALA_EXPRESSION (expr)))));
+				(_tmp21 == NULL ? NULL : (_tmp21 = (g_object_unref (_tmp21), NULL)));
+				(get_method == NULL ? NULL : (get_method = (g_object_unref (get_method), NULL)));
+				(get_params == NULL ? NULL : (get_params = (g_object_unref (get_params), NULL)));
+				(get_params_it == NULL ? NULL : (get_params_it = (g_object_unref (get_params_it), NULL)));
+				(get_param == NULL ? NULL : (get_param = (g_object_unref (get_param), NULL)));
+				(get_ccall == NULL ? NULL : (get_ccall = (g_object_unref (get_ccall), NULL)));
+			} else {
+				ValaCCodeElementAccess* _tmp28;
+				{
+					gint i;
+					i = 0;
+					for (i = 1; i < rank; i++) {
+						ValaCCodeExpression* _tmp23;
+						ValaCCodeParenthesizedExpression* _tmp22;
+						ValaCCodeBinaryExpression* _tmp24;
+						ValaCCodeBinaryExpression* cmul;
+						ValaCCodeExpression* _tmp27;
+						ValaCCodeParenthesizedExpression* _tmp26;
+						ValaExpression* _tmp25;
+						/* access to element in an array*/
+						_tmp23 = NULL;
+						_tmp22 = NULL;
+						_tmp24 = NULL;
+						cmul = (_tmp24 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_MUL, VALA_CCODE_EXPRESSION ((_tmp22 = vala_ccode_parenthesized_expression_new (cindex))), (_tmp23 = vala_ccode_generator_get_array_length_cexpression (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_element_access_get_container (expr), i + 1))), (_tmp23 == NULL ? NULL : (_tmp23 = (g_object_unref (_tmp23), NULL))), (_tmp22 == NULL ? NULL : (_tmp22 = (g_object_unref (_tmp22), NULL))), _tmp24);
+						_tmp27 = NULL;
+						_tmp26 = NULL;
+						_tmp25 = NULL;
+						cindex = (_tmp27 = VALA_CCODE_EXPRESSION (vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_PLUS, VALA_CCODE_EXPRESSION (cmul), VALA_CCODE_EXPRESSION ((_tmp26 = vala_ccode_parenthesized_expression_new (VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE ((_tmp25 = ((ValaExpression*) gee_list_get (((GeeList*) indices), i))))))))))), (cindex == NULL ? NULL : (cindex = (g_object_unref (cindex), NULL))), _tmp27);
+						(_tmp26 == NULL ? NULL : (_tmp26 = (g_object_unref (_tmp26), NULL)));
+						(_tmp25 == NULL ? NULL : (_tmp25 = (g_object_unref (_tmp25), NULL)));
+						(cmul == NULL ? NULL : (cmul = (g_object_unref (cmul), NULL)));
+					}
+				}
+				_tmp28 = NULL;
+				vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), VALA_CCODE_EXPRESSION ((_tmp28 = vala_ccode_element_access_new (ccontainer, cindex))));
+				(_tmp28 == NULL ? NULL : (_tmp28 = (g_object_unref (_tmp28), NULL)));
 			}
-			_tmp24 = NULL;
-			vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), VALA_CCODE_EXPRESSION ((_tmp24 = vala_ccode_element_access_new (ccontainer, cindex))));
-			(_tmp24 == NULL ? NULL : (_tmp24 = (g_object_unref (_tmp24), NULL)));
 		}
 	}
 	vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (vala_ccode_expression_binding_get_codenode (VALA_CCODE_EXPRESSION_BINDING (self))));
