@@ -78,7 +78,6 @@
 #include <vala/valarealliteral.h>
 #include <vala/valastringliteral.h>
 #include <vala/valanullliteral.h>
-#include <vala/valaliteralexpression.h>
 #include <vala/valaparenthesizedexpression.h>
 #include <vala/valaelementaccess.h>
 #include <vala/valabaseaccess.h>
@@ -192,11 +191,13 @@ ValaCCodeFunctionCall* vala_ccode_generator_get_property_set_call (ValaCCodeGene
 gboolean vala_ccode_generator_is_address_of_possible (ValaCCodeGenerator* self, ValaExpression* e);
 ValaCCodeExpression* vala_ccode_generator_get_address_of_expression (ValaCCodeGenerator* self, ValaExpression* e, ValaCCodeExpression* ce);
 gboolean vala_ccode_generator_add_wrapper (ValaCCodeGenerator* self, const char* wrapper_name);
+ValaDataType* vala_ccode_generator_get_data_type_for_symbol (ValaTypesymbol* sym);
 ValaCCodeIdentifier* vala_ccode_generator_get_value_setter_function (ValaCCodeGenerator* self, ValaDataType* type_reference);
 gint vala_ccode_generator_get_param_pos (ValaCCodeGenerator* self, double param_pos, gboolean ellipsis);
 char* vala_ccode_generator_get_signal_marshaller_function (ValaCCodeGenerator* self, ValaSignal* sig, const char* prefix);
 GType vala_ccode_generator_get_type (void);
 
+
 G_END_DECLS
 
 #endif
