@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #ifndef __GOBJECT_VALACCODEGENERATORCLASS_H__
@@ -32,6 +32,7 @@ G_BEGIN_DECLS
 
 
 
+
 G_END_DECLS
 
 #endif
