@@ -29,6 +29,9 @@
 #include <ccode/valaccodeexpressionstatement.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaInterfaceRegisterFunctionPrivate {
 	ValaInterface* _interface_reference;
 };
@@ -50,6 +53,7 @@ static gpointer vala_interface_register_function_parent_class = NULL;
 static void vala_interface_register_function_dispose (GObject * obj);
 
 
+
 ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterface* iface) {
 	ValaInterfaceRegisterFunction * self;
 	g_return_val_if_fail (iface == NULL || VALA_IS_INTERFACE (iface), NULL);
@@ -64,14 +68,14 @@ static ValaTypesymbol* vala_interface_register_function_real_get_type_declaratio
 	ValaInterface* _tmp0;
 	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
-	return VALA_TYPESYMBOL ((_tmp0 = vala_interface_register_function_get_interface_reference (self), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))));
+	return VALA_TYPESYMBOL ((_tmp0 = self->priv->_interface_reference, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))));
 }
 
 
 static char* vala_interface_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
 	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
-	return vala_interface_get_type_cname (vala_interface_register_function_get_interface_reference (self));
+	return vala_interface_get_type_cname (self->priv->_interface_reference);
 }
 
 
@@ -82,7 +86,7 @@ static char* vala_interface_register_function_real_get_base_init_func_name (Vala
 	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%s_base_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_interface_register_function_get_interface_reference (self)), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("%s_base_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_interface_reference), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -117,7 +121,7 @@ static char* vala_interface_register_function_real_get_parent_type_name (ValaTyp
 static ValaSymbolAccessibility vala_interface_register_function_real_get_accessibility (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
 	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
-	return vala_symbol_get_access (VALA_SYMBOL (vala_interface_register_function_get_interface_reference (self)));
+	return vala_symbol_get_access (VALA_SYMBOL (self->priv->_interface_reference));
 }
 
 
@@ -129,7 +133,7 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 	{
 		GeeCollection* prereq_ref_collection;
 		GeeIterator* prereq_ref_it;
-		prereq_ref_collection = vala_interface_get_prerequisites (vala_interface_register_function_get_interface_reference (self));
+		prereq_ref_collection = vala_interface_get_prerequisites (self->priv->_interface_reference);
 		prereq_ref_it = gee_iterable_iterator (GEE_ITERABLE (prereq_ref_collection));
 		while (gee_iterator_next (prereq_ref_it)) {
 			ValaDataType* prereq_ref;
@@ -155,7 +159,7 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 				_tmp5 = NULL;
 				_tmp4 = NULL;
 				_tmp3 = NULL;
-				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((_tmp5 = vala_ccode_identifier_new ((_tmp4 = g_strdup_printf ("%s_type_id", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_interface_register_function_get_interface_reference (self)), NULL))))))));
+				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((_tmp5 = vala_ccode_identifier_new ((_tmp4 = g_strdup_printf ("%s_type_id", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_interface_reference), NULL))))))));
 				(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
 				_tmp4 = (g_free (_tmp4), NULL);
 				_tmp3 = (g_free (_tmp3), NULL);
