@@ -21,8 +21,11 @@
  */
 
 #include <vala/valaarraylengthfield.h>
-#include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
+#include <vala/valacodenode.h>
+
+
+
 
 enum  {
 	VALA_ARRAY_LENGTH_FIELD_DUMMY_PROPERTY
@@ -30,6 +33,7 @@ enum  {
 static gpointer vala_array_length_field_parent_class = NULL;
 
 
+
 /**
  * Creates a new array length field.
  *
