@@ -1,6 +1,6 @@
 /* valaarrayresizemethod.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,15 +21,20 @@
  */
 
 #include <vala/valaarrayresizemethod.h>
-#include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
+#include <vala/valacodenode.h>
+
+
+
 
 enum  {
 	VALA_ARRAY_RESIZE_METHOD_DUMMY_PROPERTY
 };
+static GObject * vala_array_resize_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_array_resize_method_parent_class = NULL;
 
 
+
 /**
  * Creates a new array resize method.
  *
@@ -45,8 +50,25 @@ ValaArrayResizeMethod* vala_array_resize_method_new (ValaSourceReference* source
 }
 
 
+static GObject * vala_array_resize_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
+	GObject * obj;
+	ValaArrayResizeMethodClass * klass;
+	GObjectClass * parent_class;
+	ValaArrayResizeMethod * self;
+	klass = VALA_ARRAY_RESIZE_METHOD_CLASS (g_type_class_peek (VALA_TYPE_ARRAY_RESIZE_METHOD));
+	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
+	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
+	self = VALA_ARRAY_RESIZE_METHOD (obj);
+	{
+		vala_method_set_cinstance_parameter_position (VALA_METHOD (self), 0.1);
+	}
+	return obj;
+}
+
+
 static void vala_array_resize_method_class_init (ValaArrayResizeMethodClass * klass) {
 	vala_array_resize_method_parent_class = g_type_class_peek_parent (klass);
+	G_OBJECT_CLASS (klass)->constructor = vala_array_resize_method_constructor;
 }
 
 
