@@ -24,6 +24,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaAssignmentPrivate {
 	ValaAssignmentOperator _operator;
 	ValaExpression* _left;
@@ -44,6 +47,7 @@ static gpointer vala_assignment_parent_class = NULL;
 static void vala_assignment_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new assignment.
  *
@@ -62,8 +66,14 @@ ValaAssignment* vala_assignment_new (ValaExpression* left, ValaExpression* right
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	(__params_it->name = "left", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, left), __params_it++);
-	(__params_it->name = "right", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, right), __params_it++);
+	__params_it->name = "left";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, left);
+	__params_it++;
+	__params_it->name = "right";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, right);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_ASSIGNMENT, __params_it - __params, __params);
 	vala_assignment_set_operator (self, operator);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -168,7 +178,7 @@ static void vala_assignment_get_property (GObject * object, guint property_id, G
 		g_value_set_object (value, vala_assignment_get_left (self));
 		break;
 		case VALA_ASSIGNMENT_OPERATOR:
-		g_value_set_int (value, vala_assignment_get_operator (self));
+		g_value_set_enum (value, vala_assignment_get_operator (self));
 		break;
 		case VALA_ASSIGNMENT_RIGHT:
 		g_value_set_object (value, vala_assignment_get_right (self));
@@ -188,7 +198,7 @@ static void vala_assignment_set_property (GObject * object, guint property_id, c
 		vala_assignment_set_left (self, g_value_get_object (value));
 		break;
 		case VALA_ASSIGNMENT_OPERATOR:
-		vala_assignment_set_operator (self, g_value_get_int (value));
+		vala_assignment_set_operator (self, g_value_get_enum (value));
 		break;
 		case VALA_ASSIGNMENT_RIGHT:
 		vala_assignment_set_right (self, g_value_get_object (value));
@@ -211,7 +221,7 @@ static void vala_assignment_class_init (ValaAssignmentClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_assignment_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_assignment_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ASSIGNMENT_LEFT, g_param_spec_object ("left", "left", "left", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ASSIGNMENT_OPERATOR, g_param_spec_int ("operator", "operator", "operator", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ASSIGNMENT_OPERATOR, g_param_spec_enum ("operator", "operator", "operator", VALA_TYPE_ASSIGNMENT_OPERATOR, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ASSIGNMENT_RIGHT, g_param_spec_object ("right", "right", "right", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
@@ -241,4 +251,15 @@ GType vala_assignment_get_type (void) {
 
 
 
+GType vala_assignment_operator_get_type (void) {
+	static GType vala_assignment_operator_type_id = 0;
+	if (G_UNLIKELY (vala_assignment_operator_type_id == 0)) {
+		static const GEnumValue values[] = {{VALA_ASSIGNMENT_OPERATOR_SIMPLE, "VALA_ASSIGNMENT_OPERATOR_SIMPLE", "simple"}, {VALA_ASSIGNMENT_OPERATOR_BITWISE_OR, "VALA_ASSIGNMENT_OPERATOR_BITWISE_OR", "bitwise-or"}, {VALA_ASSIGNMENT_OPERATOR_BITWISE_AND, "VALA_ASSIGNMENT_OPERATOR_BITWISE_AND", "bitwise-and"}, {VALA_ASSIGNMENT_OPERATOR_BITWISE_XOR, "VALA_ASSIGNMENT_OPERATOR_BITWISE_XOR", "bitwise-xor"}, {VALA_ASSIGNMENT_OPERATOR_ADD, "VALA_ASSIGNMENT_OPERATOR_ADD", "add"}, {VALA_ASSIGNMENT_OPERATOR_SUB, "VALA_ASSIGNMENT_OPERATOR_SUB", "sub"}, {VALA_ASSIGNMENT_OPERATOR_MUL, "VALA_ASSIGNMENT_OPERATOR_MUL", "mul"}, {VALA_ASSIGNMENT_OPERATOR_DIV, "VALA_ASSIGNMENT_OPERATOR_DIV", "div"}, {VALA_ASSIGNMENT_OPERATOR_PERCENT, "VALA_ASSIGNMENT_OPERATOR_PERCENT", "percent"}, {VALA_ASSIGNMENT_OPERATOR_SHIFT_LEFT, "VALA_ASSIGNMENT_OPERATOR_SHIFT_LEFT", "shift-left"}, {VALA_ASSIGNMENT_OPERATOR_SHIFT_RIGHT, "VALA_ASSIGNMENT_OPERATOR_SHIFT_RIGHT", "shift-right"}, {0, NULL, NULL}};
+		vala_assignment_operator_type_id = g_enum_register_static ("ValaAssignmentOperator", values);
+	}
+	return vala_assignment_operator_type_id;
+}
+
+
+
 
