@@ -40,17 +40,19 @@ G_BEGIN_DECLS
 
 typedef struct _ValaAssignmentPrivate ValaAssignmentPrivate;
 
+#define VALA_TYPE_ASSIGNMENT_OPERATOR (vala_assignment_operator_get_type ())
+
 /**
  * Represents an assignment expression in the source code.
  *
  * Supports =, |=, &=, ^=, +=, -=, *=, /=, %=, <<=, >>=.
  */
 struct _ValaAssignment {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaAssignmentPrivate * priv;
 };
 struct _ValaAssignmentClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 typedef enum  {
 	VALA_ASSIGNMENT_OPERATOR_SIMPLE,
@@ -66,6 +68,7 @@ typedef enum  {
 	VALA_ASSIGNMENT_OPERATOR_SHIFT_RIGHT
 } ValaAssignmentOperator;
 
+
 ValaAssignment* vala_assignment_new (ValaExpression* left, ValaExpression* right, ValaAssignmentOperator operator, ValaSourceReference* source_reference);
 ValaExpression* vala_assignment_get_left (ValaAssignment* self);
 void vala_assignment_set_left (ValaAssignment* self, ValaExpression* value);
@@ -74,6 +77,8 @@ void vala_assignment_set_operator (ValaAssignment* self, ValaAssignmentOperator
 ValaExpression* vala_assignment_get_right (ValaAssignment* self);
 void vala_assignment_set_right (ValaAssignment* self, ValaExpression* value);
 GType vala_assignment_get_type (void);
+GType vala_assignment_operator_get_type (void);
+
 
 G_END_DECLS
 
