@@ -1,11 +1,11 @@
 /* valabooleanliteral.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALABOOLEANLITERAL_H__
-#define __VALABOOLEANLITERAL_H__
+#ifndef __VALA_VALABOOLEANLITERAL_H__
+#define __VALA_VALABOOLEANLITERAL_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -46,17 +46,18 @@ typedef struct _ValaBooleanLiteralPrivate ValaBooleanLiteralPrivate;
  * Represents a literal boolean, i.e. true or false.
  */
 struct _ValaBooleanLiteral {
-	ValaLiteral parent;
+	ValaLiteral parent_instance;
 	ValaBooleanLiteralPrivate * priv;
 };
 struct _ValaBooleanLiteralClass {
-	ValaLiteralClass parent;
+	ValaLiteralClass parent_class;
 };
 
 ValaBooleanLiteral* vala_boolean_literal_new (gboolean b, ValaSourceReference* source);
 gboolean vala_boolean_literal_get_value (ValaBooleanLiteral* self);
 void vala_boolean_literal_set_value (ValaBooleanLiteral* self, gboolean value);
-GType vala_boolean_literal_get_type ();
+GType vala_boolean_literal_get_type (void);
+
 
 G_END_DECLS
 
