@@ -1,6 +1,6 @@
 /* valacharacterliteral.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #ifndef __VALA_VALACHARACTERLITERAL_H__
@@ -60,6 +60,7 @@ char* vala_character_literal_get_value (ValaCharacterLiteral* self);
 void vala_character_literal_set_value (ValaCharacterLiteral* self, const char* value);
 GType vala_character_literal_get_type (void);
 
+
 G_END_DECLS
 
 #endif
