@@ -57,6 +57,8 @@ struct _ValaCodeGeneratorClass {
 	ValaCodeBinding* (*create_interface_binding) (ValaCodeGenerator* self, ValaInterface* node);
 	ValaCodeBinding* (*create_enum_binding) (ValaCodeGenerator* self, ValaEnum* node);
 	ValaCodeBinding* (*create_enum_value_binding) (ValaCodeGenerator* self, ValaEnumValue* node);
+	ValaCodeBinding* (*create_error_domain_binding) (ValaCodeGenerator* self, ValaErrorDomain* node);
+	ValaCodeBinding* (*create_error_code_binding) (ValaCodeGenerator* self, ValaErrorCode* node);
 	ValaCodeBinding* (*create_delegate_binding) (ValaCodeGenerator* self, ValaDelegate* node);
 	ValaCodeBinding* (*create_constant_binding) (ValaCodeGenerator* self, ValaConstant* node);
 	ValaCodeBinding* (*create_field_binding) (ValaCodeGenerator* self, ValaField* node);
@@ -91,6 +93,7 @@ struct _ValaCodeGeneratorClass {
 	ValaCodeBinding* (*create_try_statement_binding) (ValaCodeGenerator* self, ValaTryStatement* node);
 	ValaCodeBinding* (*create_catch_clause_binding) (ValaCodeGenerator* self, ValaCatchClause* node);
 	ValaCodeBinding* (*create_lock_statement_binding) (ValaCodeGenerator* self, ValaLockStatement* node);
+	ValaCodeBinding* (*create_delete_statement_binding) (ValaCodeGenerator* self, ValaDeleteStatement* node);
 	ValaCodeBinding* (*create_array_creation_expression_binding) (ValaCodeGenerator* self, ValaArrayCreationExpression* node);
 	ValaCodeBinding* (*create_boolean_literal_binding) (ValaCodeGenerator* self, ValaBooleanLiteral* node);
 	ValaCodeBinding* (*create_character_literal_binding) (ValaCodeGenerator* self, ValaCharacterLiteral* node);
@@ -98,7 +101,6 @@ struct _ValaCodeGeneratorClass {
 	ValaCodeBinding* (*create_real_literal_binding) (ValaCodeGenerator* self, ValaRealLiteral* node);
 	ValaCodeBinding* (*create_string_literal_binding) (ValaCodeGenerator* self, ValaStringLiteral* node);
 	ValaCodeBinding* (*create_null_literal_binding) (ValaCodeGenerator* self, ValaNullLiteral* node);
-	ValaCodeBinding* (*create_literal_expression_binding) (ValaCodeGenerator* self, ValaLiteralExpression* node);
 	ValaCodeBinding* (*create_parenthesized_expression_binding) (ValaCodeGenerator* self, ValaParenthesizedExpression* node);
 	ValaCodeBinding* (*create_member_access_binding) (ValaCodeGenerator* self, ValaMemberAccess* node);
 	ValaCodeBinding* (*create_member_access_simple_binding) (ValaCodeGenerator* self, ValaMemberAccess* node);
@@ -129,6 +131,8 @@ ValaCodeBinding* vala_code_generator_create_struct_binding (ValaCodeGenerator* s
 ValaCodeBinding* vala_code_generator_create_interface_binding (ValaCodeGenerator* self, ValaInterface* node);
 ValaCodeBinding* vala_code_generator_create_enum_binding (ValaCodeGenerator* self, ValaEnum* node);
 ValaCodeBinding* vala_code_generator_create_enum_value_binding (ValaCodeGenerator* self, ValaEnumValue* node);
+ValaCodeBinding* vala_code_generator_create_error_domain_binding (ValaCodeGenerator* self, ValaErrorDomain* node);
+ValaCodeBinding* vala_code_generator_create_error_code_binding (ValaCodeGenerator* self, ValaErrorCode* node);
 ValaCodeBinding* vala_code_generator_create_delegate_binding (ValaCodeGenerator* self, ValaDelegate* node);
 ValaCodeBinding* vala_code_generator_create_constant_binding (ValaCodeGenerator* self, ValaConstant* node);
 ValaCodeBinding* vala_code_generator_create_field_binding (ValaCodeGenerator* self, ValaField* node);
@@ -163,6 +167,7 @@ ValaCodeBinding* vala_code_generator_create_throw_statement_binding (ValaCodeGen
 ValaCodeBinding* vala_code_generator_create_try_statement_binding (ValaCodeGenerator* self, ValaTryStatement* node);
 ValaCodeBinding* vala_code_generator_create_catch_clause_binding (ValaCodeGenerator* self, ValaCatchClause* node);
 ValaCodeBinding* vala_code_generator_create_lock_statement_binding (ValaCodeGenerator* self, ValaLockStatement* node);
+ValaCodeBinding* vala_code_generator_create_delete_statement_binding (ValaCodeGenerator* self, ValaDeleteStatement* node);
 ValaCodeBinding* vala_code_generator_create_array_creation_expression_binding (ValaCodeGenerator* self, ValaArrayCreationExpression* node);
 ValaCodeBinding* vala_code_generator_create_boolean_literal_binding (ValaCodeGenerator* self, ValaBooleanLiteral* node);
 ValaCodeBinding* vala_code_generator_create_character_literal_binding (ValaCodeGenerator* self, ValaCharacterLiteral* node);
@@ -170,7 +175,6 @@ ValaCodeBinding* vala_code_generator_create_integer_literal_binding (ValaCodeGen
 ValaCodeBinding* vala_code_generator_create_real_literal_binding (ValaCodeGenerator* self, ValaRealLiteral* node);
 ValaCodeBinding* vala_code_generator_create_string_literal_binding (ValaCodeGenerator* self, ValaStringLiteral* node);
 ValaCodeBinding* vala_code_generator_create_null_literal_binding (ValaCodeGenerator* self, ValaNullLiteral* node);
-ValaCodeBinding* vala_code_generator_create_literal_expression_binding (ValaCodeGenerator* self, ValaLiteralExpression* node);
 ValaCodeBinding* vala_code_generator_create_parenthesized_expression_binding (ValaCodeGenerator* self, ValaParenthesizedExpression* node);
 ValaCodeBinding* vala_code_generator_create_member_access_binding (ValaCodeGenerator* self, ValaMemberAccess* node);
 ValaCodeBinding* vala_code_generator_create_member_access_simple_binding (ValaCodeGenerator* self, ValaMemberAccess* node);
@@ -195,6 +199,7 @@ ValaCodeBinding* vala_code_generator_create_assignment_binding (ValaCodeGenerato
 ValaCodeGenerator* vala_code_generator_new (void);
 GType vala_code_generator_get_type (void);
 
+
 G_END_DECLS
 
 #endif
