@@ -29,6 +29,9 @@
 #include <vala/valaattribute.h>
 #include <vala/valasourcefile.h>
 
+
+
+
 struct _ValaCodeNodePrivate {
 	ValaCodeNode* _parent_node;
 	ValaSourceReference* _source_reference;
@@ -57,6 +60,7 @@ static void vala_code_node_dispose (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Visits this code node with the specified CodeVisitor.
  *
@@ -155,10 +159,10 @@ static char* vala_code_node_real_to_string (ValaCodeNode* self) {
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
 	str = g_string_new ("");
 	g_string_append (g_string_append (str, "/* "), g_type_name (G_TYPE_FROM_INSTANCE (G_OBJECT (self))));
-	if (vala_code_node_get_source_reference (self) != NULL) {
+	if (self->priv->_source_reference != NULL) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		g_string_append (g_string_append (str, "@"), (_tmp0 = vala_source_reference_to_string (vala_code_node_get_source_reference (self))));
+		g_string_append (g_string_append (str, "@"), (_tmp0 = vala_source_reference_to_string (self->priv->_source_reference)));
 		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	_tmp1 = NULL;
@@ -210,12 +214,12 @@ void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value) {
 	ValaCCodeNode* _tmp4;
 	ValaCCodeNode* _tmp3;
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	if (vala_code_node_get_source_reference (self) != NULL) {
+	if (value != NULL && self->priv->_source_reference != NULL) {
 		ValaCCodeLineDirective* _tmp2;
 		char* _tmp1;
 		_tmp2 = NULL;
 		_tmp1 = NULL;
-		vala_ccode_node_set_line (value, (_tmp2 = vala_ccode_line_directive_new ((_tmp1 = g_path_get_basename (vala_source_file_get_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (self))))), vala_source_reference_get_first_line (vala_code_node_get_source_reference (self)))));
+		vala_ccode_node_set_line (value, (_tmp2 = vala_ccode_line_directive_new ((_tmp1 = g_path_get_basename (vala_source_file_get_filename (vala_source_reference_get_file (self->priv->_source_reference)))), vala_source_reference_get_first_line (self->priv->_source_reference))));
 		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
 		_tmp1 = (g_free (_tmp1), NULL);
 	}
