@@ -77,7 +77,6 @@
 #include <vala/valarealliteral.h>
 #include <vala/valastringliteral.h>
 #include <vala/valanullliteral.h>
-#include <vala/valaliteralexpression.h>
 #include <vala/valaparenthesizedexpression.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valainvocationexpression.h>
@@ -99,6 +98,9 @@
 #include <vala/valaassignment.h>
 #include <vala/valaexpression.h>
 
+
+
+
 enum  {
 	VALA_CODE_VISITOR_DUMMY_PROPERTY
 };
@@ -157,7 +159,6 @@ static void vala_code_visitor_real_visit_integer_literal (ValaCodeVisitor* self,
 static void vala_code_visitor_real_visit_real_literal (ValaCodeVisitor* self, ValaRealLiteral* lit);
 static void vala_code_visitor_real_visit_string_literal (ValaCodeVisitor* self, ValaStringLiteral* lit);
 static void vala_code_visitor_real_visit_null_literal (ValaCodeVisitor* self, ValaNullLiteral* lit);
-static void vala_code_visitor_real_visit_literal_expression (ValaCodeVisitor* self, ValaLiteralExpression* expr);
 static void vala_code_visitor_real_visit_parenthesized_expression (ValaCodeVisitor* self, ValaParenthesizedExpression* expr);
 static void vala_code_visitor_real_visit_member_access (ValaCodeVisitor* self, ValaMemberAccess* expr);
 static void vala_code_visitor_real_visit_invocation_expression (ValaCodeVisitor* self, ValaInvocationExpression* expr);
@@ -181,6 +182,7 @@ static void vala_code_visitor_real_visit_end_full_expression (ValaCodeVisitor* s
 static gpointer vala_code_visitor_parent_class = NULL;
 
 
+
 /**
  * Visit operation called for source files.
  *
@@ -1061,22 +1063,6 @@ void vala_code_visitor_visit_null_literal (ValaCodeVisitor* self, ValaNullLitera
 }
 
 
-/**
- * Visit operation called for literal expressions.
- *
- * @param expr a literal expression
- */
-static void vala_code_visitor_real_visit_literal_expression (ValaCodeVisitor* self, ValaLiteralExpression* expr) {
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_LITERAL_EXPRESSION (expr));
-}
-
-
-void vala_code_visitor_visit_literal_expression (ValaCodeVisitor* self, ValaLiteralExpression* expr) {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_literal_expression (self, expr);
-}
-
-
 /**
  * Visit operation called for parenthesized expressions.
  *
@@ -1454,7 +1440,6 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_real_literal = vala_code_visitor_real_visit_real_literal;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_string_literal = vala_code_visitor_real_visit_string_literal;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_null_literal = vala_code_visitor_real_visit_null_literal;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_literal_expression = vala_code_visitor_real_visit_literal_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_parenthesized_expression = vala_code_visitor_real_visit_parenthesized_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_member_access = vala_code_visitor_real_visit_member_access;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_invocation_expression = vala_code_visitor_real_visit_invocation_expression;
