@@ -1,11 +1,11 @@
 /* valacodevisitor.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,11 +18,11 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
-#ifndef __VALACODEVISITOR_H__
-#define __VALACODEVISITOR_H__
+#ifndef __VALA_VALACODEVISITOR_H__
+#define __VALA_VALACODEVISITOR_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -44,11 +44,11 @@ typedef struct _ValaCodeVisitorPrivate ValaCodeVisitorPrivate;
  * Abstract code node visitor for traversing source code tree.
  */
 struct _ValaCodeVisitor {
-	GObject parent;
+	GObject parent_instance;
 	ValaCodeVisitorPrivate * priv;
 };
 struct _ValaCodeVisitorClass {
-	GObjectClass parent;
+	GObjectClass parent_class;
 	void (*visit_source_file) (ValaCodeVisitor* self, ValaSourceFile* source_file);
 	void (*visit_namespace) (ValaCodeVisitor* self, ValaNamespace* ns);
 	void (*visit_class) (ValaCodeVisitor* self, ValaClass* cl);
@@ -56,9 +56,9 @@ struct _ValaCodeVisitorClass {
 	void (*visit_interface) (ValaCodeVisitor* self, ValaInterface* iface);
 	void (*visit_enum) (ValaCodeVisitor* self, ValaEnum* en);
 	void (*visit_enum_value) (ValaCodeVisitor* self, ValaEnumValue* ev);
-	void (*visit_flags) (ValaCodeVisitor* self, ValaFlags* fl);
-	void (*visit_flags_value) (ValaCodeVisitor* self, ValaFlagsValue* fv);
-	void (*visit_callback) (ValaCodeVisitor* self, ValaCallback* cb);
+	void (*visit_error_domain) (ValaCodeVisitor* self, ValaErrorDomain* edomain);
+	void (*visit_error_code) (ValaCodeVisitor* self, ValaErrorCode* ecode);
+	void (*visit_delegate) (ValaCodeVisitor* self, ValaDelegate* d);
 	void (*visit_member) (ValaCodeVisitor* self, ValaMember* m);
 	void (*visit_constant) (ValaCodeVisitor* self, ValaConstant* c);
 	void (*visit_field) (ValaCodeVisitor* self, ValaField* f);
@@ -73,15 +73,13 @@ struct _ValaCodeVisitorClass {
 	void (*visit_named_argument) (ValaCodeVisitor* self, ValaNamedArgument* n);
 	void (*visit_type_parameter) (ValaCodeVisitor* self, ValaTypeParameter* p);
 	void (*visit_namespace_reference) (ValaCodeVisitor* self, ValaNamespaceReference* ns);
-	void (*visit_type_reference) (ValaCodeVisitor* self, ValaTypeReference* type);
-	void (*visit_begin_block) (ValaCodeVisitor* self, ValaBlock* b);
-	void (*visit_end_block) (ValaCodeVisitor* self, ValaBlock* b);
+	void (*visit_data_type) (ValaCodeVisitor* self, ValaDataType* type);
+	void (*visit_block) (ValaCodeVisitor* self, ValaBlock* b);
 	void (*visit_empty_statement) (ValaCodeVisitor* self, ValaEmptyStatement* stmt);
 	void (*visit_declaration_statement) (ValaCodeVisitor* self, ValaDeclarationStatement* stmt);
 	void (*visit_local_variable_declaration) (ValaCodeVisitor* self, ValaLocalVariableDeclaration* decl);
 	void (*visit_variable_declarator) (ValaCodeVisitor* self, ValaVariableDeclarator* decl);
-	void (*visit_begin_initializer_list) (ValaCodeVisitor* self, ValaInitializerList* list);
-	void (*visit_end_initializer_list) (ValaCodeVisitor* self, ValaInitializerList* list);
+	void (*visit_initializer_list) (ValaCodeVisitor* self, ValaInitializerList* list);
 	void (*visit_expression_statement) (ValaCodeVisitor* self, ValaExpressionStatement* stmt);
 	void (*visit_if_statement) (ValaCodeVisitor* self, ValaIfStatement* stmt);
 	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
@@ -90,34 +88,29 @@ struct _ValaCodeVisitorClass {
 	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
 	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
-	void (*visit_begin_foreach_statement) (ValaCodeVisitor* self, ValaForeachStatement* stmt);
-	void (*visit_end_foreach_statement) (ValaCodeVisitor* self, ValaForeachStatement* stmt);
+	void (*visit_foreach_statement) (ValaCodeVisitor* self, ValaForeachStatement* stmt);
 	void (*visit_break_statement) (ValaCodeVisitor* self, ValaBreakStatement* stmt);
 	void (*visit_continue_statement) (ValaCodeVisitor* self, ValaContinueStatement* stmt);
-	void (*visit_begin_return_statement) (ValaCodeVisitor* self, ValaReturnStatement* stmt);
-	void (*visit_end_return_statement) (ValaCodeVisitor* self, ValaReturnStatement* stmt);
+	void (*visit_return_statement) (ValaCodeVisitor* self, ValaReturnStatement* stmt);
 	void (*visit_throw_statement) (ValaCodeVisitor* self, ValaThrowStatement* stmt);
 	void (*visit_try_statement) (ValaCodeVisitor* self, ValaTryStatement* stmt);
 	void (*visit_catch_clause) (ValaCodeVisitor* self, ValaCatchClause* clause);
 	void (*visit_lock_statement) (ValaCodeVisitor* self, ValaLockStatement* stmt);
-	void (*visit_begin_array_creation_expression) (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
-	void (*visit_end_array_creation_expression) (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
+	void (*visit_delete_statement) (ValaCodeVisitor* self, ValaDeleteStatement* stmt);
+	void (*visit_array_creation_expression) (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
 	void (*visit_boolean_literal) (ValaCodeVisitor* self, ValaBooleanLiteral* lit);
 	void (*visit_character_literal) (ValaCodeVisitor* self, ValaCharacterLiteral* lit);
 	void (*visit_integer_literal) (ValaCodeVisitor* self, ValaIntegerLiteral* lit);
 	void (*visit_real_literal) (ValaCodeVisitor* self, ValaRealLiteral* lit);
 	void (*visit_string_literal) (ValaCodeVisitor* self, ValaStringLiteral* lit);
 	void (*visit_null_literal) (ValaCodeVisitor* self, ValaNullLiteral* lit);
-	void (*visit_literal_expression) (ValaCodeVisitor* self, ValaLiteralExpression* expr);
 	void (*visit_parenthesized_expression) (ValaCodeVisitor* self, ValaParenthesizedExpression* expr);
 	void (*visit_member_access) (ValaCodeVisitor* self, ValaMemberAccess* expr);
-	void (*visit_begin_invocation_expression) (ValaCodeVisitor* self, ValaInvocationExpression* expr);
-	void (*visit_end_invocation_expression) (ValaCodeVisitor* self, ValaInvocationExpression* expr);
+	void (*visit_invocation_expression) (ValaCodeVisitor* self, ValaInvocationExpression* expr);
 	void (*visit_element_access) (ValaCodeVisitor* self, ValaElementAccess* expr);
 	void (*visit_base_access) (ValaCodeVisitor* self, ValaBaseAccess* expr);
 	void (*visit_postfix_expression) (ValaCodeVisitor* self, ValaPostfixExpression* expr);
-	void (*visit_begin_object_creation_expression) (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
-	void (*visit_end_object_creation_expression) (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
+	void (*visit_object_creation_expression) (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
 	void (*visit_sizeof_expression) (ValaCodeVisitor* self, ValaSizeofExpression* expr);
 	void (*visit_typeof_expression) (ValaCodeVisitor* self, ValaTypeofExpression* expr);
 	void (*visit_unary_expression) (ValaCodeVisitor* self, ValaUnaryExpression* expr);
@@ -128,10 +121,8 @@ struct _ValaCodeVisitorClass {
 	void (*visit_binary_expression) (ValaCodeVisitor* self, ValaBinaryExpression* expr);
 	void (*visit_type_check) (ValaCodeVisitor* self, ValaTypeCheck* expr);
 	void (*visit_conditional_expression) (ValaCodeVisitor* self, ValaConditionalExpression* expr);
-	void (*visit_begin_lambda_expression) (ValaCodeVisitor* self, ValaLambdaExpression* expr);
-	void (*visit_end_lambda_expression) (ValaCodeVisitor* self, ValaLambdaExpression* expr);
-	void (*visit_begin_assignment) (ValaCodeVisitor* self, ValaAssignment* a);
-	void (*visit_end_assignment) (ValaCodeVisitor* self, ValaAssignment* a);
+	void (*visit_lambda_expression) (ValaCodeVisitor* self, ValaLambdaExpression* expr);
+	void (*visit_assignment) (ValaCodeVisitor* self, ValaAssignment* a);
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
@@ -142,9 +133,9 @@ void vala_code_visitor_visit_struct (ValaCodeVisitor* self, ValaStruct* st);
 void vala_code_visitor_visit_interface (ValaCodeVisitor* self, ValaInterface* iface);
 void vala_code_visitor_visit_enum (ValaCodeVisitor* self, ValaEnum* en);
 void vala_code_visitor_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* ev);
-void vala_code_visitor_visit_flags (ValaCodeVisitor* self, ValaFlags* fl);
-void vala_code_visitor_visit_flags_value (ValaCodeVisitor* self, ValaFlagsValue* fv);
-void vala_code_visitor_visit_callback (ValaCodeVisitor* self, ValaCallback* cb);
+void vala_code_visitor_visit_error_domain (ValaCodeVisitor* self, ValaErrorDomain* edomain);
+void vala_code_visitor_visit_error_code (ValaCodeVisitor* self, ValaErrorCode* ecode);
+void vala_code_visitor_visit_delegate (ValaCodeVisitor* self, ValaDelegate* d);
 void vala_code_visitor_visit_member (ValaCodeVisitor* self, ValaMember* m);
 void vala_code_visitor_visit_constant (ValaCodeVisitor* self, ValaConstant* c);
 void vala_code_visitor_visit_field (ValaCodeVisitor* self, ValaField* f);
@@ -159,15 +150,13 @@ void vala_code_visitor_visit_destructor (ValaCodeVisitor* self, ValaDestructor*
 void vala_code_visitor_visit_named_argument (ValaCodeVisitor* self, ValaNamedArgument* n);
 void vala_code_visitor_visit_type_parameter (ValaCodeVisitor* self, ValaTypeParameter* p);
 void vala_code_visitor_visit_namespace_reference (ValaCodeVisitor* self, ValaNamespaceReference* ns);
-void vala_code_visitor_visit_type_reference (ValaCodeVisitor* self, ValaTypeReference* type);
-void vala_code_visitor_visit_begin_block (ValaCodeVisitor* self, ValaBlock* b);
-void vala_code_visitor_visit_end_block (ValaCodeVisitor* self, ValaBlock* b);
+void vala_code_visitor_visit_data_type (ValaCodeVisitor* self, ValaDataType* type);
+void vala_code_visitor_visit_block (ValaCodeVisitor* self, ValaBlock* b);
 void vala_code_visitor_visit_empty_statement (ValaCodeVisitor* self, ValaEmptyStatement* stmt);
 void vala_code_visitor_visit_declaration_statement (ValaCodeVisitor* self, ValaDeclarationStatement* stmt);
 void vala_code_visitor_visit_local_variable_declaration (ValaCodeVisitor* self, ValaLocalVariableDeclaration* decl);
 void vala_code_visitor_visit_variable_declarator (ValaCodeVisitor* self, ValaVariableDeclarator* decl);
-void vala_code_visitor_visit_begin_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list);
-void vala_code_visitor_visit_end_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list);
+void vala_code_visitor_visit_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list);
 void vala_code_visitor_visit_expression_statement (ValaCodeVisitor* self, ValaExpressionStatement* stmt);
 void vala_code_visitor_visit_if_statement (ValaCodeVisitor* self, ValaIfStatement* stmt);
 void vala_code_visitor_visit_switch_statement (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
@@ -176,34 +165,29 @@ void vala_code_visitor_visit_switch_label (ValaCodeVisitor* self, ValaSwitchLabe
 void vala_code_visitor_visit_while_statement (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 void vala_code_visitor_visit_do_statement (ValaCodeVisitor* self, ValaDoStatement* stmt);
 void vala_code_visitor_visit_for_statement (ValaCodeVisitor* self, ValaForStatement* stmt);
-void vala_code_visitor_visit_begin_foreach_statement (ValaCodeVisitor* self, ValaForeachStatement* stmt);
-void vala_code_visitor_visit_end_foreach_statement (ValaCodeVisitor* self, ValaForeachStatement* stmt);
+void vala_code_visitor_visit_foreach_statement (ValaCodeVisitor* self, ValaForeachStatement* stmt);
 void vala_code_visitor_visit_break_statement (ValaCodeVisitor* self, ValaBreakStatement* stmt);
 void vala_code_visitor_visit_continue_statement (ValaCodeVisitor* self, ValaContinueStatement* stmt);
-void vala_code_visitor_visit_begin_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
-void vala_code_visitor_visit_end_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
+void vala_code_visitor_visit_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
 void vala_code_visitor_visit_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
 void vala_code_visitor_visit_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
 void vala_code_visitor_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
 void vala_code_visitor_visit_lock_statement (ValaCodeVisitor* self, ValaLockStatement* stmt);
-void vala_code_visitor_visit_begin_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
-void vala_code_visitor_visit_end_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
+void vala_code_visitor_visit_delete_statement (ValaCodeVisitor* self, ValaDeleteStatement* stmt);
+void vala_code_visitor_visit_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
 void vala_code_visitor_visit_boolean_literal (ValaCodeVisitor* self, ValaBooleanLiteral* lit);
 void vala_code_visitor_visit_character_literal (ValaCodeVisitor* self, ValaCharacterLiteral* lit);
 void vala_code_visitor_visit_integer_literal (ValaCodeVisitor* self, ValaIntegerLiteral* lit);
 void vala_code_visitor_visit_real_literal (ValaCodeVisitor* self, ValaRealLiteral* lit);
 void vala_code_visitor_visit_string_literal (ValaCodeVisitor* self, ValaStringLiteral* lit);
 void vala_code_visitor_visit_null_literal (ValaCodeVisitor* self, ValaNullLiteral* lit);
-void vala_code_visitor_visit_literal_expression (ValaCodeVisitor* self, ValaLiteralExpression* expr);
 void vala_code_visitor_visit_parenthesized_expression (ValaCodeVisitor* self, ValaParenthesizedExpression* expr);
 void vala_code_visitor_visit_member_access (ValaCodeVisitor* self, ValaMemberAccess* expr);
-void vala_code_visitor_visit_begin_invocation_expression (ValaCodeVisitor* self, ValaInvocationExpression* expr);
-void vala_code_visitor_visit_end_invocation_expression (ValaCodeVisitor* self, ValaInvocationExpression* expr);
+void vala_code_visitor_visit_invocation_expression (ValaCodeVisitor* self, ValaInvocationExpression* expr);
 void vala_code_visitor_visit_element_access (ValaCodeVisitor* self, ValaElementAccess* expr);
 void vala_code_visitor_visit_base_access (ValaCodeVisitor* self, ValaBaseAccess* expr);
 void vala_code_visitor_visit_postfix_expression (ValaCodeVisitor* self, ValaPostfixExpression* expr);
-void vala_code_visitor_visit_begin_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
-void vala_code_visitor_visit_end_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
+void vala_code_visitor_visit_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
 void vala_code_visitor_visit_sizeof_expression (ValaCodeVisitor* self, ValaSizeofExpression* expr);
 void vala_code_visitor_visit_typeof_expression (ValaCodeVisitor* self, ValaTypeofExpression* expr);
 void vala_code_visitor_visit_unary_expression (ValaCodeVisitor* self, ValaUnaryExpression* expr);
@@ -214,12 +198,11 @@ void vala_code_visitor_visit_reference_transfer_expression (ValaCodeVisitor* sel
 void vala_code_visitor_visit_binary_expression (ValaCodeVisitor* self, ValaBinaryExpression* expr);
 void vala_code_visitor_visit_type_check (ValaCodeVisitor* self, ValaTypeCheck* expr);
 void vala_code_visitor_visit_conditional_expression (ValaCodeVisitor* self, ValaConditionalExpression* expr);
-void vala_code_visitor_visit_begin_lambda_expression (ValaCodeVisitor* self, ValaLambdaExpression* expr);
-void vala_code_visitor_visit_end_lambda_expression (ValaCodeVisitor* self, ValaLambdaExpression* expr);
-void vala_code_visitor_visit_begin_assignment (ValaCodeVisitor* self, ValaAssignment* a);
-void vala_code_visitor_visit_end_assignment (ValaCodeVisitor* self, ValaAssignment* a);
+void vala_code_visitor_visit_lambda_expression (ValaCodeVisitor* self, ValaLambdaExpression* expr);
+void vala_code_visitor_visit_assignment (ValaCodeVisitor* self, ValaAssignment* a);
 void vala_code_visitor_visit_end_full_expression (ValaCodeVisitor* self, ValaExpression* expr);
-GType vala_code_visitor_get_type ();
+GType vala_code_visitor_get_type (void);
+
 
 G_END_DECLS
 
