@@ -28,6 +28,9 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
+
+
+
 struct _ValaConstantPrivate {
 	ValaExpression* _initializer;
 	char* cname;
@@ -53,6 +56,7 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Creates a new constant.
  *
@@ -90,8 +94,8 @@ static void vala_constant_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 	self = VALA_CONSTANT (base);
 	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_constant_get_type_reference (self)), visitor);
-	if (vala_constant_get_initializer (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_constant_get_initializer (self)), visitor);
+	if (self->priv->_initializer != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_initializer), visitor);
 	}
 }
 
