@@ -1,11 +1,11 @@
 /* valacreationmethod.vala
  *
- * Copyright (C) 2007  Raffaele Sandrini, Jürg Billeter
+ * Copyright (C) 2007-2008  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,12 +17,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACREATIONMETHOD_H__
-#define __VALACREATIONMETHOD_H__
+#ifndef __VALA_VALACREATIONMETHOD_H__
+#define __VALA_VALACREATIONMETHOD_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -47,18 +47,21 @@ typedef struct _ValaCreationMethodPrivate ValaCreationMethodPrivate;
  * Represents a type creation method.
  */
 struct _ValaCreationMethod {
-	ValaMethod parent;
+	ValaMethod parent_instance;
 	ValaCreationMethodPrivate * priv;
 };
 struct _ValaCreationMethodClass {
-	ValaMethodClass parent;
+	ValaMethodClass parent_class;
 };
 
-ValaCreationMethod* vala_creation_method_new (const char* name, ValaSourceReference* source_reference);
+ValaCreationMethod* vala_creation_method_new (const char* type_name, const char* name, ValaSourceReference* source_reference);
+char* vala_creation_method_get_type_name (ValaCreationMethod* self);
+void vala_creation_method_set_type_name (ValaCreationMethod* self, const char* value);
 gint vala_creation_method_get_n_construction_params (ValaCreationMethod* self);
 void vala_creation_method_set_n_construction_params (ValaCreationMethod* self, gint value);
 GType vala_creation_method_get_type (void);
 
+
 G_END_DECLS
 
 #endif
