@@ -31,6 +31,7 @@
 #include <string.h>
 #include <gee/collection.h>
 #include <vala/valacodenode.h>
+#include <vala/valatypesymbol.h>
 
 G_BEGIN_DECLS
 
@@ -66,12 +67,12 @@ struct _ValaDataTypeClass {
 	gboolean (*is_reference_type_or_type_parameter) (ValaDataType* self);
 	gboolean (*is_array) (ValaDataType* self);
 	GeeCollection* (*get_symbols) (ValaDataType* self);
+	ValaSymbol* (*get_member) (ValaDataType* self, const char* member_name);
 	ValaSymbol* (*get_pointer_member) (ValaDataType* self, const char* member_name);
 	gboolean (*is_real_struct_type) (ValaDataType* self);
 	char* (*get_type_id) (ValaDataType* self);
 };
 
-ValaDataType* vala_data_type_new (void);
 void vala_data_type_add_type_argument (ValaDataType* self, ValaDataType* arg);
 GeeList* vala_data_type_get_type_arguments (ValaDataType* self);
 void vala_data_type_remove_all_type_arguments (ValaDataType* self);
@@ -88,6 +89,7 @@ GeeCollection* vala_data_type_get_parameters (ValaDataType* self);
 gboolean vala_data_type_is_reference_type_or_type_parameter (ValaDataType* self);
 gboolean vala_data_type_is_array (ValaDataType* self);
 GeeCollection* vala_data_type_get_symbols (ValaDataType* self);
+ValaSymbol* vala_data_type_get_member (ValaDataType* self, const char* member_name);
 ValaSymbol* vala_data_type_get_pointer_member (ValaDataType* self, const char* member_name);
 gboolean vala_data_type_is_real_struct_type (ValaDataType* self);
 char* vala_data_type_get_type_id (ValaDataType* self);
@@ -111,6 +113,7 @@ gboolean vala_data_type_get_is_ref (ValaDataType* self);
 void vala_data_type_set_is_ref (ValaDataType* self, gboolean value);
 GType vala_data_type_get_type (void);
 
+
 G_END_DECLS
 
 #endif
