@@ -25,6 +25,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaDeclarationStatementPrivate {
 	ValaLocalVariableDeclaration* _declaration;
 };
@@ -39,6 +42,7 @@ static ValaStatementIface* vala_declaration_statement_vala_statement_parent_ifac
 static void vala_declaration_statement_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new declaration statement.
  *
@@ -54,7 +58,10 @@ ValaDeclarationStatement* vala_declaration_statement_new (ValaLocalVariableDecla
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "declaration", g_value_init (&__params_it->value, VALA_TYPE_LOCAL_VARIABLE_DECLARATION), g_value_set_object (&__params_it->value, decl), __params_it++);
+	__params_it->name = "declaration";
+	g_value_init (&__params_it->value, VALA_TYPE_LOCAL_VARIABLE_DECLARATION);
+	g_value_set_object (&__params_it->value, decl);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_DECLARATION_STATEMENT, __params_it - __params, __params);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	while (__params_it > __params) {
@@ -70,7 +77,7 @@ static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCode
 	ValaDeclarationStatement * self;
 	self = VALA_DECLARATION_STATEMENT (base);
 	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_declaration_statement_get_declaration (self)), visitor);
+	vala_code_node_accept (VALA_CODE_NODE (self->priv->_declaration), visitor);
 	vala_code_visitor_visit_declaration_statement (visitor, self);
 }
 
