@@ -25,6 +25,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaDestructorPrivate {
 	ValaBlock* _body;
 	gboolean _instance;
@@ -41,6 +44,7 @@ static gpointer vala_destructor_parent_class = NULL;
 static void vala_destructor_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new destructor.
  *
@@ -68,8 +72,8 @@ static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVi
 	ValaDestructor * self;
 	self = VALA_DESTRUCTOR (base);
 	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	if (vala_destructor_get_body (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_destructor_get_body (self)), visitor);
+	if (self->priv->_body != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_body), visitor);
 	}
 }
 
