@@ -1,6 +1,6 @@
 /* valaelementaccess.vala
  *
- * Copyright (C) 2006-2007  Raffaele Sandrini, Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,7 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- * 	Raffaele Sandrini <rasa@gmx.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
  * 	Jürg Billeter <j@bitron.ch>
  */
 
@@ -28,6 +28,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaElementAccessPrivate {
 	ValaExpression* _container;
 	GeeList* indices;
@@ -38,15 +41,18 @@ enum  {
 	VALA_ELEMENT_ACCESS_CONTAINER
 };
 static void vala_element_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_element_access_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gboolean vala_element_access_real_is_pure (ValaExpression* base);
 static gpointer vala_element_access_parent_class = NULL;
 static void vala_element_access_dispose (GObject * obj);
 
 
+
 void vala_element_access_append_index (ValaElementAccess* self, ValaExpression* index) {
 	g_return_if_fail (VALA_IS_ELEMENT_ACCESS (self));
 	g_return_if_fail (index == NULL || VALA_IS_EXPRESSION (index));
 	gee_collection_add (GEE_COLLECTION (self->priv->indices), index);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (index), VALA_CODE_NODE (self));
 }
 
 
@@ -71,7 +77,7 @@ static void vala_element_access_real_accept (ValaCodeNode* base, ValaCodeVisitor
 	ValaElementAccess * self;
 	self = VALA_ELEMENT_ACCESS (base);
 	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_element_access_get_container (self)), visitor);
+	vala_code_node_accept (VALA_CODE_NODE (self->priv->_container), visitor);
 	{
 		GeeList* e_collection;
 		GeeIterator* e_it;
@@ -79,7 +85,7 @@ static void vala_element_access_real_accept (ValaCodeNode* base, ValaCodeVisitor
 		e_it = gee_iterable_iterator (GEE_ITERABLE (e_collection));
 		while (gee_iterator_next (e_it)) {
 			ValaExpression* e;
-			e = gee_iterator_get (e_it);
+			e = ((ValaExpression*) gee_iterator_get (e_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (e), visitor);
 				(e == NULL ? NULL : (e = (g_object_unref (e), NULL)));
@@ -91,6 +97,23 @@ static void vala_element_access_real_accept (ValaCodeNode* base, ValaCodeVisitor
 }
 
 
+static void vala_element_access_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
+	ValaElementAccess * self;
+	gint index;
+	self = VALA_ELEMENT_ACCESS (base);
+	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	if (self->priv->_container == old_node) {
+		vala_element_access_set_container (self, new_node);
+	}
+	index = gee_list_index_of (self->priv->indices, old_node);
+	if (index >= 0 && vala_code_node_get_parent_node (VALA_CODE_NODE (new_node)) == NULL) {
+		gee_list_set (((GeeList*) self->priv->indices), index, new_node);
+		vala_code_node_set_parent_node (VALA_CODE_NODE (new_node), VALA_CODE_NODE (self));
+	}
+}
+
+
 static gboolean vala_element_access_real_is_pure (ValaExpression* base) {
 	ValaElementAccess * self;
 	self = VALA_ELEMENT_ACCESS (base);
@@ -101,7 +124,7 @@ static gboolean vala_element_access_real_is_pure (ValaExpression* base) {
 		index_it = gee_iterable_iterator (GEE_ITERABLE (index_collection));
 		while (gee_iterator_next (index_it)) {
 			ValaExpression* index;
-			index = gee_iterator_get (index_it);
+			index = ((ValaExpression*) gee_iterator_get (index_it));
 			{
 				if (!vala_expression_is_pure (index)) {
 					gboolean _tmp0;
@@ -112,7 +135,7 @@ static gboolean vala_element_access_real_is_pure (ValaExpression* base) {
 		}
 		(index_it == NULL ? NULL : (index_it = (g_object_unref (index_it), NULL)));
 	}
-	return vala_expression_is_pure (vala_element_access_get_container (self));
+	return vala_expression_is_pure (self->priv->_container);
 }
 
 
@@ -167,6 +190,7 @@ static void vala_element_access_class_init (ValaElementAccessClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = vala_element_access_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_element_access_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_element_access_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_element_access_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_element_access_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ELEMENT_ACCESS_CONTAINER, g_param_spec_object ("container", "container", "container", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
