@@ -1,6 +1,6 @@
 /* valaexpression.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,9 @@
 #include <vala/valasymbol.h>
 #include <vala/valavariabledeclarator.h>
 
+
+
+
 struct _ValaExpressionPrivate {
 	ValaDataType* _static_type;
 	ValaDataType* _expected_type;
@@ -33,6 +36,7 @@ struct _ValaExpressionPrivate {
 	gboolean _ref_missing;
 	gboolean _ref_sink;
 	gboolean _can_fail;
+	gboolean _lvalue;
 };
 #define VALA_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_EXPRESSION, ValaExpressionPrivate))
 enum  {
@@ -43,20 +47,20 @@ enum  {
 	VALA_EXPRESSION_REF_LEAKED,
 	VALA_EXPRESSION_REF_MISSING,
 	VALA_EXPRESSION_REF_SINK,
-	VALA_EXPRESSION_CAN_FAIL
+	VALA_EXPRESSION_CAN_FAIL,
+	VALA_EXPRESSION_LVALUE
 };
 static gpointer vala_expression_parent_class = NULL;
 static void vala_expression_dispose (GObject * obj);
 
 
+
 /**
  * Returns whether this expression is pure, i.e. whether this expression
  * is free of side-effects.
  */
 gboolean vala_expression_is_pure (ValaExpression* self) {
-	gboolean result;
-	result = VALA_EXPRESSION_GET_CLASS (self)->is_pure (self);
-	return result;
+	return VALA_EXPRESSION_GET_CLASS (self)->is_pure (self);
 }
 
 
@@ -152,6 +156,18 @@ void vala_expression_set_can_fail (ValaExpression* self, gboolean value) {
 }
 
 
+gboolean vala_expression_get_lvalue (ValaExpression* self) {
+	g_return_val_if_fail (VALA_IS_EXPRESSION (self), FALSE);
+	return self->priv->_lvalue;
+}
+
+
+void vala_expression_set_lvalue (ValaExpression* self, gboolean value) {
+	g_return_if_fail (VALA_IS_EXPRESSION (self));
+	self->priv->_lvalue = value;
+}
+
+
 static void vala_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaExpression * self;
 	self = VALA_EXPRESSION (object);
@@ -177,6 +193,9 @@ static void vala_expression_get_property (GObject * object, guint property_id, G
 		case VALA_EXPRESSION_CAN_FAIL:
 		g_value_set_boolean (value, vala_expression_get_can_fail (self));
 		break;
+		case VALA_EXPRESSION_LVALUE:
+		g_value_set_boolean (value, vala_expression_get_lvalue (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -209,6 +228,9 @@ static void vala_expression_set_property (GObject * object, guint property_id, c
 		case VALA_EXPRESSION_CAN_FAIL:
 		vala_expression_set_can_fail (self, g_value_get_boolean (value));
 		break;
+		case VALA_EXPRESSION_LVALUE:
+		vala_expression_set_lvalue (self, g_value_get_boolean (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -229,6 +251,7 @@ static void vala_expression_class_init (ValaExpressionClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_REF_MISSING, g_param_spec_boolean ("ref-missing", "ref-missing", "ref-missing", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_REF_SINK, g_param_spec_boolean ("ref-sink", "ref-sink", "ref-sink", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_CAN_FAIL, g_param_spec_boolean ("can-fail", "can-fail", "can-fail", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_LVALUE, g_param_spec_boolean ("lvalue", "lvalue", "lvalue", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
