@@ -27,9 +27,7 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/collection.h>
 #include <vala/valamember.h>
-#include <vala/valainvokable.h>
 #include <vala/valalockable.h>
 #include <vala/valacodenode.h>
 
@@ -49,27 +47,30 @@ typedef struct _ValaFieldPrivate ValaFieldPrivate;
  * Represents a type or namespace field.
  */
 struct _ValaField {
-	ValaMember parent;
+	ValaMember parent_instance;
 	ValaFieldPrivate * priv;
 };
 struct _ValaFieldClass {
-	ValaMemberClass parent;
+	ValaMemberClass parent_class;
 };
 
-ValaField* vala_field_new (const char* name, ValaTypeReference* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference);
+ValaField* vala_field_new (const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference);
 char* vala_field_get_cname (ValaField* self);
 char* vala_field_get_default_cname (ValaField* self);
 void vala_field_process_attributes (ValaField* self);
-ValaTypeReference* vala_field_get_type_reference (ValaField* self);
-void vala_field_set_type_reference (ValaField* self, ValaTypeReference* value);
+ValaDataType* vala_field_get_type_reference (ValaField* self);
+void vala_field_set_type_reference (ValaField* self, ValaDataType* value);
 ValaExpression* vala_field_get_initializer (ValaField* self);
 void vala_field_set_initializer (ValaField* self, ValaExpression* value);
 gboolean vala_field_get_instance (ValaField* self);
 void vala_field_set_instance (ValaField* self, gboolean value);
+gboolean vala_field_get_is_volatile (ValaField* self);
+void vala_field_set_is_volatile (ValaField* self, gboolean value);
 gboolean vala_field_get_no_array_length (ValaField* self);
 void vala_field_set_no_array_length (ValaField* self, gboolean value);
 GType vala_field_get_type (void);
 
+
 G_END_DECLS
 
 #endif
