@@ -1,6 +1,6 @@
 /* valaformalparameter.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <vala/valaformalparameter.h>
@@ -26,12 +26,19 @@
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valaattribute.h>
+
+
+
 
 struct _ValaFormalParameterPrivate {
 	gboolean _ellipsis;
 	ValaExpression* _default_expression;
 	gboolean _no_array_length;
 	gboolean _construct_parameter;
+	double _cparameter_position;
+	double _carray_length_parameter_position;
+	double _cdelegate_target_parameter_position;
 	ValaDataType* _data_type;
 };
 #define VALA_FORMAL_PARAMETER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FORMAL_PARAMETER, ValaFormalParameterPrivate))
@@ -41,14 +48,20 @@ enum  {
 	VALA_FORMAL_PARAMETER_ELLIPSIS,
 	VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION,
 	VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH,
-	VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER
+	VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER,
+	VALA_FORMAL_PARAMETER_CPARAMETER_POSITION,
+	VALA_FORMAL_PARAMETER_CARRAY_LENGTH_PARAMETER_POSITION,
+	VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION
 };
 static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static void vala_formal_parameter_process_ccode_attribute (ValaFormalParameter* self, ValaAttribute* a);
 static GObject * vala_formal_parameter_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_formal_parameter_parent_class = NULL;
 static void vala_formal_parameter_dispose (GObject * obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
+
 
 
 /**
@@ -97,10 +110,10 @@ static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, Vala
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (base);
 	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	if (!vala_formal_parameter_get_ellipsis (self)) {
+	if (!self->priv->_ellipsis) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_formal_parameter_get_type_reference (self)), visitor);
-		if (vala_formal_parameter_get_default_expression (self) != NULL) {
-			vala_code_node_accept (VALA_CODE_NODE (vala_formal_parameter_get_default_expression (self)), visitor);
+		if (self->priv->_default_expression != NULL) {
+			vala_code_node_accept (VALA_CODE_NODE (self->priv->_default_expression), visitor);
 		}
 	}
 }
@@ -117,6 +130,55 @@ static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDat
 }
 
 
+static void vala_formal_parameter_process_ccode_attribute (ValaFormalParameter* self, ValaAttribute* a) {
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
+	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	if (vala_attribute_has_argument (a, "array_length_pos")) {
+		vala_formal_parameter_set_carray_length_parameter_position (self, vala_attribute_get_double (a, "array_length_pos"));
+	}
+	if (vala_attribute_has_argument (a, "delegate_target_pos")) {
+		vala_formal_parameter_set_cdelegate_target_parameter_position (self, vala_attribute_get_double (a, "delegate_target_pos"));
+	}
+}
+
+
+/**
+ * Process all associated attributes.
+ */
+void vala_formal_parameter_process_attributes (ValaFormalParameter* self) {
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
+	{
+		GList* a_collection;
+		GList* a_it;
+		a_collection = VALA_CODE_NODE (self)->attributes;
+		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* _tmp0;
+			ValaAttribute* a;
+			_tmp0 = NULL;
+			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			{
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
+					vala_formal_parameter_process_ccode_attribute (self, a);
+				}
+				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+			}
+		}
+	}
+}
+
+
+ValaFormalParameter* vala_formal_parameter_copy (ValaFormalParameter* self) {
+	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
+	if (!self->priv->_ellipsis) {
+		ValaFormalParameter* result;
+		result = vala_formal_parameter_new (vala_symbol_get_name (VALA_SYMBOL (self)), vala_formal_parameter_get_type_reference (self), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
+		return result;
+	} else {
+		return vala_formal_parameter_new_with_ellipsis (NULL);
+	}
+}
+
+
 ValaDataType* vala_formal_parameter_get_type_reference (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
 	return self->priv->_data_type;
@@ -186,6 +248,42 @@ void vala_formal_parameter_set_construct_parameter (ValaFormalParameter* self, g
 }
 
 
+double vala_formal_parameter_get_cparameter_position (ValaFormalParameter* self) {
+	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), 0.0);
+	return self->priv->_cparameter_position;
+}
+
+
+void vala_formal_parameter_set_cparameter_position (ValaFormalParameter* self, double value) {
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
+	self->priv->_cparameter_position = value;
+}
+
+
+double vala_formal_parameter_get_carray_length_parameter_position (ValaFormalParameter* self) {
+	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), 0.0);
+	return self->priv->_carray_length_parameter_position;
+}
+
+
+void vala_formal_parameter_set_carray_length_parameter_position (ValaFormalParameter* self, double value) {
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
+	self->priv->_carray_length_parameter_position = value;
+}
+
+
+double vala_formal_parameter_get_cdelegate_target_parameter_position (ValaFormalParameter* self) {
+	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), 0.0);
+	return self->priv->_cdelegate_target_parameter_position;
+}
+
+
+void vala_formal_parameter_set_cdelegate_target_parameter_position (ValaFormalParameter* self, double value) {
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
+	self->priv->_cdelegate_target_parameter_position = value;
+}
+
+
 static GObject * vala_formal_parameter_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
 	GObject * obj;
 	ValaFormalParameterClass * klass;
@@ -221,6 +319,15 @@ static void vala_formal_parameter_get_property (GObject * object, guint property
 		case VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER:
 		g_value_set_boolean (value, vala_formal_parameter_get_construct_parameter (self));
 		break;
+		case VALA_FORMAL_PARAMETER_CPARAMETER_POSITION:
+		g_value_set_double (value, vala_formal_parameter_get_cparameter_position (self));
+		break;
+		case VALA_FORMAL_PARAMETER_CARRAY_LENGTH_PARAMETER_POSITION:
+		g_value_set_double (value, vala_formal_parameter_get_carray_length_parameter_position (self));
+		break;
+		case VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION:
+		g_value_set_double (value, vala_formal_parameter_get_cdelegate_target_parameter_position (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -247,6 +354,15 @@ static void vala_formal_parameter_set_property (GObject * object, guint property
 		case VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER:
 		vala_formal_parameter_set_construct_parameter (self, g_value_get_boolean (value));
 		break;
+		case VALA_FORMAL_PARAMETER_CPARAMETER_POSITION:
+		vala_formal_parameter_set_cparameter_position (self, g_value_get_double (value));
+		break;
+		case VALA_FORMAL_PARAMETER_CARRAY_LENGTH_PARAMETER_POSITION:
+		vala_formal_parameter_set_carray_length_parameter_position (self, g_value_get_double (value));
+		break;
+		case VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION:
+		vala_formal_parameter_set_cdelegate_target_parameter_position (self, g_value_get_double (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -269,6 +385,9 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "default-expression", "default-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER, g_param_spec_boolean ("construct-parameter", "construct-parameter", "construct-parameter", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CPARAMETER_POSITION, g_param_spec_double ("cparameter-position", "cparameter-position", "cparameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CARRAY_LENGTH_PARAMETER_POSITION, g_param_spec_double ("carray-length-parameter-position", "carray-length-parameter-position", "carray-length-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION, g_param_spec_double ("cdelegate-target-parameter-position", "cdelegate-target-parameter-position", "cdelegate-target-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -296,5 +415,16 @@ GType vala_formal_parameter_get_type (void) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
