@@ -1,6 +1,6 @@
 /* valaformalparameter.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #ifndef __VALA_VALAFORMALPARAMETER_H__
@@ -28,6 +28,8 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <float.h>
+#include <math.h>
 #include <vala/valasymbol.h>
 #include <vala/valacodenode.h>
 
@@ -56,6 +58,8 @@ struct _ValaFormalParameterClass {
 
 ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaDataType* type, ValaSourceReference* source);
 ValaFormalParameter* vala_formal_parameter_new_with_ellipsis (ValaSourceReference* source);
+void vala_formal_parameter_process_attributes (ValaFormalParameter* self);
+ValaFormalParameter* vala_formal_parameter_copy (ValaFormalParameter* self);
 ValaDataType* vala_formal_parameter_get_type_reference (ValaFormalParameter* self);
 void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaDataType* value);
 gboolean vala_formal_parameter_get_ellipsis (ValaFormalParameter* self);
@@ -66,8 +70,15 @@ gboolean vala_formal_parameter_get_no_array_length (ValaFormalParameter* self);
 void vala_formal_parameter_set_no_array_length (ValaFormalParameter* self, gboolean value);
 gboolean vala_formal_parameter_get_construct_parameter (ValaFormalParameter* self);
 void vala_formal_parameter_set_construct_parameter (ValaFormalParameter* self, gboolean value);
+double vala_formal_parameter_get_cparameter_position (ValaFormalParameter* self);
+void vala_formal_parameter_set_cparameter_position (ValaFormalParameter* self, double value);
+double vala_formal_parameter_get_carray_length_parameter_position (ValaFormalParameter* self);
+void vala_formal_parameter_set_carray_length_parameter_position (ValaFormalParameter* self, double value);
+double vala_formal_parameter_get_cdelegate_target_parameter_position (ValaFormalParameter* self);
+void vala_formal_parameter_set_cdelegate_target_parameter_position (ValaFormalParameter* self, double value);
 GType vala_formal_parameter_get_type (void);
 
+
 G_END_DECLS
 
 #endif
