@@ -1,6 +1,6 @@
 /* valaforstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,6 +29,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaForStatementPrivate {
 	GeeList* initializer;
 	GeeList* iterator;
@@ -42,12 +45,14 @@ enum  {
 	VALA_FOR_STATEMENT_BODY
 };
 static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_for_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_for_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_for_statement_parent_class = NULL;
 static ValaStatementIface* vala_for_statement_vala_statement_parent_iface = NULL;
 static void vala_for_statement_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new for statement.
  *
@@ -65,7 +70,10 @@ ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock*
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "condition", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, condition), __params_it++);
+	__params_it->name = "condition";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, condition);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_FOR_STATEMENT, __params_it - __params, __params);
 	vala_for_statement_set_body (self, body);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -127,6 +135,14 @@ GeeCollection* vala_for_statement_get_iterator (ValaForStatement* self) {
 
 
 static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
+	ValaForStatement * self;
+	self = VALA_FOR_STATEMENT (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_for_statement (visitor, self);
+}
+
+
+static void vala_for_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaForStatement * self;
 	self = VALA_FOR_STATEMENT (base);
 	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
@@ -137,7 +153,7 @@ static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 		init_expr_it = gee_iterable_iterator (GEE_ITERABLE (init_expr_collection));
 		while (gee_iterator_next (init_expr_it)) {
 			ValaExpression* init_expr;
-			init_expr = gee_iterator_get (init_expr_it);
+			init_expr = ((ValaExpression*) gee_iterator_get (init_expr_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (init_expr), visitor);
 				vala_code_visitor_visit_end_full_expression (visitor, init_expr);
@@ -146,8 +162,10 @@ static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 		}
 		(init_expr_it == NULL ? NULL : (init_expr_it = (g_object_unref (init_expr_it), NULL)));
 	}
-	vala_code_node_accept (VALA_CODE_NODE (vala_for_statement_get_condition (self)), visitor);
-	vala_code_visitor_visit_end_full_expression (visitor, vala_for_statement_get_condition (self));
+	if (vala_for_statement_get_condition (self) != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (vala_for_statement_get_condition (self)), visitor);
+		vala_code_visitor_visit_end_full_expression (visitor, vala_for_statement_get_condition (self));
+	}
 	{
 		GeeList* it_expr_collection;
 		GeeIterator* it_expr_it;
@@ -155,7 +173,7 @@ static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 		it_expr_it = gee_iterable_iterator (GEE_ITERABLE (it_expr_collection));
 		while (gee_iterator_next (it_expr_it)) {
 			ValaExpression* it_expr;
-			it_expr = gee_iterator_get (it_expr_it);
+			it_expr = ((ValaExpression*) gee_iterator_get (it_expr_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (it_expr), visitor);
 				vala_code_visitor_visit_end_full_expression (visitor, it_expr);
@@ -165,7 +183,6 @@ static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 		(it_expr_it == NULL ? NULL : (it_expr_it = (g_object_unref (it_expr_it), NULL)));
 	}
 	vala_code_node_accept (VALA_CODE_NODE (vala_for_statement_get_body (self)), visitor);
-	vala_code_visitor_visit_for_statement (visitor, self);
 }
 
 
@@ -185,7 +202,7 @@ static void vala_for_statement_real_replace_expression (ValaCodeNode* base, Vala
 			ValaExpression* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = gee_list_get (((GeeList*) self->priv->initializer), i)) == old_node, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+			if ((_tmp1 = (_tmp0 = ((ValaExpression*) gee_list_get (((GeeList*) self->priv->initializer), i))) == old_node, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
 				gee_list_set (((GeeList*) self->priv->initializer), i, new_node);
 				return;
 			}
@@ -198,7 +215,7 @@ static void vala_for_statement_real_replace_expression (ValaCodeNode* base, Vala
 			ValaExpression* _tmp2;
 			gboolean _tmp3;
 			_tmp2 = NULL;
-			if ((_tmp3 = (_tmp2 = gee_list_get (((GeeList*) self->priv->iterator), i)) == old_node, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
+			if ((_tmp3 = (_tmp2 = ((ValaExpression*) gee_list_get (((GeeList*) self->priv->iterator), i))) == old_node, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
 				gee_list_set (((GeeList*) self->priv->iterator), i, new_node);
 				return;
 			}
@@ -220,7 +237,9 @@ void vala_for_statement_set_condition (ValaForStatement* self, ValaExpression* v
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
-	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_condition), VALA_CODE_NODE (self));
+	if (self->priv->_condition != NULL) {
+		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_condition), VALA_CODE_NODE (self));
+	}
 }
 
 
@@ -282,6 +301,7 @@ static void vala_for_statement_class_init (ValaForStatementClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = vala_for_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_for_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_for_statement_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_for_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_for_statement_real_replace_expression;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOR_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOR_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
