@@ -1,6 +1,6 @@
 /* valaifstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,6 +26,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaIfStatementPrivate {
 	ValaBlock* _true_statement;
 	ValaBlock* _false_statement;
@@ -39,12 +42,14 @@ enum  {
 	VALA_IF_STATEMENT_FALSE_STATEMENT
 };
 static void vala_if_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_if_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_if_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_if_statement_parent_class = NULL;
 static ValaStatementIface* vala_if_statement_vala_statement_parent_iface = NULL;
 static void vala_if_statement_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new if statement.
  *
@@ -63,9 +68,18 @@ ValaIfStatement* vala_if_statement_new (ValaExpression* cond, ValaBlock* true_st
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
-	(__params_it->name = "condition", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, cond), __params_it++);
-	(__params_it->name = "true-statement", g_value_init (&__params_it->value, VALA_TYPE_BLOCK), g_value_set_object (&__params_it->value, true_stmt), __params_it++);
-	(__params_it->name = "false-statement", g_value_init (&__params_it->value, VALA_TYPE_BLOCK), g_value_set_object (&__params_it->value, false_stmt), __params_it++);
+	__params_it->name = "condition";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, cond);
+	__params_it++;
+	__params_it->name = "true-statement";
+	g_value_init (&__params_it->value, VALA_TYPE_BLOCK);
+	g_value_set_object (&__params_it->value, true_stmt);
+	__params_it++;
+	__params_it->name = "false-statement";
+	g_value_init (&__params_it->value, VALA_TYPE_BLOCK);
+	g_value_set_object (&__params_it->value, false_stmt);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_IF_STATEMENT, __params_it - __params, __params);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	while (__params_it > __params) {
@@ -78,16 +92,23 @@ ValaIfStatement* vala_if_statement_new (ValaExpression* cond, ValaBlock* true_st
 
 
 static void vala_if_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
+	ValaIfStatement * self;
+	self = VALA_IF_STATEMENT (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_if_statement (visitor, self);
+}
+
+
+static void vala_if_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaIfStatement * self;
 	self = VALA_IF_STATEMENT (base);
 	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_if_statement_get_condition (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_if_statement_get_condition (self));
-	vala_code_node_accept (VALA_CODE_NODE (vala_if_statement_get_true_statement (self)), visitor);
-	if (vala_if_statement_get_false_statement (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_if_statement_get_false_statement (self)), visitor);
+	vala_code_node_accept (VALA_CODE_NODE (self->priv->_true_statement), visitor);
+	if (self->priv->_false_statement != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_false_statement), visitor);
 	}
-	vala_code_visitor_visit_if_statement (visitor, self);
 }
 
 
@@ -198,6 +219,7 @@ static void vala_if_statement_class_init (ValaIfStatementClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = vala_if_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_if_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_if_statement_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_if_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_if_statement_real_replace_expression;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_IF_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_IF_STATEMENT_TRUE_STATEMENT, g_param_spec_object ("true-statement", "true-statement", "true-statement", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
