@@ -33,11 +33,15 @@
 #include <vala/valatypesymbol.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valadatatype.h>
+#include <vala/valaenumvalue.h>
 #include <vala/valaarraytype.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valamember.h>
 #include <vala/valapropertyaccessor.h>
 
+
+
+
 struct _ValaInterfaceWriterPrivate {
 	ValaCodeContext* context;
 	FILE* stream;
@@ -54,7 +58,6 @@ static void vala_interface_writer_real_visit_class (ValaCodeVisitor* base, ValaC
 static void vala_interface_writer_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st);
 static void vala_interface_writer_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface);
 static void vala_interface_writer_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en);
-static void vala_interface_writer_real_visit_enum_value (ValaCodeVisitor* base, ValaEnumValue* ev);
 static void vala_interface_writer_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* edomain);
 static void vala_interface_writer_real_visit_error_code (ValaCodeVisitor* base, ValaErrorCode* ecode);
 static void vala_interface_writer_real_visit_constant (ValaCodeVisitor* base, ValaConstant* c);
@@ -82,6 +85,7 @@ static void vala_interface_writer_dispose (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Writes the public interface of the specified code context into the
  * specified file.
@@ -417,6 +421,9 @@ static void vala_interface_writer_real_visit_interface (ValaCodeVisitor* base, V
 	gboolean first;
 	char* cheaders;
 	char* _tmp3;
+	char* _tmp5;
+	char* _tmp4;
+	gboolean _tmp6;
 	GeeCollection* type_params;
 	GeeCollection* prerequisites;
 	self = VALA_INTERFACE_WRITER (base);
@@ -458,8 +465,20 @@ static void vala_interface_writer_real_visit_interface (ValaCodeVisitor* base, V
 		(cheader_it == NULL ? NULL : (cheader_it = (g_object_unref (cheader_it), NULL)));
 	}
 	_tmp3 = NULL;
-	vala_interface_writer_write_string (self, (_tmp3 = g_strdup_printf ("[CCode (cheader_filename = \"%s\")]", cheaders)));
+	vala_interface_writer_write_string (self, (_tmp3 = g_strdup_printf ("[CCode (cheader_filename = \"%s\"", cheaders)));
 	_tmp3 = (g_free (_tmp3), NULL);
+	_tmp5 = NULL;
+	_tmp4 = NULL;
+	if ((_tmp6 = _vala_strcmp0 ((_tmp4 = vala_interface_get_lower_case_csuffix (iface)), (_tmp5 = vala_interface_get_default_lower_case_csuffix (iface))) != 0, (_tmp5 = (g_free (_tmp5), NULL)), (_tmp4 = (g_free (_tmp4), NULL)), _tmp6)) {
+		char* _tmp8;
+		char* _tmp7;
+		_tmp8 = NULL;
+		_tmp7 = NULL;
+		vala_interface_writer_write_string (self, (_tmp8 = g_strdup_printf (", lower_case_csuffix = \"%s\"", (_tmp7 = vala_interface_get_lower_case_csuffix (iface)))));
+		_tmp8 = (g_free (_tmp8), NULL);
+		_tmp7 = (g_free (_tmp7), NULL);
+	}
+	vala_interface_writer_write_string (self, ")]");
 	vala_interface_writer_write_newline (self);
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_accessibility (self, VALA_SYMBOL (iface));
@@ -534,6 +553,7 @@ static void vala_interface_writer_real_visit_enum (ValaCodeVisitor* base, ValaEn
 	char* cheaders;
 	char* _tmp4;
 	char* _tmp3;
+	char* _tmp6;
 	self = VALA_INTERFACE_WRITER (base);
 	g_return_if_fail (en == NULL || VALA_IS_ENUM (en));
 	if (vala_code_node_get_source_reference (VALA_CODE_NODE (en)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (en))))) {
@@ -574,9 +594,18 @@ static void vala_interface_writer_real_visit_enum (ValaCodeVisitor* base, ValaEn
 	}
 	_tmp4 = NULL;
 	_tmp3 = NULL;
-	vala_interface_writer_write_string (self, (_tmp4 = g_strdup_printf ("[CCode (cprefix = \"%s\", cheader_filename = \"%s\")]", (_tmp3 = vala_enum_get_cprefix (en)), cheaders)));
+	vala_interface_writer_write_string (self, (_tmp4 = g_strdup_printf ("[CCode (cprefix = \"%s\", ", (_tmp3 = vala_enum_get_cprefix (en)))));
 	_tmp4 = (g_free (_tmp4), NULL);
 	_tmp3 = (g_free (_tmp3), NULL);
+	if (!vala_enum_get_has_type_id (en)) {
+		char* _tmp5;
+		_tmp5 = NULL;
+		vala_interface_writer_write_string (self, (_tmp5 = g_strdup_printf ("has_type_id = \"%d\", ", vala_enum_get_has_type_id (en))));
+		_tmp5 = (g_free (_tmp5), NULL);
+	}
+	_tmp6 = NULL;
+	vala_interface_writer_write_string (self, (_tmp6 = g_strdup_printf ("cheader_filename = \"%s\")]", cheaders)));
+	_tmp6 = (g_free (_tmp6), NULL);
 	if (vala_enum_get_is_flags (en)) {
 		vala_interface_writer_write_indent (self);
 		vala_interface_writer_write_string (self, "[Flags]");
@@ -586,24 +615,61 @@ static void vala_interface_writer_real_visit_enum (ValaCodeVisitor* base, ValaEn
 	vala_interface_writer_write_string (self, "enum ");
 	vala_interface_writer_write_identifier (self, vala_symbol_get_name (VALA_SYMBOL (en)));
 	vala_interface_writer_write_begin_block (self);
-	vala_code_node_accept_children (VALA_CODE_NODE (en), VALA_CODE_VISITOR (self));
+	first = TRUE;
+	{
+		GeeCollection* ev_collection;
+		GeeIterator* ev_it;
+		ev_collection = vala_enum_get_values (en);
+		ev_it = gee_iterable_iterator (GEE_ITERABLE (ev_collection));
+		while (gee_iterator_next (ev_it)) {
+			ValaEnumValue* ev;
+			ev = ((ValaEnumValue*) gee_iterator_get (ev_it));
+			{
+				if (first) {
+					first = FALSE;
+				} else {
+					vala_interface_writer_write_string (self, ",");
+					vala_interface_writer_write_newline (self);
+				}
+				vala_interface_writer_write_indent (self);
+				vala_interface_writer_write_identifier (self, vala_symbol_get_name (VALA_SYMBOL (ev)));
+				(ev == NULL ? NULL : (ev = (g_object_unref (ev), NULL)));
+			}
+		}
+		(ev_collection == NULL ? NULL : (ev_collection = (g_object_unref (ev_collection), NULL)));
+		(ev_it == NULL ? NULL : (ev_it = (g_object_unref (ev_it), NULL)));
+	}
+	if (!first) {
+		GeeCollection* _tmp7;
+		gboolean _tmp8;
+		_tmp7 = NULL;
+		if ((_tmp8 = gee_collection_get_size ((_tmp7 = vala_enum_get_methods (en))) > 0, (_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL))), _tmp8)) {
+			vala_interface_writer_write_string (self, ";");
+		}
+		vala_interface_writer_write_newline (self);
+	}
+	{
+		GeeCollection* m_collection;
+		GeeIterator* m_it;
+		m_collection = vala_enum_get_methods (en);
+		m_it = gee_iterable_iterator (GEE_ITERABLE (m_collection));
+		while (gee_iterator_next (m_it)) {
+			ValaMethod* m;
+			m = ((ValaMethod*) gee_iterator_get (m_it));
+			{
+				vala_code_node_accept (VALA_CODE_NODE (m), VALA_CODE_VISITOR (self));
+				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+			}
+		}
+		(m_collection == NULL ? NULL : (m_collection = (g_object_unref (m_collection), NULL)));
+		(m_it == NULL ? NULL : (m_it = (g_object_unref (m_it), NULL)));
+	}
 	vala_interface_writer_write_end_block (self);
 	vala_interface_writer_write_newline (self);
 	cheaders = (g_free (cheaders), NULL);
 }
 
 
-static void vala_interface_writer_real_visit_enum_value (ValaCodeVisitor* base, ValaEnumValue* ev) {
-	ValaInterfaceWriter * self;
-	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (ev == NULL || VALA_IS_ENUM_VALUE (ev));
-	vala_interface_writer_write_indent (self);
-	vala_interface_writer_write_identifier (self, vala_symbol_get_name (VALA_SYMBOL (ev)));
-	vala_interface_writer_write_string (self, ",");
-	vala_interface_writer_write_newline (self);
-}
-
-
 static void vala_interface_writer_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* edomain) {
 	ValaInterfaceWriter * self;
 	gboolean first;
@@ -1211,7 +1277,7 @@ static void vala_interface_writer_write_identifier (ValaInterfaceWriter* self, c
 static void vala_interface_writer_write_return_type (ValaInterfaceWriter* self, ValaDataType* type) {
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
 	g_return_if_fail (type == NULL || VALA_IS_DATA_TYPE (type));
-	if ((vala_data_type_get_data_type (type) != NULL && vala_typesymbol_is_reference_type (vala_data_type_get_data_type (type))) || vala_data_type_get_type_parameter (type) != NULL) {
+	if (vala_data_type_is_reference_type_or_type_parameter (type)) {
 		if (!vala_data_type_get_transfers_ownership (type)) {
 			vala_interface_writer_write_string (self, "weak ");
 		}
@@ -1309,7 +1375,6 @@ static void vala_interface_writer_class_init (ValaInterfaceWriterClass * klass)
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_interface_writer_real_visit_struct;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_interface = vala_interface_writer_real_visit_interface;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_interface_writer_real_visit_enum;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_enum_value = vala_interface_writer_real_visit_enum_value;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_error_domain = vala_interface_writer_real_visit_error_domain;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_error_code = vala_interface_writer_real_visit_error_code;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_constant = vala_interface_writer_real_visit_constant;
