@@ -1,6 +1,6 @@
 /* valaliteral.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -43,17 +44,16 @@ typedef struct _ValaLiteralPrivate ValaLiteralPrivate;
  * Base class for all literals in the source code.
  */
 struct _ValaLiteral {
-	ValaCodeNode parent_instance;
+	ValaExpression parent_instance;
 	ValaLiteralPrivate * priv;
 };
 struct _ValaLiteralClass {
-	ValaCodeNodeClass parent_class;
+	ValaExpressionClass parent_class;
 };
 
-ValaDataType* vala_literal_get_static_type (ValaLiteral* self);
-void vala_literal_set_static_type (ValaLiteral* self, ValaDataType* value);
 GType vala_literal_get_type (void);
 
+
 G_END_DECLS
 
 #endif
