@@ -1,6 +1,6 @@
 /* valamember.vala
  *
- * Copyright (C) 2006-2007  Raffaele Sandrini, Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,7 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- * 	Raffaele Sandrini <rasa@gmx.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <vala/valamember.h>
@@ -28,6 +28,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valasourcefile.h>
 
+
+
+
 struct _ValaMemberPrivate {
 	GeeList* cheader_filenames;
 };
@@ -41,6 +44,7 @@ static gpointer vala_member_parent_class = NULL;
 static void vala_member_dispose (GObject * obj);
 
 
+
 static void vala_member_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMember * self;
 	self = VALA_MEMBER (base);
@@ -52,7 +56,7 @@ static void vala_member_real_accept (ValaCodeNode* base, ValaCodeVisitor* visito
 static GeeCollection* vala_member_real_get_cheader_filenames (ValaSymbol* base) {
 	ValaMember * self;
 	self = VALA_MEMBER (base);
-	if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0) {
+	if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0 && vala_symbol_get_parent_symbol (VALA_SYMBOL (self)) != NULL) {
 		{
 			GeeCollection* filename_collection;
 			GeeIterator* filename_it;
@@ -60,11 +64,11 @@ static GeeCollection* vala_member_real_get_cheader_filenames (ValaSymbol* base)
 			filename_it = gee_iterable_iterator (GEE_ITERABLE (filename_collection));
 			while (gee_iterator_next (filename_it)) {
 				char* filename;
-				filename = gee_iterator_get (filename_it);
+				filename = ((char*) gee_iterator_get (filename_it));
 				{
 					/* default to header filenames of the namespace */
 					vala_member_add_cheader_filename (self, filename);
-					(filename = (g_free (filename), NULL));
+					filename = (g_free (filename), NULL);
 				}
 			}
 			(filename_collection == NULL ? NULL : (filename_collection = (g_object_unref (filename_collection), NULL)));
@@ -75,7 +79,7 @@ static GeeCollection* vala_member_real_get_cheader_filenames (ValaSymbol* base)
 			/* don't add default include directives for VAPI files*/
 			_tmp0 = NULL;
 			gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), (_tmp0 = vala_source_file_get_cinclude_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))));
-			(_tmp0 = (g_free (_tmp0), NULL));
+			_tmp0 = (g_free (_tmp0), NULL);
 		}
 	}
 	return GEE_COLLECTION (gee_read_only_collection_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, GEE_COLLECTION (self->priv->cheader_filenames)));
