@@ -29,6 +29,9 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valaproperty.h>
 
+
+
+
 struct _ValaMemberAccessPrivate {
 	char* _member_name;
 	gboolean _pointer_member_access;
@@ -55,6 +58,7 @@ static gpointer vala_member_access_parent_class = NULL;
 static void vala_member_access_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new member access expression.
  *
@@ -136,7 +140,7 @@ static void vala_member_access_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 		type_arg_it = gee_iterable_iterator (GEE_ITERABLE (type_arg_collection));
 		while (gee_iterator_next (type_arg_it)) {
 			ValaDataType* type_arg;
-			type_arg = gee_iterator_get (type_arg_it);
+			type_arg = ((ValaDataType*) gee_iterator_get (type_arg_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (type_arg), visitor);
 				(type_arg == NULL ? NULL : (type_arg = (g_object_unref (type_arg), NULL)));
@@ -154,13 +158,13 @@ static char* vala_member_access_real_to_string (ValaCodeNode* base) {
 	if (vala_member_access_get_inner (self) == NULL) {
 		const char* _tmp0;
 		_tmp0 = NULL;
-		return (_tmp0 = vala_member_access_get_member_name (self), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+		return (_tmp0 = self->priv->_member_name, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	} else {
 		char* _tmp2;
 		char* _tmp3;
 		_tmp2 = NULL;
 		_tmp3 = NULL;
-		return (_tmp3 = g_strdup_printf ("%s.%s", (_tmp2 = vala_code_node_to_string (VALA_CODE_NODE (vala_member_access_get_inner (self)))), vala_member_access_get_member_name (self)), (_tmp2 = (g_free (_tmp2), NULL)), _tmp3);
+		return (_tmp3 = g_strdup_printf ("%s.%s", (_tmp2 = vala_code_node_to_string (VALA_CODE_NODE (vala_member_access_get_inner (self)))), self->priv->_member_name), (_tmp2 = (g_free (_tmp2), NULL)), _tmp3);
 	}
 }
 
@@ -196,7 +200,7 @@ static void vala_member_access_real_replace_type (ValaCodeNode* base, ValaDataTy
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = gee_list_get (((GeeList*) self->priv->type_argument_list), i)) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+			if ((_tmp1 = (_tmp0 = ((ValaDataType*) gee_list_get (((GeeList*) self->priv->type_argument_list), i))) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
 				gee_list_set (((GeeList*) self->priv->type_argument_list), i, new_type);
 				return;
 			}
@@ -356,7 +360,7 @@ static void vala_member_access_init (ValaMemberAccess * self) {
 static void vala_member_access_dispose (GObject * obj) {
 	ValaMemberAccess * self;
 	self = VALA_MEMBER_ACCESS (obj);
-	(self->priv->_member_name = (g_free (self->priv->_member_name), NULL));
+	self->priv->_member_name = (g_free (self->priv->_member_name), NULL);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
 	(self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_object_unref (self->priv->type_argument_list), NULL)));
 	G_OBJECT_CLASS (vala_member_access_parent_class)->dispose (obj);
