@@ -1,6 +1,6 @@
 /* valamemorymanager.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <vala/valamemorymanager.h>
@@ -27,15 +27,18 @@
 #include <gee/iterator.h>
 #include <vala/valasymbol.h>
 #include <vala/valaexpression.h>
-#include <vala/valatypereference.h>
 #include <vala/valadatatype.h>
-#include <vala/valainvokable.h>
+#include <vala/valanulltype.h>
+#include <vala/valapointertype.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valasemanticanalyzer.h>
 #include <vala/valacodenode.h>
 #include <vala/valapointerindirection.h>
 #include <vala/valasignal.h>
 
+
+
+
 struct _ValaMemoryManagerPrivate {
 	ValaSymbol* current_symbol;
 };
@@ -61,13 +64,18 @@ static void vala_memory_manager_real_visit_block (ValaCodeVisitor* base, ValaBlo
 static void vala_memory_manager_real_visit_variable_declarator (ValaCodeVisitor* base, ValaVariableDeclarator* decl);
 static void vala_memory_manager_real_visit_initializer_list (ValaCodeVisitor* base, ValaInitializerList* list);
 static void vala_memory_manager_real_visit_expression_statement (ValaCodeVisitor* base, ValaExpressionStatement* stmt);
+static void vala_memory_manager_real_visit_if_statement (ValaCodeVisitor* base, ValaIfStatement* stmt);
 static void vala_memory_manager_real_visit_switch_section (ValaCodeVisitor* base, ValaSwitchSection* section);
+static void vala_memory_manager_real_visit_while_statement (ValaCodeVisitor* base, ValaWhileStatement* stmt);
+static void vala_memory_manager_real_visit_do_statement (ValaCodeVisitor* base, ValaDoStatement* stmt);
+static void vala_memory_manager_real_visit_for_statement (ValaCodeVisitor* base, ValaForStatement* stmt);
 static void vala_memory_manager_real_visit_foreach_statement (ValaCodeVisitor* base, ValaForeachStatement* stmt);
 static void vala_memory_manager_real_visit_return_statement (ValaCodeVisitor* base, ValaReturnStatement* stmt);
 static void vala_memory_manager_real_visit_throw_statement (ValaCodeVisitor* base, ValaThrowStatement* stmt);
 static void vala_memory_manager_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt);
 static void vala_memory_manager_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause);
 static void vala_memory_manager_real_visit_array_creation_expression (ValaCodeVisitor* base, ValaArrayCreationExpression* e);
+static void vala_memory_manager_real_visit_parenthesized_expression (ValaCodeVisitor* base, ValaParenthesizedExpression* expr);
 static void vala_memory_manager_real_visit_member_access (ValaCodeVisitor* base, ValaMemberAccess* expr);
 static void vala_memory_manager_real_visit_invocation_expression (ValaCodeVisitor* base, ValaInvocationExpression* expr);
 static void vala_memory_manager_real_visit_object_creation_expression (ValaCodeVisitor* base, ValaObjectCreationExpression* expr);
@@ -78,6 +86,7 @@ static gpointer vala_memory_manager_parent_class = NULL;
 static void vala_memory_manager_dispose (GObject * obj);
 
 
+
 /**
  * Analyze memory usage in the specified code context.
  *
@@ -85,15 +94,15 @@ static void vala_memory_manager_dispose (GObject * obj);
  */
 void vala_memory_manager_analyze (ValaMemoryManager* self, ValaCodeContext* context) {
 	g_return_if_fail (VALA_IS_MEMORY_MANAGER (self));
-	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
+	g_return_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context));
 	vala_code_context_accept (context, VALA_CODE_VISITOR (self));
 }
 
 
 static void vala_memory_manager_visit_possibly_leaked_expression (ValaMemoryManager* self, ValaExpression* expr) {
 	g_return_if_fail (VALA_IS_MEMORY_MANAGER (self));
-	g_return_if_fail (VALA_IS_EXPRESSION (expr));
-	if (vala_expression_get_static_type (expr) != NULL && ((vala_type_reference_get_data_type (vala_expression_get_static_type (expr)) != NULL && vala_data_type_is_reference_type (vala_type_reference_get_data_type (vala_expression_get_static_type (expr)))) || vala_type_reference_get_type_parameter (vala_expression_get_static_type (expr)) != NULL) && vala_type_reference_get_transfers_ownership (vala_expression_get_static_type (expr))) {
+	g_return_if_fail (expr == NULL || VALA_IS_EXPRESSION (expr));
+	if (vala_expression_get_static_type (expr) != NULL && vala_data_type_get_transfers_ownership (vala_expression_get_static_type (expr))) {
 		/* mark reference as leaked */
 		vala_expression_set_ref_leaked (expr, TRUE);
 	}
@@ -102,8 +111,8 @@ static void vala_memory_manager_visit_possibly_leaked_expression (ValaMemoryMana
 
 static void vala_memory_manager_visit_possibly_missing_copy_expression (ValaMemoryManager* self, ValaExpression* expr) {
 	g_return_if_fail (VALA_IS_MEMORY_MANAGER (self));
-	g_return_if_fail (VALA_IS_EXPRESSION (expr));
-	if (vala_expression_get_static_type (expr) != NULL && ((vala_type_reference_get_data_type (vala_expression_get_static_type (expr)) != NULL && vala_data_type_is_reference_type (vala_type_reference_get_data_type (vala_expression_get_static_type (expr)))) || vala_type_reference_get_type_parameter (vala_expression_get_static_type (expr)) != NULL) && !vala_type_reference_get_transfers_ownership (vala_expression_get_static_type (expr))) {
+	g_return_if_fail (expr == NULL || VALA_IS_EXPRESSION (expr));
+	if (vala_expression_get_static_type (expr) != NULL && !vala_data_type_get_transfers_ownership (vala_expression_get_static_type (expr)) && !(VALA_IS_NULL_TYPE (vala_expression_get_static_type (expr)))) {
 		/* mark reference as missing */
 		vala_expression_set_ref_missing (expr, TRUE);
 	}
@@ -113,7 +122,7 @@ static void vala_memory_manager_visit_possibly_missing_copy_expression (ValaMemo
 static void vala_memory_manager_real_visit_source_file (ValaCodeVisitor* base, ValaSourceFile* source_file) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_SOURCE_FILE (source_file));
+	g_return_if_fail (source_file == NULL || VALA_IS_SOURCE_FILE (source_file));
 	if (!vala_source_file_get_pkg (source_file)) {
 		vala_source_file_accept_children (source_file, VALA_CODE_VISITOR (self));
 	}
@@ -123,7 +132,7 @@ static void vala_memory_manager_real_visit_source_file (ValaCodeVisitor* base, V
 static void vala_memory_manager_real_visit_class (ValaCodeVisitor* base, ValaClass* cl) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_CLASS (cl));
+	g_return_if_fail (cl == NULL || VALA_IS_CLASS (cl));
 	vala_code_node_accept_children (VALA_CODE_NODE (cl), VALA_CODE_VISITOR (self));
 }
 
@@ -131,7 +140,7 @@ static void vala_memory_manager_real_visit_class (ValaCodeVisitor* base, ValaCla
 static void vala_memory_manager_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_STRUCT (st));
+	g_return_if_fail (st == NULL || VALA_IS_STRUCT (st));
 	vala_code_node_accept_children (VALA_CODE_NODE (st), VALA_CODE_VISITOR (self));
 }
 
@@ -139,7 +148,7 @@ static void vala_memory_manager_real_visit_struct (ValaCodeVisitor* base, ValaSt
 static void vala_memory_manager_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_INTERFACE (iface));
+	g_return_if_fail (iface == NULL || VALA_IS_INTERFACE (iface));
 	vala_code_node_accept_children (VALA_CODE_NODE (iface), VALA_CODE_VISITOR (self));
 }
 
@@ -147,12 +156,14 @@ static void vala_memory_manager_real_visit_interface (ValaCodeVisitor* base, Val
 static void vala_memory_manager_real_visit_field (ValaCodeVisitor* base, ValaField* f) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_FIELD (f));
+	g_return_if_fail (f == NULL || VALA_IS_FIELD (f));
 	if (vala_field_get_initializer (f) != NULL) {
-		if (vala_type_reference_get_takes_ownership (vala_field_get_type_reference (f))) {
-			vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_field_get_initializer (f));
-		} else {
-			vala_memory_manager_visit_possibly_leaked_expression (self, vala_field_get_initializer (f));
+		if (!(VALA_IS_POINTER_TYPE (vala_field_get_type_reference (f)))) {
+			if (vala_data_type_get_takes_ownership (vala_field_get_type_reference (f))) {
+				vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_field_get_initializer (f));
+			} else {
+				vala_memory_manager_visit_possibly_leaked_expression (self, vala_field_get_initializer (f));
+			}
 		}
 	}
 }
@@ -162,19 +173,21 @@ static void vala_memory_manager_real_visit_method (ValaCodeVisitor* base, ValaMe
 	ValaMemoryManager * self;
 	ValaSymbol* _tmp0;
 	ValaSymbol* old_symbol;
-	ValaSymbol* _tmp1;
-	ValaSymbol* _tmp3;
 	ValaSymbol* _tmp2;
+	ValaMethod* _tmp1;
+	ValaSymbol* _tmp4;
+	ValaSymbol* _tmp3;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_METHOD (m));
+	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
 	_tmp0 = NULL;
 	old_symbol = (_tmp0 = self->priv->current_symbol, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
-	_tmp1 = NULL;
-	self->priv->current_symbol = (_tmp1 = VALA_SYMBOL (g_object_ref (m)), (self->priv->current_symbol == NULL ? NULL : (self->priv->current_symbol = (g_object_unref (self->priv->current_symbol), NULL))), _tmp1);
-	vala_code_node_accept_children (VALA_CODE_NODE (m), VALA_CODE_VISITOR (self));
-	_tmp3 = NULL;
 	_tmp2 = NULL;
-	self->priv->current_symbol = (_tmp3 = (_tmp2 = old_symbol, (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (self->priv->current_symbol == NULL ? NULL : (self->priv->current_symbol = (g_object_unref (self->priv->current_symbol), NULL))), _tmp3);
+	_tmp1 = NULL;
+	self->priv->current_symbol = (_tmp2 = VALA_SYMBOL ((_tmp1 = m, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)))), (self->priv->current_symbol == NULL ? NULL : (self->priv->current_symbol = (g_object_unref (self->priv->current_symbol), NULL))), _tmp2);
+	vala_code_node_accept_children (VALA_CODE_NODE (m), VALA_CODE_VISITOR (self));
+	_tmp4 = NULL;
+	_tmp3 = NULL;
+	self->priv->current_symbol = (_tmp4 = (_tmp3 = old_symbol, (_tmp3 == NULL ? NULL : g_object_ref (_tmp3))), (self->priv->current_symbol == NULL ? NULL : (self->priv->current_symbol = (g_object_unref (self->priv->current_symbol), NULL))), _tmp4);
 	(old_symbol == NULL ? NULL : (old_symbol = (g_object_unref (old_symbol), NULL)));
 }
 
@@ -182,18 +195,20 @@ static void vala_memory_manager_real_visit_method (ValaCodeVisitor* base, ValaMe
 static void vala_memory_manager_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_CREATION_METHOD (m));
+	g_return_if_fail (m == NULL || VALA_IS_CREATION_METHOD (m));
 	vala_code_visitor_visit_method (VALA_CODE_VISITOR (self), VALA_METHOD (m));
 }
 
 
 static void vala_memory_manager_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop) {
 	ValaMemoryManager * self;
-	ValaSymbol* _tmp0;
+	ValaSymbol* _tmp1;
+	ValaProperty* _tmp0;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_PROPERTY (prop));
+	g_return_if_fail (prop == NULL || VALA_IS_PROPERTY (prop));
+	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->current_symbol = (_tmp0 = VALA_SYMBOL (g_object_ref (prop)), (self->priv->current_symbol == NULL ? NULL : (self->priv->current_symbol = (g_object_unref (self->priv->current_symbol), NULL))), _tmp0);
+	self->priv->current_symbol = (_tmp1 = VALA_SYMBOL ((_tmp0 = prop, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)))), (self->priv->current_symbol == NULL ? NULL : (self->priv->current_symbol = (g_object_unref (self->priv->current_symbol), NULL))), _tmp1);
 	vala_code_node_accept_children (VALA_CODE_NODE (prop), VALA_CODE_VISITOR (self));
 }
 
@@ -201,7 +216,7 @@ static void vala_memory_manager_real_visit_property (ValaCodeVisitor* base, Vala
 static void vala_memory_manager_real_visit_property_accessor (ValaCodeVisitor* base, ValaPropertyAccessor* acc) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (acc));
+	g_return_if_fail (acc == NULL || VALA_IS_PROPERTY_ACCESSOR (acc));
 	vala_code_node_accept_children (VALA_CODE_NODE (acc), VALA_CODE_VISITOR (self));
 }
 
@@ -209,7 +224,7 @@ static void vala_memory_manager_real_visit_property_accessor (ValaCodeVisitor* b
 static void vala_memory_manager_real_visit_constructor (ValaCodeVisitor* base, ValaConstructor* c) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_CONSTRUCTOR (c));
+	g_return_if_fail (c == NULL || VALA_IS_CONSTRUCTOR (c));
 	vala_code_node_accept_children (VALA_CODE_NODE (c), VALA_CODE_VISITOR (self));
 }
 
@@ -217,7 +232,7 @@ static void vala_memory_manager_real_visit_constructor (ValaCodeVisitor* base, V
 static void vala_memory_manager_real_visit_destructor (ValaCodeVisitor* base, ValaDestructor* d) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_DESTRUCTOR (d));
+	g_return_if_fail (d == NULL || VALA_IS_DESTRUCTOR (d));
 	vala_code_node_accept_children (VALA_CODE_NODE (d), VALA_CODE_VISITOR (self));
 }
 
@@ -225,7 +240,7 @@ static void vala_memory_manager_real_visit_destructor (ValaCodeVisitor* base, Va
 static void vala_memory_manager_real_visit_named_argument (ValaCodeVisitor* base, ValaNamedArgument* n) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_NAMED_ARGUMENT (n));
+	g_return_if_fail (n == NULL || VALA_IS_NAMED_ARGUMENT (n));
 	vala_memory_manager_visit_possibly_leaked_expression (self, vala_named_argument_get_argument (n));
 }
 
@@ -233,7 +248,7 @@ static void vala_memory_manager_real_visit_named_argument (ValaCodeVisitor* base
 static void vala_memory_manager_real_visit_block (ValaCodeVisitor* base, ValaBlock* b) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_BLOCK (b));
+	g_return_if_fail (b == NULL || VALA_IS_BLOCK (b));
 	vala_code_node_accept_children (VALA_CODE_NODE (b), VALA_CODE_VISITOR (self));
 }
 
@@ -241,13 +256,15 @@ static void vala_memory_manager_real_visit_block (ValaCodeVisitor* base, ValaBlo
 static void vala_memory_manager_real_visit_variable_declarator (ValaCodeVisitor* base, ValaVariableDeclarator* decl) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_VARIABLE_DECLARATOR (decl));
+	g_return_if_fail (decl == NULL || VALA_IS_VARIABLE_DECLARATOR (decl));
 	vala_code_node_accept_children (VALA_CODE_NODE (decl), VALA_CODE_VISITOR (self));
 	if (vala_variable_declarator_get_initializer (decl) != NULL) {
-		if (vala_type_reference_get_takes_ownership (vala_variable_declarator_get_type_reference (decl))) {
-			vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_variable_declarator_get_initializer (decl));
-		} else {
-			vala_memory_manager_visit_possibly_leaked_expression (self, vala_variable_declarator_get_initializer (decl));
+		if (!(VALA_IS_POINTER_TYPE (vala_variable_declarator_get_type_reference (decl)))) {
+			if (vala_data_type_get_takes_ownership (vala_variable_declarator_get_type_reference (decl))) {
+				vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_variable_declarator_get_initializer (decl));
+			} else {
+				vala_memory_manager_visit_possibly_leaked_expression (self, vala_variable_declarator_get_initializer (decl));
+			}
 		}
 	}
 }
@@ -256,7 +273,7 @@ static void vala_memory_manager_real_visit_variable_declarator (ValaCodeVisitor*
 static void vala_memory_manager_real_visit_initializer_list (ValaCodeVisitor* base, ValaInitializerList* list) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_INITIALIZER_LIST (list));
+	g_return_if_fail (list == NULL || VALA_IS_INITIALIZER_LIST (list));
 	vala_code_node_accept_children (VALA_CODE_NODE (list), VALA_CODE_VISITOR (self));
 }
 
@@ -264,23 +281,55 @@ static void vala_memory_manager_real_visit_initializer_list (ValaCodeVisitor* ba
 static void vala_memory_manager_real_visit_expression_statement (ValaCodeVisitor* base, ValaExpressionStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_EXPRESSION_STATEMENT (stmt));
+	g_return_if_fail (stmt == NULL || VALA_IS_EXPRESSION_STATEMENT (stmt));
 	vala_memory_manager_visit_possibly_leaked_expression (self, vala_expression_statement_get_expression (stmt));
 }
 
 
+static void vala_memory_manager_real_visit_if_statement (ValaCodeVisitor* base, ValaIfStatement* stmt) {
+	ValaMemoryManager * self;
+	self = VALA_MEMORY_MANAGER (base);
+	g_return_if_fail (stmt == NULL || VALA_IS_IF_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_memory_manager_real_visit_switch_section (ValaCodeVisitor* base, ValaSwitchSection* section) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_SWITCH_SECTION (section));
+	g_return_if_fail (section == NULL || VALA_IS_SWITCH_SECTION (section));
 	vala_code_node_accept_children (VALA_CODE_NODE (section), VALA_CODE_VISITOR (self));
 }
 
 
+static void vala_memory_manager_real_visit_while_statement (ValaCodeVisitor* base, ValaWhileStatement* stmt) {
+	ValaMemoryManager * self;
+	self = VALA_MEMORY_MANAGER (base);
+	g_return_if_fail (stmt == NULL || VALA_IS_WHILE_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_memory_manager_real_visit_do_statement (ValaCodeVisitor* base, ValaDoStatement* stmt) {
+	ValaMemoryManager * self;
+	self = VALA_MEMORY_MANAGER (base);
+	g_return_if_fail (stmt == NULL || VALA_IS_DO_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_memory_manager_real_visit_for_statement (ValaCodeVisitor* base, ValaForStatement* stmt) {
+	ValaMemoryManager * self;
+	self = VALA_MEMORY_MANAGER (base);
+	g_return_if_fail (stmt == NULL || VALA_IS_FOR_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_memory_manager_real_visit_foreach_statement (ValaCodeVisitor* base, ValaForeachStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (stmt));
+	g_return_if_fail (stmt == NULL || VALA_IS_FOREACH_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -288,7 +337,7 @@ static void vala_memory_manager_real_visit_foreach_statement (ValaCodeVisitor* b
 static void vala_memory_manager_real_visit_return_statement (ValaCodeVisitor* base, ValaReturnStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_RETURN_STATEMENT (stmt));
+	g_return_if_fail (stmt == NULL || VALA_IS_RETURN_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 	if (vala_return_statement_get_return_expression (stmt) != NULL) {
 		if (VALA_IS_METHOD (self->priv->current_symbol)) {
@@ -296,15 +345,30 @@ static void vala_memory_manager_real_visit_return_statement (ValaCodeVisitor* ba
 			ValaMethod* m;
 			_tmp0 = NULL;
 			m = (_tmp0 = VALA_METHOD (self->priv->current_symbol), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
-			if (vala_type_reference_get_transfers_ownership (vala_method_get_return_type (m))) {
-				vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_return_statement_get_return_expression (stmt));
-			} else {
-				vala_memory_manager_visit_possibly_leaked_expression (self, vala_return_statement_get_return_expression (stmt));
+			if (!(VALA_IS_POINTER_TYPE (vala_method_get_return_type (m)))) {
+				if (vala_data_type_get_transfers_ownership (vala_method_get_return_type (m))) {
+					vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_return_statement_get_return_expression (stmt));
+				} else {
+					vala_memory_manager_visit_possibly_leaked_expression (self, vala_return_statement_get_return_expression (stmt));
+				}
 			}
 			(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
 		} else {
-			/* property get accessor */
-			vala_memory_manager_visit_possibly_leaked_expression (self, vala_return_statement_get_return_expression (stmt));
+			if (VALA_IS_PROPERTY (self->priv->current_symbol)) {
+				ValaProperty* _tmp1;
+				ValaProperty* prop;
+				/* property get accessor */
+				_tmp1 = NULL;
+				prop = (_tmp1 = VALA_PROPERTY (self->priv->current_symbol), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+				if (vala_data_type_get_transfers_ownership (vala_property_get_type_reference (prop))) {
+					vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_return_statement_get_return_expression (stmt));
+				} else {
+					vala_memory_manager_visit_possibly_leaked_expression (self, vala_return_statement_get_return_expression (stmt));
+				}
+				(prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL)));
+			} else {
+				g_assert_not_reached ();
+			}
 		}
 	}
 }
@@ -313,7 +377,7 @@ static void vala_memory_manager_real_visit_return_statement (ValaCodeVisitor* ba
 static void vala_memory_manager_real_visit_throw_statement (ValaCodeVisitor* base, ValaThrowStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_THROW_STATEMENT (stmt));
+	g_return_if_fail (stmt == NULL || VALA_IS_THROW_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -321,7 +385,7 @@ static void vala_memory_manager_real_visit_throw_statement (ValaCodeVisitor* bas
 static void vala_memory_manager_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_TRY_STATEMENT (stmt));
+	g_return_if_fail (stmt == NULL || VALA_IS_TRY_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -329,7 +393,7 @@ static void vala_memory_manager_real_visit_try_statement (ValaCodeVisitor* base,
 static void vala_memory_manager_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_CATCH_CLAUSE (clause));
+	g_return_if_fail (clause == NULL || VALA_IS_CATCH_CLAUSE (clause));
 	vala_code_node_accept_children (VALA_CODE_NODE (clause), VALA_CODE_VISITOR (self));
 }
 
@@ -337,7 +401,7 @@ static void vala_memory_manager_real_visit_catch_clause (ValaCodeVisitor* base,
 static void vala_memory_manager_real_visit_array_creation_expression (ValaCodeVisitor* base, ValaArrayCreationExpression* e) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (e));
+	g_return_if_fail (e == NULL || VALA_IS_ARRAY_CREATION_EXPRESSION (e));
 	if (vala_array_creation_expression_get_initializer_list (e) != NULL) {
 		{
 			GeeCollection* init_collection;
@@ -346,9 +410,13 @@ static void vala_memory_manager_real_visit_array_creation_expression (ValaCodeVi
 			init_it = gee_iterable_iterator (GEE_ITERABLE (init_collection));
 			while (gee_iterator_next (init_it)) {
 				ValaExpression* init;
-				init = gee_iterator_get (init_it);
+				init = ((ValaExpression*) gee_iterator_get (init_it));
 				{
-					vala_memory_manager_visit_possibly_missing_copy_expression (self, init);
+					if (vala_data_type_is_reference_type_or_type_parameter (vala_expression_get_static_type (init))) {
+						vala_memory_manager_visit_possibly_missing_copy_expression (self, init);
+					} else {
+						vala_memory_manager_visit_possibly_leaked_expression (self, init);
+					}
 					(init == NULL ? NULL : (init = (g_object_unref (init), NULL)));
 				}
 			}
@@ -359,10 +427,18 @@ static void vala_memory_manager_real_visit_array_creation_expression (ValaCodeVi
 }
 
 
+static void vala_memory_manager_real_visit_parenthesized_expression (ValaCodeVisitor* base, ValaParenthesizedExpression* expr) {
+	ValaMemoryManager * self;
+	self = VALA_MEMORY_MANAGER (base);
+	g_return_if_fail (expr == NULL || VALA_IS_PARENTHESIZED_EXPRESSION (expr));
+	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_memory_manager_real_visit_member_access (ValaCodeVisitor* base, ValaMemberAccess* expr) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_MEMBER_ACCESS (expr));
+	g_return_if_fail (expr == NULL || VALA_IS_MEMBER_ACCESS (expr));
 	if (vala_member_access_get_inner (expr) != NULL) {
 		vala_memory_manager_visit_possibly_leaked_expression (self, vala_member_access_get_inner (expr));
 	}
@@ -371,16 +447,16 @@ static void vala_memory_manager_real_visit_member_access (ValaCodeVisitor* base,
 
 static void vala_memory_manager_real_visit_invocation_expression (ValaCodeVisitor* base, ValaInvocationExpression* expr) {
 	ValaMemoryManager * self;
-	ValaInvokable* _tmp0;
-	ValaInvokable* msym;
+	ValaDataType* _tmp0;
+	ValaDataType* mtype;
 	GeeCollection* params;
 	GeeIterator* params_it;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (expr));
+	g_return_if_fail (expr == NULL || VALA_IS_INVOCATION_EXPRESSION (expr));
 	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
 	_tmp0 = NULL;
-	msym = (_tmp0 = VALA_INVOKABLE (vala_expression_get_symbol_reference (vala_invocation_expression_get_call (expr))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
-	params = vala_invokable_get_parameters (msym);
+	mtype = (_tmp0 = vala_expression_get_static_type (vala_invocation_expression_get_call (expr)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	params = vala_data_type_get_parameters (mtype);
 	params_it = gee_iterable_iterator (GEE_ITERABLE (params));
 	{
 		GeeCollection* arg_collection;
@@ -389,24 +465,24 @@ static void vala_memory_manager_real_visit_invocation_expression (ValaCodeVisito
 		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
 		while (gee_iterator_next (arg_it)) {
 			ValaExpression* arg;
-			arg = gee_iterator_get (arg_it);
+			arg = ((ValaExpression*) gee_iterator_get (arg_it));
 			{
 				if (gee_iterator_next (params_it)) {
 					ValaFormalParameter* param;
-					param = gee_iterator_get (params_it);
-					if (!vala_formal_parameter_get_ellipsis (param) && ((vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (param)) != NULL && vala_data_type_is_reference_type (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (param)))) || vala_type_reference_get_type_parameter (vala_formal_parameter_get_type_reference (param)) != NULL)) {
+					param = ((ValaFormalParameter*) gee_iterator_get (params_it));
+					if (!vala_formal_parameter_get_ellipsis (param) && vala_data_type_is_reference_type_or_type_parameter (vala_formal_parameter_get_type_reference (param))) {
 						gboolean is_ref;
-						is_ref = vala_type_reference_get_takes_ownership (vala_formal_parameter_get_type_reference (param));
-						if (is_ref && vala_type_reference_get_type_parameter (vala_formal_parameter_get_type_reference (param)) != NULL) {
+						is_ref = vala_data_type_get_transfers_ownership (vala_formal_parameter_get_type_reference (param));
+						if (is_ref && vala_data_type_get_type_parameter (vala_formal_parameter_get_type_reference (param)) != NULL) {
 							if (VALA_IS_MEMBER_ACCESS (vala_invocation_expression_get_call (expr))) {
 								ValaMemberAccess* _tmp1;
 								ValaMemberAccess* ma;
-								ValaTypeReference* param_type;
+								ValaDataType* param_type;
 								_tmp1 = NULL;
 								ma = (_tmp1 = VALA_MEMBER_ACCESS (vala_invocation_expression_get_call (expr)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
-								param_type = vala_semantic_analyzer_get_actual_type (vala_expression_get_static_type (vala_member_access_get_inner (ma)), VALA_SYMBOL (msym), vala_formal_parameter_get_type_reference (param), VALA_CODE_NODE (expr));
+								param_type = vala_semantic_analyzer_get_actual_type (vala_expression_get_static_type (vala_member_access_get_inner (ma)), vala_expression_get_symbol_reference (VALA_EXPRESSION (ma)), vala_formal_parameter_get_type_reference (param), VALA_CODE_NODE (expr));
 								if (param_type != NULL) {
-									is_ref = vala_type_reference_get_takes_ownership (param_type);
+									is_ref = vala_data_type_get_takes_ownership (param_type);
 								}
 								(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
 								(param_type == NULL ? NULL : (param_type = (g_object_unref (param_type), NULL)));
@@ -430,7 +506,7 @@ static void vala_memory_manager_real_visit_invocation_expression (ValaCodeVisito
 		(arg_collection == NULL ? NULL : (arg_collection = (g_object_unref (arg_collection), NULL)));
 		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
-	(msym == NULL ? NULL : (msym = (g_object_unref (msym), NULL)));
+	(mtype == NULL ? NULL : (mtype = (g_object_unref (mtype), NULL)));
 	(params == NULL ? NULL : (params = (g_object_unref (params), NULL)));
 	(params_it == NULL ? NULL : (params_it = (g_object_unref (params_it), NULL)));
 }
@@ -438,19 +514,19 @@ static void vala_memory_manager_real_visit_invocation_expression (ValaCodeVisito
 
 static void vala_memory_manager_real_visit_object_creation_expression (ValaCodeVisitor* base, ValaObjectCreationExpression* expr) {
 	ValaMemoryManager * self;
-	ValaInvokable* _tmp0;
-	ValaInvokable* msym;
+	ValaMethod* _tmp0;
+	ValaMethod* msym;
 	GeeCollection* params;
 	GeeIterator* params_it;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (expr));
+	g_return_if_fail (expr == NULL || VALA_IS_OBJECT_CREATION_EXPRESSION (expr));
 	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
-	if (!(VALA_IS_INVOKABLE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))))) {
+	if (!(VALA_IS_METHOD (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))))) {
 		return;
 	}
 	_tmp0 = NULL;
-	msym = (_tmp0 = VALA_INVOKABLE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
-	params = vala_invokable_get_parameters (msym);
+	msym = (_tmp0 = VALA_METHOD (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	params = vala_method_get_parameters (msym);
 	params_it = gee_iterable_iterator (GEE_ITERABLE (params));
 	{
 		GeeCollection* arg_collection;
@@ -459,19 +535,19 @@ static void vala_memory_manager_real_visit_object_creation_expression (ValaCodeV
 		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
 		while (gee_iterator_next (arg_it)) {
 			ValaExpression* arg;
-			arg = gee_iterator_get (arg_it);
+			arg = ((ValaExpression*) gee_iterator_get (arg_it));
 			{
 				if (gee_iterator_next (params_it)) {
 					ValaFormalParameter* param;
-					param = gee_iterator_get (params_it);
-					if (!vala_formal_parameter_get_ellipsis (param) && ((vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (param)) != NULL && vala_data_type_is_reference_type (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (param)))) || vala_type_reference_get_type_parameter (vala_formal_parameter_get_type_reference (param)) != NULL)) {
+					param = ((ValaFormalParameter*) gee_iterator_get (params_it));
+					if (!vala_formal_parameter_get_ellipsis (param) && vala_data_type_is_reference_type_or_type_parameter (vala_formal_parameter_get_type_reference (param))) {
 						gboolean is_ref;
-						is_ref = vala_type_reference_get_takes_ownership (vala_formal_parameter_get_type_reference (param));
-						if (is_ref && vala_type_reference_get_type_parameter (vala_formal_parameter_get_type_reference (param)) != NULL) {
-							ValaTypeReference* param_type;
+						is_ref = vala_data_type_get_transfers_ownership (vala_formal_parameter_get_type_reference (param));
+						if (is_ref && vala_data_type_get_type_parameter (vala_formal_parameter_get_type_reference (param)) != NULL) {
+							ValaDataType* param_type;
 							param_type = vala_semantic_analyzer_get_actual_type (vala_object_creation_expression_get_type_reference (expr), VALA_SYMBOL (msym), vala_formal_parameter_get_type_reference (param), VALA_CODE_NODE (expr));
 							if (param_type != NULL) {
-								is_ref = vala_type_reference_get_takes_ownership (param_type);
+								is_ref = vala_data_type_get_takes_ownership (param_type);
 							}
 							(param_type == NULL ? NULL : (param_type = (g_object_unref (param_type), NULL)));
 						}
@@ -502,7 +578,7 @@ static void vala_memory_manager_real_visit_object_creation_expression (ValaCodeV
 static void vala_memory_manager_real_visit_binary_expression (ValaCodeVisitor* base, ValaBinaryExpression* expr) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_BINARY_EXPRESSION (expr));
+	g_return_if_fail (expr == NULL || VALA_IS_BINARY_EXPRESSION (expr));
 	vala_memory_manager_visit_possibly_leaked_expression (self, vala_binary_expression_get_left (expr));
 	vala_memory_manager_visit_possibly_leaked_expression (self, vala_binary_expression_get_right (expr));
 }
@@ -511,7 +587,7 @@ static void vala_memory_manager_real_visit_binary_expression (ValaCodeVisitor* b
 static void vala_memory_manager_real_visit_lambda_expression (ValaCodeVisitor* base, ValaLambdaExpression* l) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_LAMBDA_EXPRESSION (l));
+	g_return_if_fail (l == NULL || VALA_IS_LAMBDA_EXPRESSION (l));
 	vala_code_node_accept_children (VALA_CODE_NODE (l), VALA_CODE_VISITOR (self));
 }
 
@@ -519,14 +595,16 @@ static void vala_memory_manager_real_visit_lambda_expression (ValaCodeVisitor* b
 static void vala_memory_manager_real_visit_assignment (ValaCodeVisitor* base, ValaAssignment* a) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (VALA_IS_ASSIGNMENT (a));
+	g_return_if_fail (a == NULL || VALA_IS_ASSIGNMENT (a));
 	vala_code_node_accept_children (VALA_CODE_NODE (a), VALA_CODE_VISITOR (self));
 	if (VALA_IS_POINTER_INDIRECTION (vala_assignment_get_left (a)) || VALA_IS_SIGNAL (vala_expression_get_symbol_reference (vala_assignment_get_left (a)))) {
 	} else {
-		if (vala_type_reference_get_takes_ownership (vala_expression_get_static_type (vala_assignment_get_left (a)))) {
-			vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_assignment_get_right (a));
-		} else {
-			vala_memory_manager_visit_possibly_leaked_expression (self, vala_assignment_get_right (a));
+		if (!(VALA_IS_POINTER_TYPE (vala_expression_get_static_type (vala_assignment_get_left (a))))) {
+			if (vala_data_type_get_takes_ownership (vala_expression_get_static_type (vala_assignment_get_left (a)))) {
+				vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_assignment_get_right (a));
+			} else {
+				vala_memory_manager_visit_possibly_leaked_expression (self, vala_assignment_get_right (a));
+			}
 		}
 	}
 }
@@ -563,13 +641,18 @@ static void vala_memory_manager_class_init (ValaMemoryManagerClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_variable_declarator = vala_memory_manager_real_visit_variable_declarator;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_initializer_list = vala_memory_manager_real_visit_initializer_list;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_expression_statement = vala_memory_manager_real_visit_expression_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_if_statement = vala_memory_manager_real_visit_if_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_switch_section = vala_memory_manager_real_visit_switch_section;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_while_statement = vala_memory_manager_real_visit_while_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_do_statement = vala_memory_manager_real_visit_do_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_for_statement = vala_memory_manager_real_visit_for_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_foreach_statement = vala_memory_manager_real_visit_foreach_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_return_statement = vala_memory_manager_real_visit_return_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_throw_statement = vala_memory_manager_real_visit_throw_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_try_statement = vala_memory_manager_real_visit_try_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_catch_clause = vala_memory_manager_real_visit_catch_clause;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_array_creation_expression = vala_memory_manager_real_visit_array_creation_expression;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_parenthesized_expression = vala_memory_manager_real_visit_parenthesized_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_member_access = vala_memory_manager_real_visit_member_access;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_invocation_expression = vala_memory_manager_real_visit_invocation_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_object_creation_expression = vala_memory_manager_real_visit_object_creation_expression;
