@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #ifndef __VALA_VALAMEMORYMANAGER_H__
@@ -44,13 +44,18 @@
 #include <vala/valavariabledeclarator.h>
 #include <vala/valainitializerlist.h>
 #include <vala/valaexpressionstatement.h>
+#include <vala/valaifstatement.h>
 #include <vala/valaswitchsection.h>
+#include <vala/valawhilestatement.h>
+#include <vala/valadostatement.h>
+#include <vala/valaforstatement.h>
 #include <vala/valaforeachstatement.h>
 #include <vala/valareturnstatement.h>
 #include <vala/valathrowstatement.h>
 #include <vala/valatrystatement.h>
 #include <vala/valacatchclause.h>
 #include <vala/valaarraycreationexpression.h>
+#include <vala/valaparenthesizedexpression.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valainvocationexpression.h>
 #include <vala/valaobjectcreationexpression.h>
@@ -88,6 +93,7 @@ void vala_memory_manager_analyze (ValaMemoryManager* self, ValaCodeContext* cont
 ValaMemoryManager* vala_memory_manager_new (void);
 GType vala_memory_manager_get_type (void);
 
+
 G_END_DECLS
 
 #endif
