@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <vala/valamethod.h>
@@ -27,29 +27,36 @@
 #include <gee/readonlycollection.h>
 #include <gee/iterable.h>
 #include <gee/iterator.h>
-#include <vala/valablock.h>
+#include <vala/valabasicblock.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valavariabledeclarator.h>
 #include <vala/valadatatype.h>
 #include <vala/valaexpression.h>
+#include <vala/valablock.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
+
+
+
 struct _ValaMethodPrivate {
-	ValaBlock* _body;
+	ValaBasicBlock* _entry_block;
+	ValaBasicBlock* _exit_block;
 	gboolean _is_abstract;
 	gboolean _is_virtual;
 	gboolean _overrides;
 	gboolean _is_inline;
 	gboolean _returns_modified_pointer;
-	gboolean _instance_last;
 	ValaMethod* _base_method;
 	ValaMethod* _base_interface_method;
 	ValaFormalParameter* _this_parameter;
 	ValaVariableDeclarator* _result_var;
+	double _cinstance_parameter_position;
+	double _carray_length_parameter_position;
+	double _cdelegate_target_parameter_position;
 	gboolean _printf_format;
 	gboolean _instance;
 	GeeList* parameters;
@@ -61,12 +68,15 @@ struct _ValaMethodPrivate {
 	GeeList* preconditions;
 	GeeList* postconditions;
 	ValaDataType* _return_type;
+	ValaBlock* _body;
 };
 #define VALA_METHOD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_METHOD, ValaMethodPrivate))
 enum  {
 	VALA_METHOD_DUMMY_PROPERTY,
 	VALA_METHOD_RETURN_TYPE,
 	VALA_METHOD_BODY,
+	VALA_METHOD_ENTRY_BLOCK,
+	VALA_METHOD_EXIT_BLOCK,
 	VALA_METHOD_INSTANCE,
 	VALA_METHOD_VFUNC_NAME,
 	VALA_METHOD_SENTINEL,
@@ -75,11 +85,13 @@ enum  {
 	VALA_METHOD_OVERRIDES,
 	VALA_METHOD_IS_INLINE,
 	VALA_METHOD_RETURNS_MODIFIED_POINTER,
-	VALA_METHOD_INSTANCE_LAST,
 	VALA_METHOD_BASE_METHOD,
 	VALA_METHOD_BASE_INTERFACE_METHOD,
 	VALA_METHOD_THIS_PARAMETER,
 	VALA_METHOD_RESULT_VAR,
+	VALA_METHOD_CINSTANCE_PARAMETER_POSITION,
+	VALA_METHOD_CARRAY_LENGTH_PARAMETER_POSITION,
+	VALA_METHOD_CDELEGATE_TARGET_PARAMETER_POSITION,
 	VALA_METHOD_NO_ARRAY_LENGTH,
 	VALA_METHOD_PRINTF_FORMAT
 };
@@ -88,9 +100,12 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 static char* vala_method_real_get_default_cname (ValaMethod* self);
 static void vala_method_process_ccode_attribute (ValaMethod* self, ValaAttribute* a);
 static void vala_method_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static GObject * vala_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_method_parent_class = NULL;
 static void vala_method_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static int _vala_strcmp0 (const char * str1, const char * str2);
+
 
 
 /**
@@ -124,6 +139,10 @@ void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param) {
 	if (vala_method_get_no_array_length (self)) {
 		vala_formal_parameter_set_no_array_length (param, TRUE);
 	}
+	/* default C parameter position*/
+	vala_formal_parameter_set_cparameter_position (param, ((double) gee_collection_get_size (GEE_COLLECTION (self->priv->parameters)) + 1));
+	vala_formal_parameter_set_carray_length_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
+	vala_formal_parameter_set_cdelegate_target_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
 	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
 	if (!vala_formal_parameter_get_ellipsis (param)) {
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (param)), VALA_SYMBOL (param));
@@ -159,7 +178,7 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
 		while (gee_iterator_next (param_it)) {
 			ValaFormalParameter* param;
-			param = gee_iterator_get (param_it);
+			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (param), visitor);
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
@@ -174,7 +193,7 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 		error_domain_it = gee_iterable_iterator (GEE_ITERABLE (error_domain_collection));
 		while (gee_iterator_next (error_domain_it)) {
 			ValaDataType* error_domain;
-			error_domain = gee_iterator_get (error_domain_it);
+			error_domain = ((ValaDataType*) gee_iterator_get (error_domain_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (error_domain), visitor);
 				(error_domain == NULL ? NULL : (error_domain = (g_object_unref (error_domain), NULL)));
@@ -182,8 +201,8 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 		}
 		(error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL)));
 	}
-	if (vala_method_get_result_var (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_variable_declarator_get_type_reference (vala_method_get_result_var (self))), visitor);
+	if (self->priv->_result_var != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (vala_variable_declarator_get_type_reference (self->priv->_result_var)), visitor);
 	}
 	{
 		GeeList* precondition_collection;
@@ -192,7 +211,7 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 		precondition_it = gee_iterable_iterator (GEE_ITERABLE (precondition_collection));
 		while (gee_iterator_next (precondition_it)) {
 			ValaExpression* precondition;
-			precondition = gee_iterator_get (precondition_it);
+			precondition = ((ValaExpression*) gee_iterator_get (precondition_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (precondition), visitor);
 				(precondition == NULL ? NULL : (precondition = (g_object_unref (precondition), NULL)));
@@ -207,7 +226,7 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 		postcondition_it = gee_iterable_iterator (GEE_ITERABLE (postcondition_collection));
 		while (gee_iterator_next (postcondition_it)) {
 			ValaExpression* postcondition;
-			postcondition = gee_iterator_get (postcondition_it);
+			postcondition = ((ValaExpression*) gee_iterator_get (postcondition_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (postcondition), visitor);
 				(postcondition == NULL ? NULL : (postcondition = (g_object_unref (postcondition), NULL)));
@@ -247,26 +266,29 @@ char* vala_method_get_cname (ValaMethod* self) {
  */
 static char* vala_method_real_get_default_cname (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
-	if (g_str_has_prefix (vala_symbol_get_name (VALA_SYMBOL (self)), "_")) {
-		char* _tmp0;
-		char* _tmp1;
-		_tmp0 = NULL;
-		_tmp1 = NULL;
-		return (_tmp1 = g_strdup_printf ("_%s%s", (_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), g_utf8_offset_to_pointer (vala_symbol_get_name (VALA_SYMBOL (self)), 1)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	if (_vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (self)), "main") == 0 && vala_symbol_get_name (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))) == NULL) {
+		return g_strdup ("_main");
 	} else {
-		char* _tmp3;
-		char* _tmp4;
-		_tmp3 = NULL;
-		_tmp4 = NULL;
-		return (_tmp4 = g_strdup_printf ("%s%s", (_tmp3 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (_tmp3 = (g_free (_tmp3), NULL)), _tmp4);
+		/* avoid conflict with generated main function*/
+		if (g_str_has_prefix (vala_symbol_get_name (VALA_SYMBOL (self)), "_")) {
+			char* _tmp1;
+			char* _tmp2;
+			_tmp1 = NULL;
+			_tmp2 = NULL;
+			return (_tmp2 = g_strdup_printf ("_%s%s", (_tmp1 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), g_utf8_offset_to_pointer (vala_symbol_get_name (VALA_SYMBOL (self)), ((glong) 1))), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
+		} else {
+			char* _tmp4;
+			char* _tmp5;
+			_tmp4 = NULL;
+			_tmp5 = NULL;
+			return (_tmp5 = g_strdup_printf ("%s%s", (_tmp4 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (_tmp4 = (g_free (_tmp4), NULL)), _tmp5);
+		}
 	}
 }
 
 
 char* vala_method_get_default_cname (ValaMethod* self) {
-	char* result;
-	result = VALA_METHOD_GET_CLASS (self)->get_default_cname (self);
-	return result;
+	return VALA_METHOD_GET_CLASS (self)->get_default_cname (self);
 }
 
 
@@ -278,7 +300,7 @@ char* vala_method_get_default_cname (ValaMethod* self) {
  */
 char* vala_method_get_real_cname (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
-	if (vala_method_get_base_method (self) != NULL || vala_method_get_base_interface_method (self) != NULL) {
+	if (self->priv->_base_method != NULL || self->priv->_base_interface_method != NULL) {
 		char* _tmp0;
 		char* _tmp1;
 		_tmp0 = NULL;
@@ -312,7 +334,7 @@ static void vala_method_process_ccode_attribute (ValaMethod* self, ValaAttribute
 		char* _tmp0;
 		_tmp0 = NULL;
 		vala_method_set_cname (self, (_tmp0 = vala_attribute_get_string (a, "cname")));
-		(_tmp0 = (g_free (_tmp0), NULL));
+		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
@@ -330,24 +352,33 @@ static void vala_method_process_ccode_attribute (ValaMethod* self, ValaAttribute
 				filename = (_tmp1 = *filename_it, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 				{
 					vala_member_add_cheader_filename (VALA_MEMBER (self), filename);
-					(filename = (g_free (filename), NULL));
+					filename = (g_free (filename), NULL);
 				}
 			}
-			(filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL));
+			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL);
 		}
-		(val = (g_free (val), NULL));
+		val = (g_free (val), NULL);
 	}
 	if (vala_attribute_has_argument (a, "vfunc_name")) {
 		char* _tmp2;
 		_tmp2 = NULL;
 		vala_method_set_vfunc_name (self, (_tmp2 = vala_attribute_get_string (a, "vfunc_name")));
-		(_tmp2 = (g_free (_tmp2), NULL));
+		_tmp2 = (g_free (_tmp2), NULL);
 	}
 	if (vala_attribute_has_argument (a, "sentinel")) {
 		char* _tmp3;
 		_tmp3 = NULL;
 		vala_method_set_sentinel (self, (_tmp3 = vala_attribute_get_string (a, "sentinel")));
-		(_tmp3 = (g_free (_tmp3), NULL));
+		_tmp3 = (g_free (_tmp3), NULL);
+	}
+	if (vala_attribute_has_argument (a, "instance_pos")) {
+		vala_method_set_cinstance_parameter_position (self, vala_attribute_get_double (a, "instance_pos"));
+	}
+	if (vala_attribute_has_argument (a, "array_length_pos")) {
+		vala_method_set_carray_length_parameter_position (self, vala_attribute_get_double (a, "array_length_pos"));
+	}
+	if (vala_attribute_has_argument (a, "delegate_target_pos")) {
+		vala_method_set_cdelegate_target_parameter_position (self, vala_attribute_get_double (a, "delegate_target_pos"));
 	}
 }
 
@@ -365,29 +396,25 @@ void vala_method_process_attributes (ValaMethod* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
-				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_method_process_ccode_attribute (self, a);
 				} else {
-					if (g_utf8_collate (vala_attribute_get_name (a), "ReturnsModifiedPointer") == 0) {
+					if (_vala_strcmp0 (vala_attribute_get_name (a), "ReturnsModifiedPointer") == 0) {
 						vala_method_set_returns_modified_pointer (self, TRUE);
 					} else {
-						if (g_utf8_collate (vala_attribute_get_name (a), "InstanceLast") == 0) {
-							vala_method_set_instance_last (self, TRUE);
+						if (_vala_strcmp0 (vala_attribute_get_name (a), "FloatingReference") == 0) {
+							vala_data_type_set_floating_reference (vala_method_get_return_type (self), TRUE);
 						} else {
-							if (g_utf8_collate (vala_attribute_get_name (a), "FloatingReference") == 0) {
-								vala_data_type_set_floating_reference (vala_method_get_return_type (self), TRUE);
+							if (_vala_strcmp0 (vala_attribute_get_name (a), "NoArrayLength") == 0) {
+								vala_method_set_no_array_length (self, TRUE);
 							} else {
-								if (g_utf8_collate (vala_attribute_get_name (a), "NoArrayLength") == 0) {
-									vala_method_set_no_array_length (self, TRUE);
+								if (_vala_strcmp0 (vala_attribute_get_name (a), "PrintfFormat") == 0) {
+									vala_method_set_printf_format (self, TRUE);
 								} else {
-									if (g_utf8_collate (vala_attribute_get_name (a), "PrintfFormat") == 0) {
-										vala_method_set_printf_format (self, TRUE);
-									} else {
-										if (g_utf8_collate (vala_attribute_get_name (a), "Import") == 0) {
-											vala_symbol_set_is_imported (VALA_SYMBOL (self), TRUE);
-										}
+									if (_vala_strcmp0 (vala_attribute_get_name (a), "Import") == 0) {
+										vala_symbol_set_is_imported (VALA_SYMBOL (self), TRUE);
 									}
 								}
 							}
@@ -431,7 +458,7 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
 		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
 		while (gee_iterator_next (param_it)) {
 			ValaFormalParameter* param;
-			param = gee_iterator_get (param_it);
+			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
 			{
 				ValaFormalParameter* _tmp4;
 				gboolean _tmp5;
@@ -441,7 +468,7 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
 					return (_tmp3 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp3);
 				}
 				_tmp4 = NULL;
-				if ((_tmp5 = !vala_data_type_equals (vala_formal_parameter_get_type_reference ((_tmp4 = gee_iterator_get (method_params_it))), vala_formal_parameter_get_type_reference (param)), (_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL))), _tmp5)) {
+				if ((_tmp5 = !vala_data_type_equals (vala_formal_parameter_get_type_reference ((_tmp4 = ((ValaFormalParameter*) gee_iterator_get (method_params_it)))), vala_formal_parameter_get_type_reference (param)), (_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL))), _tmp5)) {
 					gboolean _tmp6;
 					return (_tmp6 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp6);
 				}
@@ -465,7 +492,7 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
 		error_domain_it = gee_iterable_iterator (GEE_ITERABLE (error_domain_collection));
 		while (gee_iterator_next (error_domain_it)) {
 			ValaDataType* error_domain;
-			error_domain = gee_iterator_get (error_domain_it);
+			error_domain = ((ValaDataType*) gee_iterator_get (error_domain_it));
 			{
 				ValaDataType* _tmp11;
 				gboolean _tmp12;
@@ -475,7 +502,7 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
 					return (_tmp10 = FALSE, (error_domain == NULL ? NULL : (error_domain = (g_object_unref (error_domain), NULL))), (error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), (method_error_domains_it == NULL ? NULL : (method_error_domains_it = (g_object_unref (method_error_domains_it), NULL))), _tmp10);
 				}
 				_tmp11 = NULL;
-				if ((_tmp12 = !vala_data_type_equals ((_tmp11 = gee_iterator_get (method_error_domains_it)), error_domain), (_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL))), _tmp12)) {
+				if ((_tmp12 = !vala_data_type_equals ((_tmp11 = ((ValaDataType*) gee_iterator_get (method_error_domains_it))), error_domain), (_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL))), _tmp12)) {
 					gboolean _tmp13;
 					return (_tmp13 = FALSE, (error_domain == NULL ? NULL : (error_domain = (g_object_unref (error_domain), NULL))), (error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), (method_error_domains_it == NULL ? NULL : (method_error_domains_it = (g_object_unref (method_error_domains_it), NULL))), _tmp13);
 				}
@@ -576,7 +603,7 @@ static void vala_method_real_replace_type (ValaCodeNode* base, ValaDataType* old
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = gee_list_get (((GeeList*) self->priv->error_domains), i)) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+			if ((_tmp1 = (_tmp0 = ((ValaDataType*) gee_list_get (((GeeList*) self->priv->error_domains), i))) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
 				gee_list_set (((GeeList*) self->priv->error_domains), i, new_type);
 				return;
 			}
@@ -615,6 +642,41 @@ void vala_method_set_body (ValaMethod* self, ValaBlock* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
+	if (self->priv->_body != NULL) {
+		vala_symbol_set_owner (VALA_SYMBOL (self->priv->_body), vala_symbol_get_scope (VALA_SYMBOL (self)));
+	}
+}
+
+
+ValaBasicBlock* vala_method_get_entry_block (ValaMethod* self) {
+	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
+	return self->priv->_entry_block;
+}
+
+
+void vala_method_set_entry_block (ValaMethod* self, ValaBasicBlock* value) {
+	ValaBasicBlock* _tmp2;
+	ValaBasicBlock* _tmp1;
+	g_return_if_fail (VALA_IS_METHOD (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_entry_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (g_object_unref (self->priv->_entry_block), NULL))), _tmp2);
+}
+
+
+ValaBasicBlock* vala_method_get_exit_block (ValaMethod* self) {
+	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
+	return self->priv->_exit_block;
+}
+
+
+void vala_method_set_exit_block (ValaMethod* self, ValaBasicBlock* value) {
+	ValaBasicBlock* _tmp2;
+	ValaBasicBlock* _tmp1;
+	g_return_if_fail (VALA_IS_METHOD (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_exit_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (g_object_unref (self->priv->_exit_block), NULL))), _tmp2);
 }
 
 
@@ -732,18 +794,6 @@ void vala_method_set_returns_modified_pointer (ValaMethod* self, gboolean value)
 }
 
 
-gboolean vala_method_get_instance_last (ValaMethod* self) {
-	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
-	return self->priv->_instance_last;
-}
-
-
-void vala_method_set_instance_last (ValaMethod* self, gboolean value) {
-	g_return_if_fail (VALA_IS_METHOD (self));
-	self->priv->_instance_last = value;
-}
-
-
 ValaMethod* vala_method_get_base_method (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	return self->priv->_base_method;
@@ -804,6 +854,42 @@ void vala_method_set_result_var (ValaMethod* self, ValaVariableDeclarator* value
 }
 
 
+double vala_method_get_cinstance_parameter_position (ValaMethod* self) {
+	g_return_val_if_fail (VALA_IS_METHOD (self), 0.0);
+	return self->priv->_cinstance_parameter_position;
+}
+
+
+void vala_method_set_cinstance_parameter_position (ValaMethod* self, double value) {
+	g_return_if_fail (VALA_IS_METHOD (self));
+	self->priv->_cinstance_parameter_position = value;
+}
+
+
+double vala_method_get_carray_length_parameter_position (ValaMethod* self) {
+	g_return_val_if_fail (VALA_IS_METHOD (self), 0.0);
+	return self->priv->_carray_length_parameter_position;
+}
+
+
+void vala_method_set_carray_length_parameter_position (ValaMethod* self, double value) {
+	g_return_if_fail (VALA_IS_METHOD (self));
+	self->priv->_carray_length_parameter_position = value;
+}
+
+
+double vala_method_get_cdelegate_target_parameter_position (ValaMethod* self) {
+	g_return_val_if_fail (VALA_IS_METHOD (self), 0.0);
+	return self->priv->_cdelegate_target_parameter_position;
+}
+
+
+void vala_method_set_cdelegate_target_parameter_position (ValaMethod* self, double value) {
+	g_return_if_fail (VALA_IS_METHOD (self));
+	self->priv->_cdelegate_target_parameter_position = value;
+}
+
+
 gboolean vala_method_get_no_array_length (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	return self->priv->_no_array_length;
@@ -820,7 +906,7 @@ void vala_method_set_no_array_length (ValaMethod* self, gboolean value) {
 		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
 		while (gee_iterator_next (param_it)) {
 			ValaFormalParameter* param;
-			param = gee_iterator_get (param_it);
+			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
 			{
 				vala_formal_parameter_set_no_array_length (param, value);
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
@@ -843,6 +929,23 @@ void vala_method_set_printf_format (ValaMethod* self, gboolean value) {
 }
 
 
+static GObject * vala_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
+	GObject * obj;
+	ValaMethodClass * klass;
+	GObjectClass * parent_class;
+	ValaMethod * self;
+	klass = VALA_METHOD_CLASS (g_type_class_peek (VALA_TYPE_METHOD));
+	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
+	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
+	self = VALA_METHOD (obj);
+	{
+		vala_method_set_carray_length_parameter_position (self, ((double) -3));
+		vala_method_set_cdelegate_target_parameter_position (self, ((double) -3));
+	}
+	return obj;
+}
+
+
 static void vala_method_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaMethod * self;
 	self = VALA_METHOD (object);
@@ -853,6 +956,12 @@ static void vala_method_get_property (GObject * object, guint property_id, GValu
 		case VALA_METHOD_BODY:
 		g_value_set_object (value, vala_method_get_body (self));
 		break;
+		case VALA_METHOD_ENTRY_BLOCK:
+		g_value_set_object (value, vala_method_get_entry_block (self));
+		break;
+		case VALA_METHOD_EXIT_BLOCK:
+		g_value_set_object (value, vala_method_get_exit_block (self));
+		break;
 		case VALA_METHOD_INSTANCE:
 		g_value_set_boolean (value, vala_method_get_instance (self));
 		break;
@@ -877,9 +986,6 @@ static void vala_method_get_property (GObject * object, guint property_id, GValu
 		case VALA_METHOD_RETURNS_MODIFIED_POINTER:
 		g_value_set_boolean (value, vala_method_get_returns_modified_pointer (self));
 		break;
-		case VALA_METHOD_INSTANCE_LAST:
-		g_value_set_boolean (value, vala_method_get_instance_last (self));
-		break;
 		case VALA_METHOD_BASE_METHOD:
 		g_value_set_object (value, vala_method_get_base_method (self));
 		break;
@@ -892,6 +998,15 @@ static void vala_method_get_property (GObject * object, guint property_id, GValu
 		case VALA_METHOD_RESULT_VAR:
 		g_value_set_object (value, vala_method_get_result_var (self));
 		break;
+		case VALA_METHOD_CINSTANCE_PARAMETER_POSITION:
+		g_value_set_double (value, vala_method_get_cinstance_parameter_position (self));
+		break;
+		case VALA_METHOD_CARRAY_LENGTH_PARAMETER_POSITION:
+		g_value_set_double (value, vala_method_get_carray_length_parameter_position (self));
+		break;
+		case VALA_METHOD_CDELEGATE_TARGET_PARAMETER_POSITION:
+		g_value_set_double (value, vala_method_get_cdelegate_target_parameter_position (self));
+		break;
 		case VALA_METHOD_NO_ARRAY_LENGTH:
 		g_value_set_boolean (value, vala_method_get_no_array_length (self));
 		break;
@@ -915,6 +1030,12 @@ static void vala_method_set_property (GObject * object, guint property_id, const
 		case VALA_METHOD_BODY:
 		vala_method_set_body (self, g_value_get_object (value));
 		break;
+		case VALA_METHOD_ENTRY_BLOCK:
+		vala_method_set_entry_block (self, g_value_get_object (value));
+		break;
+		case VALA_METHOD_EXIT_BLOCK:
+		vala_method_set_exit_block (self, g_value_get_object (value));
+		break;
 		case VALA_METHOD_INSTANCE:
 		vala_method_set_instance (self, g_value_get_boolean (value));
 		break;
@@ -939,9 +1060,6 @@ static void vala_method_set_property (GObject * object, guint property_id, const
 		case VALA_METHOD_RETURNS_MODIFIED_POINTER:
 		vala_method_set_returns_modified_pointer (self, g_value_get_boolean (value));
 		break;
-		case VALA_METHOD_INSTANCE_LAST:
-		vala_method_set_instance_last (self, g_value_get_boolean (value));
-		break;
 		case VALA_METHOD_BASE_METHOD:
 		vala_method_set_base_method (self, g_value_get_object (value));
 		break;
@@ -954,6 +1072,15 @@ static void vala_method_set_property (GObject * object, guint property_id, const
 		case VALA_METHOD_RESULT_VAR:
 		vala_method_set_result_var (self, g_value_get_object (value));
 		break;
+		case VALA_METHOD_CINSTANCE_PARAMETER_POSITION:
+		vala_method_set_cinstance_parameter_position (self, g_value_get_double (value));
+		break;
+		case VALA_METHOD_CARRAY_LENGTH_PARAMETER_POSITION:
+		vala_method_set_carray_length_parameter_position (self, g_value_get_double (value));
+		break;
+		case VALA_METHOD_CDELEGATE_TARGET_PARAMETER_POSITION:
+		vala_method_set_cdelegate_target_parameter_position (self, g_value_get_double (value));
+		break;
 		case VALA_METHOD_NO_ARRAY_LENGTH:
 		vala_method_set_no_array_length (self, g_value_get_boolean (value));
 		break;
@@ -972,6 +1099,7 @@ static void vala_method_class_init (ValaMethodClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaMethodPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_method_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_method_set_property;
+	G_OBJECT_CLASS (klass)->constructor = vala_method_constructor;
 	G_OBJECT_CLASS (klass)->dispose = vala_method_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_method_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_method_real_accept_children;
@@ -979,6 +1107,8 @@ static void vala_method_class_init (ValaMethodClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_method_real_replace_type;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_ENTRY_BLOCK, g_param_spec_object ("entry-block", "entry-block", "entry-block", VALA_TYPE_BASIC_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_EXIT_BLOCK, g_param_spec_object ("exit-block", "exit-block", "exit-block", VALA_TYPE_BASIC_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_VFUNC_NAME, g_param_spec_string ("vfunc-name", "vfunc-name", "vfunc-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_SENTINEL, g_param_spec_string ("sentinel", "sentinel", "sentinel", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -987,11 +1117,13 @@ static void vala_method_class_init (ValaMethodClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_OVERRIDES, g_param_spec_boolean ("overrides", "overrides", "overrides", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_IS_INLINE, g_param_spec_boolean ("is-inline", "is-inline", "is-inline", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RETURNS_MODIFIED_POINTER, g_param_spec_boolean ("returns-modified-pointer", "returns-modified-pointer", "returns-modified-pointer", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_INSTANCE_LAST, g_param_spec_boolean ("instance-last", "instance-last", "instance-last", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BASE_METHOD, g_param_spec_object ("base-method", "base-method", "base-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BASE_INTERFACE_METHOD, g_param_spec_object ("base-interface-method", "base-interface-method", "base-interface-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RESULT_VAR, g_param_spec_object ("result-var", "result-var", "result-var", VALA_TYPE_VARIABLE_DECLARATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_CINSTANCE_PARAMETER_POSITION, g_param_spec_double ("cinstance-parameter-position", "cinstance-parameter-position", "cinstance-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_CARRAY_LENGTH_PARAMETER_POSITION, g_param_spec_double ("carray-length-parameter-position", "carray-length-parameter-position", "carray-length-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_CDELEGATE_TARGET_PARAMETER_POSITION, g_param_spec_double ("cdelegate-target-parameter-position", "cdelegate-target-parameter-position", "cdelegate-target-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_PRINTF_FORMAT, g_param_spec_boolean ("printf-format", "printf-format", "printf-format", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -1010,18 +1142,20 @@ static void vala_method_init (ValaMethod * self) {
 static void vala_method_dispose (GObject * obj) {
 	ValaMethod * self;
 	self = VALA_METHOD (obj);
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
+	(self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (g_object_unref (self->priv->_entry_block), NULL)));
+	(self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (g_object_unref (self->priv->_exit_block), NULL)));
 	(self->priv->_base_interface_method == NULL ? NULL : (self->priv->_base_interface_method = (g_object_unref (self->priv->_base_interface_method), NULL)));
 	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
 	(self->priv->_result_var == NULL ? NULL : (self->priv->_result_var = (g_object_unref (self->priv->_result_var), NULL)));
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
-	(self->priv->cname = (g_free (self->priv->cname), NULL));
-	(self->priv->_vfunc_name = (g_free (self->priv->_vfunc_name), NULL));
-	(self->priv->_sentinel = (g_free (self->priv->_sentinel), NULL));
+	self->priv->cname = (g_free (self->priv->cname), NULL);
+	self->priv->_vfunc_name = (g_free (self->priv->_vfunc_name), NULL);
+	self->priv->_sentinel = (g_free (self->priv->_sentinel), NULL);
 	(self->priv->error_domains == NULL ? NULL : (self->priv->error_domains = (g_object_unref (self->priv->error_domains), NULL)));
 	(self->priv->preconditions == NULL ? NULL : (self->priv->preconditions = (g_object_unref (self->priv->preconditions), NULL)));
 	(self->priv->postconditions == NULL ? NULL : (self->priv->postconditions = (g_object_unref (self->priv->postconditions), NULL)));
 	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	G_OBJECT_CLASS (vala_method_parent_class)->dispose (obj);
 }
 
@@ -1053,5 +1187,16 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
