@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #ifndef __VALA_VALAMETHOD_H__
@@ -29,6 +29,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gee/collection.h>
+#include <float.h>
+#include <math.h>
 #include <vala/valamember.h>
 #include <vala/valacodenode.h>
 
@@ -76,6 +78,10 @@ ValaDataType* vala_method_get_return_type (ValaMethod* self);
 void vala_method_set_return_type (ValaMethod* self, ValaDataType* value);
 ValaBlock* vala_method_get_body (ValaMethod* self);
 void vala_method_set_body (ValaMethod* self, ValaBlock* value);
+ValaBasicBlock* vala_method_get_entry_block (ValaMethod* self);
+void vala_method_set_entry_block (ValaMethod* self, ValaBasicBlock* value);
+ValaBasicBlock* vala_method_get_exit_block (ValaMethod* self);
+void vala_method_set_exit_block (ValaMethod* self, ValaBasicBlock* value);
 gboolean vala_method_get_instance (ValaMethod* self);
 void vala_method_set_instance (ValaMethod* self, gboolean value);
 char* vala_method_get_vfunc_name (ValaMethod* self);
@@ -92,8 +98,6 @@ gboolean vala_method_get_is_inline (ValaMethod* self);
 void vala_method_set_is_inline (ValaMethod* self, gboolean value);
 gboolean vala_method_get_returns_modified_pointer (ValaMethod* self);
 void vala_method_set_returns_modified_pointer (ValaMethod* self, gboolean value);
-gboolean vala_method_get_instance_last (ValaMethod* self);
-void vala_method_set_instance_last (ValaMethod* self, gboolean value);
 ValaMethod* vala_method_get_base_method (ValaMethod* self);
 void vala_method_set_base_method (ValaMethod* self, ValaMethod* value);
 ValaMethod* vala_method_get_base_interface_method (ValaMethod* self);
@@ -102,12 +106,19 @@ ValaFormalParameter* vala_method_get_this_parameter (ValaMethod* self);
 void vala_method_set_this_parameter (ValaMethod* self, ValaFormalParameter* value);
 ValaVariableDeclarator* vala_method_get_result_var (ValaMethod* self);
 void vala_method_set_result_var (ValaMethod* self, ValaVariableDeclarator* value);
+double vala_method_get_cinstance_parameter_position (ValaMethod* self);
+void vala_method_set_cinstance_parameter_position (ValaMethod* self, double value);
+double vala_method_get_carray_length_parameter_position (ValaMethod* self);
+void vala_method_set_carray_length_parameter_position (ValaMethod* self, double value);
+double vala_method_get_cdelegate_target_parameter_position (ValaMethod* self);
+void vala_method_set_cdelegate_target_parameter_position (ValaMethod* self, double value);
 gboolean vala_method_get_no_array_length (ValaMethod* self);
 void vala_method_set_no_array_length (ValaMethod* self, gboolean value);
 gboolean vala_method_get_printf_format (ValaMethod* self);
 void vala_method_set_printf_format (ValaMethod* self, gboolean value);
 GType vala_method_get_type (void);
 
+
 G_END_DECLS
 
 #endif
