@@ -39,6 +39,9 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
+
+
+
 struct _ValaNamespacePrivate {
 	gboolean _pkg;
 	GeeList* classes;
@@ -72,6 +75,7 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Creates a new namespace.
  *
@@ -447,9 +451,20 @@ static char* vala_namespace_real_get_cprefix (ValaSymbol* base) {
 		return ((char*) gee_list_get (((GeeList*) self->priv->cprefixes), 0));
 	} else {
 		if (NULL != vala_symbol_get_name (VALA_SYMBOL (self))) {
-			const char* _tmp1;
-			_tmp1 = NULL;
-			return (_tmp1 = vala_symbol_get_name (VALA_SYMBOL (self)), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+			char* parent_prefix;
+			char* _tmp3;
+			parent_prefix = NULL;
+			if (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)) == NULL) {
+				char* _tmp1;
+				_tmp1 = NULL;
+				parent_prefix = (_tmp1 = g_strdup (""), (parent_prefix = (g_free (parent_prefix), NULL)), _tmp1);
+			} else {
+				char* _tmp2;
+				_tmp2 = NULL;
+				parent_prefix = (_tmp2 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))), (parent_prefix = (g_free (parent_prefix), NULL)), _tmp2);
+			}
+			_tmp3 = NULL;
+			return (_tmp3 = g_strconcat (parent_prefix, vala_symbol_get_name (VALA_SYMBOL (self)), NULL), (parent_prefix = (g_free (parent_prefix), NULL)), _tmp3);
 		} else {
 			return g_strdup ("");
 		}
@@ -489,7 +504,7 @@ void vala_namespace_add_cprefix (ValaNamespace* self, const char* cprefix) {
  */
 static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base) {
 	ValaNamespace * self;
-	const char* _tmp3;
+	const char* _tmp5;
 	self = VALA_NAMESPACE (base);
 	if (self->priv->lower_case_cprefix == NULL) {
 		if (vala_symbol_get_name (VALA_SYMBOL (self)) == NULL) {
@@ -497,16 +512,28 @@ static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base) {
 			_tmp0 = NULL;
 			self->priv->lower_case_cprefix = (_tmp0 = g_strdup (""), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp0);
 		} else {
-			char* _tmp2;
-			char* _tmp1;
-			_tmp2 = NULL;
-			_tmp1 = NULL;
-			self->priv->lower_case_cprefix = (_tmp2 = g_strdup_printf ("%s_", (_tmp1 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (VALA_SYMBOL (self))))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp2);
-			_tmp1 = (g_free (_tmp1), NULL);
+			char* parent_prefix;
+			char* _tmp4;
+			char* _tmp3;
+			parent_prefix = NULL;
+			if (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)) == NULL) {
+				char* _tmp1;
+				_tmp1 = NULL;
+				parent_prefix = (_tmp1 = g_strdup (""), (parent_prefix = (g_free (parent_prefix), NULL)), _tmp1);
+			} else {
+				char* _tmp2;
+				_tmp2 = NULL;
+				parent_prefix = (_tmp2 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))), (parent_prefix = (g_free (parent_prefix), NULL)), _tmp2);
+			}
+			_tmp4 = NULL;
+			_tmp3 = NULL;
+			self->priv->lower_case_cprefix = (_tmp4 = g_strdup_printf ("%s%s_", parent_prefix, (_tmp3 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (VALA_SYMBOL (self))))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp4);
+			_tmp3 = (g_free (_tmp3), NULL);
+			parent_prefix = (g_free (parent_prefix), NULL);
 		}
 	}
-	_tmp3 = NULL;
-	return (_tmp3 = self->priv->lower_case_cprefix, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+	_tmp5 = NULL;
+	return (_tmp5 = self->priv->lower_case_cprefix, (_tmp5 == NULL ? NULL : g_strdup (_tmp5)));
 }
 
 
