@@ -31,6 +31,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaObjectCreationExpressionPrivate {
 	ValaMethod* _constructor;
 	ValaMemberAccess* _member_name;
@@ -54,6 +57,7 @@ static gpointer vala_object_creation_expression_parent_class = NULL;
 static void vala_object_creation_expression_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new object creation expression.
  *
@@ -135,8 +139,8 @@ static void vala_object_creation_expression_real_accept_children (ValaCodeNode*
 	if (vala_object_creation_expression_get_type_reference (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_object_creation_expression_get_type_reference (self)), visitor);
 	}
-	if (vala_object_creation_expression_get_member_name (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_object_creation_expression_get_member_name (self)), visitor);
+	if (self->priv->_member_name != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_member_name), visitor);
 	}
 	{
 		GeeList* arg_collection;
@@ -145,7 +149,7 @@ static void vala_object_creation_expression_real_accept_children (ValaCodeNode*
 		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
 		while (gee_iterator_next (arg_it)) {
 			ValaExpression* arg;
-			arg = gee_iterator_get (arg_it);
+			arg = ((ValaExpression*) gee_iterator_get (arg_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (arg), visitor);
 				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
@@ -160,7 +164,7 @@ static void vala_object_creation_expression_real_accept_children (ValaCodeNode*
 		init_it = gee_iterable_iterator (GEE_ITERABLE (init_collection));
 		while (gee_iterator_next (init_it)) {
 			ValaMemberInitializer* init;
-			init = gee_iterator_get (init_it);
+			init = ((ValaMemberInitializer*) gee_iterator_get (init_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (init), visitor);
 				(init == NULL ? NULL : (init = (g_object_unref (init), NULL)));
