@@ -22,6 +22,9 @@
 
 #include <vala/valaparser.h>
 
+
+
+
 struct _ValaParserPrivate {
 	char* comment;
 	char* _file_comment;
@@ -35,6 +38,7 @@ static gpointer vala_parser_parent_class = NULL;
 static void vala_parser_dispose (GObject * obj);
 
 
+
 /**
  * Parse all source files in the specified code context and build a
  * code tree.
@@ -113,8 +117,8 @@ char* vala_parser_pop_comment (ValaParser* self) {
 	_tmp1 = NULL;
 	self->priv->comment = (_tmp1 = NULL, (self->priv->comment = (g_free (self->priv->comment), NULL)), _tmp1);
 	index = NULL;
-	while ((index = g_utf8_strchr (result->str, -1, '\t')) != NULL) {
-		g_string_erase (result, g_utf8_pointer_to_offset (result->str, index), 1);
+	while ((index = g_utf8_strchr (result->str, ((glong) -1), ((gunichar) '\t'))) != NULL) {
+		g_string_erase (result, g_utf8_pointer_to_offset (result->str, index), ((glong) 1));
 	}
 	_tmp2 = NULL;
 	_tmp3 = NULL;
@@ -148,8 +152,8 @@ static void vala_parser_init (ValaParser * self) {
 static void vala_parser_dispose (GObject * obj) {
 	ValaParser * self;
 	self = VALA_PARSER (obj);
-	(self->priv->comment = (g_free (self->priv->comment), NULL));
-	(self->priv->_file_comment = (g_free (self->priv->_file_comment), NULL));
+	self->priv->comment = (g_free (self->priv->comment), NULL);
+	self->priv->_file_comment = (g_free (self->priv->_file_comment), NULL);
 	G_OBJECT_CLASS (vala_parser_parent_class)->dispose (obj);
 }
 
