@@ -24,6 +24,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaPointerIndirectionPrivate {
 	ValaExpression* _inner;
 };
@@ -39,6 +42,7 @@ static gpointer vala_pointer_indirection_parent_class = NULL;
 static void vala_pointer_indirection_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new pointer indirection.
  *
@@ -53,7 +57,10 @@ ValaPointerIndirection* vala_pointer_indirection_new (ValaExpression* inner, Val
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, inner), __params_it++);
+	__params_it->name = "inner";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, inner);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_POINTER_INDIRECTION, __params_it - __params, __params);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	while (__params_it > __params) {
