@@ -24,6 +24,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaPostfixExpressionPrivate {
 	ValaExpression* _inner;
 	gboolean _increment;
@@ -40,6 +43,7 @@ static gpointer vala_postfix_expression_parent_class = NULL;
 static void vala_postfix_expression_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new postfix expression.
  *
@@ -56,7 +60,10 @@ ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboo
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _inner), __params_it++);
+	__params_it->name = "inner";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, _inner);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_POSTFIX_EXPRESSION, __params_it - __params, __params);
 	vala_postfix_expression_set_increment (self, inc);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
@@ -73,7 +80,7 @@ static void vala_postfix_expression_real_accept (ValaCodeNode* base, ValaCodeVis
 	ValaPostfixExpression * self;
 	self = VALA_POSTFIX_EXPRESSION (base);
 	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_postfix_expression_get_inner (self)), visitor);
+	vala_code_node_accept (VALA_CODE_NODE (self->priv->_inner), visitor);
 	vala_code_visitor_visit_postfix_expression (visitor, self);
 }
 
