@@ -1,6 +1,6 @@
 /* valaproperty.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,12 +23,17 @@
 #include <vala/valaproperty.h>
 #include <vala/valapropertyaccessor.h>
 #include <vala/valaformalparameter.h>
+#include <vala/valafield.h>
+#include <vala/valaexpression.h>
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
+
+
+
 struct _ValaPropertyPrivate {
 	ValaPropertyAccessor* _get_accessor;
 	ValaPropertyAccessor* _set_accessor;
@@ -39,10 +44,15 @@ struct _ValaPropertyPrivate {
 	gboolean _is_abstract;
 	gboolean _is_virtual;
 	gboolean _overrides;
+	ValaField* _field;
 	ValaProperty* _base_property;
 	ValaProperty* _base_interface_property;
+	ValaExpression* _default_expression;
 	gboolean lock_used;
 	ValaDataType* _data_type;
+	gboolean _instance;
+	char* _nick;
+	char* _blurb;
 };
 #define VALA_PROPERTY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROPERTY, ValaPropertyPrivate))
 enum  {
@@ -57,17 +67,25 @@ enum  {
 	VALA_PROPERTY_IS_ABSTRACT,
 	VALA_PROPERTY_IS_VIRTUAL,
 	VALA_PROPERTY_OVERRIDES,
+	VALA_PROPERTY_FIELD,
+	VALA_PROPERTY_INSTANCE,
 	VALA_PROPERTY_BASE_PROPERTY,
-	VALA_PROPERTY_BASE_INTERFACE_PROPERTY
+	VALA_PROPERTY_BASE_INTERFACE_PROPERTY,
+	VALA_PROPERTY_DEFAULT_EXPRESSION,
+	VALA_PROPERTY_NICK,
+	VALA_PROPERTY_BLURB
 };
 static void vala_property_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_property_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static char* vala_property_get_canonical_name (ValaProperty* self);
 static gboolean vala_property_real_get_lock_used (ValaLockable* base);
 static void vala_property_real_set_lock_used (ValaLockable* base, gboolean used);
 static void vala_property_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_property_parent_class = NULL;
 static ValaLockableIface* vala_property_vala_lockable_parent_iface = NULL;
 static void vala_property_dispose (GObject * obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
+
 
 
 /**
@@ -110,11 +128,14 @@ static void vala_property_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 	self = VALA_PROPERTY (base);
 	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_property_get_type_reference (self)), visitor);
-	if (vala_property_get_get_accessor (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_property_get_get_accessor (self)), visitor);
+	if (self->priv->_get_accessor != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_get_accessor), visitor);
 	}
-	if (vala_property_get_set_accessor (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_property_get_set_accessor (self)), visitor);
+	if (self->priv->_set_accessor != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_set_accessor), visitor);
+	}
+	if (self->priv->_default_expression != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_default_expression), visitor);
 	}
 }
 
@@ -146,12 +167,25 @@ char* vala_property_get_upper_case_cname (ValaProperty* self) {
  * @return string literal to be used in C code
  */
 ValaCCodeConstant* vala_property_get_canonical_cconstant (ValaProperty* self) {
+	char* _tmp1;
+	char* _tmp0;
+	ValaCCodeConstant* _tmp2;
+	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	_tmp2 = NULL;
+	return (_tmp2 = vala_ccode_constant_new ((_tmp1 = g_strdup_printf ("\"%s\"", (_tmp0 = vala_property_get_canonical_name (self))))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
+}
+
+
+static char* vala_property_get_canonical_name (ValaProperty* self) {
 	GString* str;
 	const char* _tmp0;
 	char* i;
-	ValaCCodeConstant* _tmp3;
+	const char* _tmp3;
+	char* _tmp4;
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
-	str = g_string_new ("\"");
+	str = g_string_new ("");
 	_tmp0 = NULL;
 	i = (_tmp0 = vala_symbol_get_name (VALA_SYMBOL (self)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	while (g_utf8_strlen (i, -1) > 0) {
@@ -168,9 +202,9 @@ ValaCCodeConstant* vala_property_get_canonical_cconstant (ValaProperty* self) {
 		_tmp1 = NULL;
 		i = (_tmp2 = (_tmp1 = g_utf8_next_char (i), (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (i = (g_free (i), NULL)), _tmp2);
 	}
-	g_string_append_c (str, '"');
 	_tmp3 = NULL;
-	return (_tmp3 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), _tmp3);
+	_tmp4 = NULL;
+	return (_tmp4 = (_tmp3 = str->str, (_tmp3 == NULL ? NULL : g_strdup (_tmp3))), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), _tmp4);
 }
 
 
@@ -184,16 +218,31 @@ void vala_property_process_attributes (ValaProperty* self) {
 		GList* a_it;
 		a_collection = VALA_CODE_NODE (self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp0;
+			ValaAttribute* _tmp2;
 			ValaAttribute* a;
-			_tmp0 = NULL;
-			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			_tmp2 = NULL;
+			a = (_tmp2 = ((ValaAttribute*) a_it->data), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
 			{
-				if (g_utf8_collate (vala_attribute_get_name (a), "Notify") == 0) {
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "Notify") == 0) {
 					vala_property_set_notify (self, TRUE);
 				} else {
-					if (g_utf8_collate (vala_attribute_get_name (a), "NoAccessorMethod") == 0) {
+					if (_vala_strcmp0 (vala_attribute_get_name (a), "NoAccessorMethod") == 0) {
 						vala_property_set_no_accessor_method (self, TRUE);
+					} else {
+						if (_vala_strcmp0 (vala_attribute_get_name (a), "Description") == 0) {
+							if (vala_attribute_has_argument (a, "nick")) {
+								char* _tmp0;
+								_tmp0 = NULL;
+								vala_property_set_nick (self, (_tmp0 = vala_attribute_get_string (a, "nick")));
+								_tmp0 = (g_free (_tmp0), NULL);
+							}
+							if (vala_attribute_has_argument (a, "blurb")) {
+								char* _tmp1;
+								_tmp1 = NULL;
+								vala_property_set_blurb (self, (_tmp1 = vala_attribute_get_string (a, "blurb")));
+								_tmp1 = (g_free (_tmp1), NULL);
+							}
+						}
 					}
 				}
 				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
@@ -231,17 +280,17 @@ gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2) {
 	if (!vala_data_type_equals (vala_property_get_type_reference (prop2), vala_property_get_type_reference (self))) {
 		return FALSE;
 	}
-	if ((vala_property_get_get_accessor (self) == NULL && vala_property_get_get_accessor (prop2) != NULL) || (vala_property_get_get_accessor (self) != NULL && vala_property_get_get_accessor (prop2) == NULL)) {
+	if ((self->priv->_get_accessor == NULL && prop2->priv->_get_accessor != NULL) || (self->priv->_get_accessor != NULL && prop2->priv->_get_accessor == NULL)) {
 		return FALSE;
 	}
-	if ((vala_property_get_set_accessor (self) == NULL && vala_property_get_set_accessor (prop2) != NULL) || (vala_property_get_set_accessor (self) != NULL && vala_property_get_set_accessor (prop2) == NULL)) {
+	if ((self->priv->_set_accessor == NULL && prop2->priv->_set_accessor != NULL) || (self->priv->_set_accessor != NULL && prop2->priv->_set_accessor == NULL)) {
 		return FALSE;
 	}
-	if (vala_property_get_set_accessor (self) != NULL) {
-		if (vala_property_accessor_get_writable (vala_property_get_set_accessor (self)) != vala_property_accessor_get_writable (vala_property_get_set_accessor (prop2))) {
+	if (self->priv->_set_accessor != NULL) {
+		if (vala_property_accessor_get_writable (self->priv->_set_accessor) != vala_property_accessor_get_writable (prop2->priv->_set_accessor)) {
 			return FALSE;
 		}
-		if (vala_property_accessor_get_construction (vala_property_get_set_accessor (self)) != vala_property_accessor_get_construction (vala_property_get_set_accessor (prop2))) {
+		if (vala_property_accessor_get_construction (self->priv->_set_accessor) != vala_property_accessor_get_construction (prop2->priv->_set_accessor)) {
 			return FALSE;
 		}
 	}
@@ -397,6 +446,34 @@ void vala_property_set_overrides (ValaProperty* self, gboolean value) {
 }
 
 
+ValaField* vala_property_get_field (ValaProperty* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
+	return self->priv->_field;
+}
+
+
+void vala_property_set_field (ValaProperty* self, ValaField* value) {
+	ValaField* _tmp2;
+	ValaField* _tmp1;
+	g_return_if_fail (VALA_IS_PROPERTY (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_field = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_field == NULL ? NULL : (self->priv->_field = (g_object_unref (self->priv->_field), NULL))), _tmp2);
+}
+
+
+gboolean vala_property_get_instance (ValaProperty* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY (self), FALSE);
+	return self->priv->_instance;
+}
+
+
+void vala_property_set_instance (ValaProperty* self, gboolean value) {
+	g_return_if_fail (VALA_IS_PROPERTY (self));
+	self->priv->_instance = value;
+}
+
+
 ValaProperty* vala_property_get_base_property (ValaProperty* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
 	return self->priv->_base_property;
@@ -425,6 +502,64 @@ void vala_property_set_base_interface_property (ValaProperty* self, ValaProperty
 }
 
 
+ValaExpression* vala_property_get_default_expression (ValaProperty* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
+	return self->priv->_default_expression;
+}
+
+
+void vala_property_set_default_expression (ValaProperty* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
+	g_return_if_fail (VALA_IS_PROPERTY (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_default_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL))), _tmp2);
+}
+
+
+char* vala_property_get_nick (ValaProperty* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
+	if (self->priv->_nick == NULL) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		self->priv->_nick = (_tmp0 = vala_property_get_canonical_name (self), (self->priv->_nick = (g_free (self->priv->_nick), NULL)), _tmp0);
+	}
+	return self->priv->_nick;
+}
+
+
+void vala_property_set_nick (ValaProperty* self, const char* value) {
+	char* _tmp3;
+	const char* _tmp2;
+	g_return_if_fail (VALA_IS_PROPERTY (self));
+	_tmp3 = NULL;
+	_tmp2 = NULL;
+	self->priv->_nick = (_tmp3 = (_tmp2 = value, (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (self->priv->_nick = (g_free (self->priv->_nick), NULL)), _tmp3);
+}
+
+
+char* vala_property_get_blurb (ValaProperty* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
+	if (self->priv->_blurb == NULL) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		self->priv->_blurb = (_tmp0 = vala_property_get_canonical_name (self), (self->priv->_blurb = (g_free (self->priv->_blurb), NULL)), _tmp0);
+	}
+	return self->priv->_blurb;
+}
+
+
+void vala_property_set_blurb (ValaProperty* self, const char* value) {
+	char* _tmp3;
+	const char* _tmp2;
+	g_return_if_fail (VALA_IS_PROPERTY (self));
+	_tmp3 = NULL;
+	_tmp2 = NULL;
+	self->priv->_blurb = (_tmp3 = (_tmp2 = value, (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (self->priv->_blurb = (g_free (self->priv->_blurb), NULL)), _tmp3);
+}
+
+
 static void vala_property_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaProperty * self;
 	self = VALA_PROPERTY (object);
@@ -459,12 +594,27 @@ static void vala_property_get_property (GObject * object, guint property_id, GVa
 		case VALA_PROPERTY_OVERRIDES:
 		g_value_set_boolean (value, vala_property_get_overrides (self));
 		break;
+		case VALA_PROPERTY_FIELD:
+		g_value_set_object (value, vala_property_get_field (self));
+		break;
+		case VALA_PROPERTY_INSTANCE:
+		g_value_set_boolean (value, vala_property_get_instance (self));
+		break;
 		case VALA_PROPERTY_BASE_PROPERTY:
 		g_value_set_object (value, vala_property_get_base_property (self));
 		break;
 		case VALA_PROPERTY_BASE_INTERFACE_PROPERTY:
 		g_value_set_object (value, vala_property_get_base_interface_property (self));
 		break;
+		case VALA_PROPERTY_DEFAULT_EXPRESSION:
+		g_value_set_object (value, vala_property_get_default_expression (self));
+		break;
+		case VALA_PROPERTY_NICK:
+		g_value_set_string (value, vala_property_get_nick (self));
+		break;
+		case VALA_PROPERTY_BLURB:
+		g_value_set_string (value, vala_property_get_blurb (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -506,12 +656,27 @@ static void vala_property_set_property (GObject * object, guint property_id, con
 		case VALA_PROPERTY_OVERRIDES:
 		vala_property_set_overrides (self, g_value_get_boolean (value));
 		break;
+		case VALA_PROPERTY_FIELD:
+		vala_property_set_field (self, g_value_get_object (value));
+		break;
+		case VALA_PROPERTY_INSTANCE:
+		vala_property_set_instance (self, g_value_get_boolean (value));
+		break;
 		case VALA_PROPERTY_BASE_PROPERTY:
 		vala_property_set_base_property (self, g_value_get_object (value));
 		break;
 		case VALA_PROPERTY_BASE_INTERFACE_PROPERTY:
 		vala_property_set_base_interface_property (self, g_value_get_object (value));
 		break;
+		case VALA_PROPERTY_DEFAULT_EXPRESSION:
+		vala_property_set_default_expression (self, g_value_get_object (value));
+		break;
+		case VALA_PROPERTY_NICK:
+		vala_property_set_nick (self, g_value_get_string (value));
+		break;
+		case VALA_PROPERTY_BLURB:
+		vala_property_set_blurb (self, g_value_get_string (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -538,8 +703,13 @@ static void vala_property_class_init (ValaPropertyClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_IS_ABSTRACT, g_param_spec_boolean ("is-abstract", "is-abstract", "is-abstract", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_IS_VIRTUAL, g_param_spec_boolean ("is-virtual", "is-virtual", "is-virtual", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_OVERRIDES, g_param_spec_boolean ("overrides", "overrides", "overrides", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_FIELD, g_param_spec_object ("field", "field", "field", VALA_TYPE_FIELD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_PROPERTY, g_param_spec_object ("base-property", "base-property", "base-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_INTERFACE_PROPERTY, g_param_spec_object ("base-interface-property", "base-interface-property", "base-interface-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "default-expression", "default-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_NICK, g_param_spec_string ("nick", "nick", "nick", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BLURB, g_param_spec_string ("blurb", "blurb", "blurb", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -553,6 +723,7 @@ static void vala_property_vala_lockable_interface_init (ValaLockableIface * ifac
 static void vala_property_init (ValaProperty * self) {
 	self->priv = VALA_PROPERTY_GET_PRIVATE (self);
 	self->priv->lock_used = FALSE;
+	self->priv->_instance = TRUE;
 }
 
 
@@ -562,8 +733,12 @@ static void vala_property_dispose (GObject * obj) {
 	(self->priv->_get_accessor == NULL ? NULL : (self->priv->_get_accessor = (g_object_unref (self->priv->_get_accessor), NULL)));
 	(self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (g_object_unref (self->priv->_set_accessor), NULL)));
 	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
+	(self->priv->_field == NULL ? NULL : (self->priv->_field = (g_object_unref (self->priv->_field), NULL)));
 	(self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL)));
+	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL)));
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
+	self->priv->_nick = (g_free (self->priv->_nick), NULL);
+	self->priv->_blurb = (g_free (self->priv->_blurb), NULL);
 	G_OBJECT_CLASS (vala_property_parent_class)->dispose (obj);
 }
 
@@ -580,5 +755,16 @@ GType vala_property_get_type (void) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
