@@ -28,6 +28,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaPropertyAccessorPrivate {
 	ValaProperty* _prop;
 	gboolean _readable;
@@ -37,6 +40,7 @@ struct _ValaPropertyAccessorPrivate {
 	ValaBlock* _body;
 	ValaBasicBlock* _entry_block;
 	ValaBasicBlock* _exit_block;
+	gboolean _automatic_body;
 	ValaFormalParameter* _value_parameter;
 };
 #define VALA_PROPERTY_ACCESSOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessorPrivate))
@@ -50,6 +54,7 @@ enum  {
 	VALA_PROPERTY_ACCESSOR_BODY,
 	VALA_PROPERTY_ACCESSOR_ENTRY_BLOCK,
 	VALA_PROPERTY_ACCESSOR_EXIT_BLOCK,
+	VALA_PROPERTY_ACCESSOR_AUTOMATIC_BODY,
 	VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER
 };
 static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -58,6 +63,7 @@ static gpointer vala_property_accessor_parent_class = NULL;
 static void vala_property_accessor_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new property accessor.
  *
@@ -94,8 +100,8 @@ static void vala_property_accessor_real_accept_children (ValaCodeNode* base, Val
 	ValaPropertyAccessor * self;
 	self = VALA_PROPERTY_ACCESSOR (base);
 	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	if (vala_property_accessor_get_body (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_property_accessor_get_body (self)), visitor);
+	if (self->priv->_body != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_body), visitor);
 	}
 }
 
@@ -208,6 +214,18 @@ void vala_property_accessor_set_exit_block (ValaPropertyAccessor* self, ValaBasi
 }
 
 
+gboolean vala_property_accessor_get_automatic_body (ValaPropertyAccessor* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), FALSE);
+	return self->priv->_automatic_body;
+}
+
+
+void vala_property_accessor_set_automatic_body (ValaPropertyAccessor* self, gboolean value) {
+	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	self->priv->_automatic_body = value;
+}
+
+
 ValaFormalParameter* vala_property_accessor_get_value_parameter (ValaPropertyAccessor* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
 	return self->priv->_value_parameter;
@@ -241,7 +259,7 @@ static void vala_property_accessor_get_property (GObject * object, guint propert
 		g_value_set_boolean (value, vala_property_accessor_get_construction (self));
 		break;
 		case VALA_PROPERTY_ACCESSOR_ACCESS:
-		g_value_set_int (value, vala_property_accessor_get_access (self));
+		g_value_set_enum (value, vala_property_accessor_get_access (self));
 		break;
 		case VALA_PROPERTY_ACCESSOR_BODY:
 		g_value_set_object (value, vala_property_accessor_get_body (self));
@@ -252,6 +270,9 @@ static void vala_property_accessor_get_property (GObject * object, guint propert
 		case VALA_PROPERTY_ACCESSOR_EXIT_BLOCK:
 		g_value_set_object (value, vala_property_accessor_get_exit_block (self));
 		break;
+		case VALA_PROPERTY_ACCESSOR_AUTOMATIC_BODY:
+		g_value_set_boolean (value, vala_property_accessor_get_automatic_body (self));
+		break;
 		case VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER:
 		g_value_set_object (value, vala_property_accessor_get_value_parameter (self));
 		break;
@@ -279,7 +300,7 @@ static void vala_property_accessor_set_property (GObject * object, guint propert
 		vala_property_accessor_set_construction (self, g_value_get_boolean (value));
 		break;
 		case VALA_PROPERTY_ACCESSOR_ACCESS:
-		vala_property_accessor_set_access (self, g_value_get_int (value));
+		vala_property_accessor_set_access (self, g_value_get_enum (value));
 		break;
 		case VALA_PROPERTY_ACCESSOR_BODY:
 		vala_property_accessor_set_body (self, g_value_get_object (value));
@@ -290,6 +311,9 @@ static void vala_property_accessor_set_property (GObject * object, guint propert
 		case VALA_PROPERTY_ACCESSOR_EXIT_BLOCK:
 		vala_property_accessor_set_exit_block (self, g_value_get_object (value));
 		break;
+		case VALA_PROPERTY_ACCESSOR_AUTOMATIC_BODY:
+		vala_property_accessor_set_automatic_body (self, g_value_get_boolean (value));
+		break;
 		case VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER:
 		vala_property_accessor_set_value_parameter (self, g_value_get_object (value));
 		break;
@@ -312,10 +336,11 @@ static void vala_property_accessor_class_init (ValaPropertyAccessorClass * klass
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_READABLE, g_param_spec_boolean ("readable", "readable", "readable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_WRITABLE, g_param_spec_boolean ("writable", "writable", "writable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_CONSTRUCTION, g_param_spec_boolean ("construction", "construction", "construction", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_ACCESS, g_param_spec_int ("access", "access", "access", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_ACCESS, g_param_spec_enum ("access", "access", "access", VALA_TYPE_SYMBOL_ACCESSIBILITY, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_ENTRY_BLOCK, g_param_spec_object ("entry-block", "entry-block", "entry-block", VALA_TYPE_BASIC_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_EXIT_BLOCK, g_param_spec_object ("exit-block", "exit-block", "exit-block", VALA_TYPE_BASIC_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_AUTOMATIC_BODY, g_param_spec_boolean ("automatic-body", "automatic-body", "automatic-body", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER, g_param_spec_object ("value-parameter", "value-parameter", "value-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
