@@ -68,10 +68,13 @@ ValaBasicBlock* vala_property_accessor_get_entry_block (ValaPropertyAccessor* se
 void vala_property_accessor_set_entry_block (ValaPropertyAccessor* self, ValaBasicBlock* value);
 ValaBasicBlock* vala_property_accessor_get_exit_block (ValaPropertyAccessor* self);
 void vala_property_accessor_set_exit_block (ValaPropertyAccessor* self, ValaBasicBlock* value);
+gboolean vala_property_accessor_get_automatic_body (ValaPropertyAccessor* self);
+void vala_property_accessor_set_automatic_body (ValaPropertyAccessor* self, gboolean value);
 ValaFormalParameter* vala_property_accessor_get_value_parameter (ValaPropertyAccessor* self);
 void vala_property_accessor_set_value_parameter (ValaPropertyAccessor* self, ValaFormalParameter* value);
 GType vala_property_accessor_get_type (void);
 
+
 G_END_DECLS
 
 #endif
