@@ -1,6 +1,6 @@
 /* valarealliteral.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaRealLiteralPrivate {
 	char* _value;
 };
@@ -33,10 +36,12 @@ enum  {
 	VALA_REAL_LITERAL_VALUE
 };
 static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_real_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_real_literal_parent_class = NULL;
 static void vala_real_literal_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new real literal.
  *
@@ -69,13 +74,20 @@ static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor*
  */
 char* vala_real_literal_get_type_name (ValaRealLiteral* self) {
 	g_return_val_if_fail (VALA_IS_REAL_LITERAL (self), NULL);
-	if (g_str_has_suffix (vala_real_literal_get_value (self), "F")) {
+	if (g_str_has_suffix (self->priv->_value, "F")) {
 		return g_strdup ("float");
 	}
 	return g_strdup ("double");
 }
 
 
+static gboolean vala_real_literal_real_is_pure (ValaExpression* base) {
+	ValaRealLiteral * self;
+	self = VALA_REAL_LITERAL (base);
+	return TRUE;
+}
+
+
 char* vala_real_literal_get_value (ValaRealLiteral* self) {
 	g_return_val_if_fail (VALA_IS_REAL_LITERAL (self), NULL);
 	return self->priv->_value;
@@ -127,6 +139,7 @@ static void vala_real_literal_class_init (ValaRealLiteralClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = vala_real_literal_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_real_literal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_real_literal_real_accept;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_real_literal_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_REAL_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
