@@ -1,6 +1,6 @@
 /* valascope.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,6 +27,9 @@
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
 
+
+
+
 struct _ValaScopePrivate {
 	ValaSymbol* _owner;
 	ValaScope* _parent_scope;
@@ -42,6 +45,7 @@ static gpointer vala_scope_parent_class = NULL;
 static void vala_scope_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new scope.
  *
@@ -78,10 +82,10 @@ void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym) {
 			if ((_tmp2 = (_tmp1 = vala_scope_lookup (self, name)) != NULL, (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2)) {
 				char* _tmp4;
 				char* _tmp3;
-				vala_code_node_set_error (VALA_CODE_NODE (vala_scope_get_owner (self)), TRUE);
+				vala_code_node_set_error (VALA_CODE_NODE (self->priv->_owner), TRUE);
 				_tmp4 = NULL;
 				_tmp3 = NULL;
-				vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (vala_scope_get_owner (self))), (_tmp4 = g_strdup_printf ("`%s' already contains a definition for `%s'", (_tmp3 = vala_symbol_get_full_name (vala_scope_get_owner (self))), name)));
+				vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self->priv->_owner)), (_tmp4 = g_strdup_printf ("`%s' already contains a definition for `%s'", (_tmp3 = vala_symbol_get_full_name (self->priv->_owner)), name)));
 				_tmp4 = (g_free (_tmp4), NULL);
 				_tmp3 = (g_free (_tmp3), NULL);
 				return;
@@ -116,6 +120,30 @@ ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name) {
 }
 
 
+/**
+ * Returns whether the specified scope is an ancestor of this scope.
+ *
+ * @param scope a scope or null for the root scope
+ * @return      true if this scope is a subscope of the specified
+ *              scope, false otherwise
+ */
+gboolean vala_scope_is_subscope_of (ValaScope* self, ValaScope* scope) {
+	g_return_val_if_fail (VALA_IS_SCOPE (self), FALSE);
+	g_return_val_if_fail (scope == NULL || VALA_IS_SCOPE (scope), FALSE);
+	if (scope == self) {
+		return TRUE;
+	}
+	/* null scope is the root scope*/
+	if (scope == NULL) {
+		return TRUE;
+	}
+	if (self->priv->_parent_scope != NULL) {
+		return vala_scope_is_subscope_of (self->priv->_parent_scope, scope);
+	}
+	return FALSE;
+}
+
+
 ValaSymbol* vala_scope_get_owner (ValaScope* self) {
 	g_return_val_if_fail (VALA_IS_SCOPE (self), NULL);
 	return self->priv->_owner;
