@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #ifndef __VALA_VALASEMANTICANALYZER_H__
@@ -35,6 +35,8 @@
 #include <vala/valaclass.h>
 #include <vala/valastruct.h>
 #include <vala/valainterface.h>
+#include <vala/valaenum.h>
+#include <vala/valaenumvalue.h>
 #include <vala/valadelegate.h>
 #include <vala/valaconstant.h>
 #include <vala/valafield.h>
@@ -54,6 +56,7 @@
 #include <vala/valaifstatement.h>
 #include <vala/valaswitchsection.h>
 #include <vala/valawhilestatement.h>
+#include <vala/valadostatement.h>
 #include <vala/valaforstatement.h>
 #include <vala/valaforeachstatement.h>
 #include <vala/valareturnstatement.h>
@@ -61,6 +64,7 @@
 #include <vala/valatrystatement.h>
 #include <vala/valacatchclause.h>
 #include <vala/valalockstatement.h>
+#include <vala/valadeletestatement.h>
 #include <vala/valaarraycreationexpression.h>
 #include <vala/valabooleanliteral.h>
 #include <vala/valacharacterliteral.h>
@@ -68,7 +72,6 @@
 #include <vala/valarealliteral.h>
 #include <vala/valastringliteral.h>
 #include <vala/valanullliteral.h>
-#include <vala/valaliteralexpression.h>
 #include <vala/valasymbol.h>
 #include <vala/valaparenthesizedexpression.h>
 #include <vala/valamemberaccess.h>
@@ -124,6 +127,7 @@ ValaSymbol* vala_semantic_analyzer_symbol_lookup_inherited (ValaSymbol* sym, con
 ValaDataType* vala_semantic_analyzer_get_actual_type (ValaDataType* derived_instance_type, ValaSymbol* generic_member, ValaDataType* generic_type, ValaCodeNode* node_reference);
 GType vala_semantic_analyzer_get_type (void);
 
+
 G_END_DECLS
 
 #endif
