@@ -1,6 +1,6 @@
 /* valasourcefile.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -42,6 +42,8 @@ G_BEGIN_DECLS
 
 typedef struct _ValaSourceFilePrivate ValaSourceFilePrivate;
 
+#define VALA_TYPE_SOURCE_FILE_DEPENDENCY_TYPE (vala_source_file_dependency_type_get_type ())
+
 /**
  * Represents a Vala source or VAPI package file.
  */
@@ -58,6 +60,7 @@ typedef enum  {
 	VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE
 } ValaSourceFileDependencyType;
 
+
 ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* filename, gboolean pkg);
 void vala_source_file_add_using_directive (ValaSourceFile* self, ValaNamespaceReference* ns);
 GeeCollection* vala_source_file_get_using_directives (ValaSourceFile* self);
@@ -77,6 +80,7 @@ GeeCollection* vala_source_file_get_source_external_includes (ValaSourceFile* se
 GeeCollection* vala_source_file_get_source_internal_includes (ValaSourceFile* self);
 GeeCollection* vala_source_file_get_header_internal_full_dependencies (ValaSourceFile* self);
 GeeCollection* vala_source_file_get_header_internal_dependencies (ValaSourceFile* self);
+char* vala_source_file_get_source_line (ValaSourceFile* self, gint lineno);
 char* vala_source_file_get_filename (ValaSourceFile* self);
 void vala_source_file_set_filename (ValaSourceFile* self, const char* value);
 char* vala_source_file_get_comment (ValaSourceFile* self);
@@ -92,6 +96,8 @@ void vala_source_file_set_mark (ValaSourceFile* self, gint value);
 ValaCodeContext* vala_source_file_get_context (ValaSourceFile* self);
 void vala_source_file_set_context (ValaSourceFile* self, ValaCodeContext* value);
 GType vala_source_file_get_type (void);
+GType vala_source_file_dependency_type_get_type (void);
+
 
 G_END_DECLS
 
