@@ -23,6 +23,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valasourcefile.h>
 
+
+
+
 struct _ValaSourceReferencePrivate {
 	ValaSourceFile* _file;
 	gint _first_line;
@@ -45,6 +48,7 @@ static gpointer vala_source_reference_parent_class = NULL;
 static void vala_source_reference_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new source reference.
  *
@@ -100,7 +104,7 @@ ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _fi
  */
 char* vala_source_reference_to_string (ValaSourceReference* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (self), NULL);
-	return (g_strdup_printf ("%s:%d.%d-%d.%d", vala_source_file_get_filename (vala_source_reference_get_file (self)), vala_source_reference_get_first_line (self), vala_source_reference_get_first_column (self), vala_source_reference_get_last_line (self), vala_source_reference_get_last_column (self)));
+	return (g_strdup_printf ("%s:%d.%d-%d.%d", vala_source_file_get_filename (self->priv->_file), self->priv->_first_line, self->priv->_first_column, self->priv->_last_line, self->priv->_last_column));
 }
 
 
@@ -261,7 +265,7 @@ static void vala_source_reference_init (ValaSourceReference * self) {
 static void vala_source_reference_dispose (GObject * obj) {
 	ValaSourceReference * self;
 	self = VALA_SOURCE_REFERENCE (obj);
-	(self->priv->_comment = (g_free (self->priv->_comment), NULL));
+	self->priv->_comment = (g_free (self->priv->_comment), NULL);
 	G_OBJECT_CLASS (vala_source_reference_parent_class)->dispose (obj);
 }
 
