@@ -1,6 +1,6 @@
 /* valastringliteral.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaStringLiteralPrivate {
 	char* _value;
 };
@@ -33,10 +36,12 @@ enum  {
 	VALA_STRING_LITERAL_VALUE
 };
 static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_string_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_string_literal_parent_class = NULL;
 static void vala_string_literal_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new string literal.
  *
@@ -63,11 +68,11 @@ char* vala_string_literal_eval (ValaStringLiteral* self) {
 	char* noquotes;
 	char* _tmp1;
 	g_return_val_if_fail (VALA_IS_STRING_LITERAL (self), NULL);
-	if (vala_string_literal_get_value (self) == NULL) {
+	if (self->priv->_value == NULL) {
 		return NULL;
 	}
 	/* remove quotes */
-	noquotes = g_strndup (g_utf8_offset_to_pointer (vala_string_literal_get_value (self), 1), ((guint) (g_utf8_strlen (vala_string_literal_get_value (self), -1) - 2)));
+	noquotes = g_strndup (g_utf8_offset_to_pointer (self->priv->_value, ((glong) 1)), ((gulong) ((guint) (g_utf8_strlen (self->priv->_value, -1) - 2))));
 	_tmp1 = NULL;
 	return (_tmp1 = g_strcompress (noquotes), (noquotes = (g_free (noquotes), NULL)), _tmp1);
 }
@@ -82,6 +87,13 @@ static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor
 }
 
 
+static gboolean vala_string_literal_real_is_pure (ValaExpression* base) {
+	ValaStringLiteral * self;
+	self = VALA_STRING_LITERAL (base);
+	return TRUE;
+}
+
+
 char* vala_string_literal_get_value (ValaStringLiteral* self) {
 	g_return_val_if_fail (VALA_IS_STRING_LITERAL (self), NULL);
 	return self->priv->_value;
@@ -133,6 +145,7 @@ static void vala_string_literal_class_init (ValaStringLiteralClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = vala_string_literal_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_string_literal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_string_literal_real_accept;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_string_literal_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_STRING_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -145,7 +158,7 @@ static void vala_string_literal_init (ValaStringLiteral * self) {
 static void vala_string_literal_dispose (GObject * obj) {
 	ValaStringLiteral * self;
 	self = VALA_STRING_LITERAL (obj);
-	(self->priv->_value = (g_free (self->priv->_value), NULL));
+	self->priv->_value = (g_free (self->priv->_value), NULL);
 	G_OBJECT_CLASS (vala_string_literal_parent_class)->dispose (obj);
 }
 
