@@ -25,6 +25,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaSwitchLabelPrivate {
 	ValaExpression* _expression;
 };
@@ -38,6 +41,7 @@ static gpointer vala_switch_label_parent_class = NULL;
 static void vala_switch_label_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new switch case label.
  *
@@ -74,10 +78,10 @@ ValaSwitchLabel* vala_switch_label_new_with_default (ValaSourceReference* source
 static void vala_switch_label_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSwitchLabel * self;
 	self = VALA_SWITCH_LABEL (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	if (vala_switch_label_get_expression (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_switch_label_get_expression (self)), visitor);
-		vala_code_visitor_visit_end_full_expression (visitor, vala_switch_label_get_expression (self));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	if (self->priv->_expression != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_expression), visitor);
+		vala_code_visitor_visit_end_full_expression (visitor, self->priv->_expression);
 	}
 	vala_code_visitor_visit_switch_label (visitor, self);
 }
