@@ -29,6 +29,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaSwitchSectionPrivate {
 	GeeList* labels;
 	GeeList* statement_list;
@@ -43,6 +46,7 @@ static gpointer vala_switch_section_parent_class = NULL;
 static void vala_switch_section_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new switch section.
  *
@@ -90,7 +94,7 @@ gboolean vala_switch_section_has_default_label (ValaSwitchSection* self) {
 		label_it = gee_iterable_iterator (GEE_ITERABLE (label_collection));
 		while (gee_iterator_next (label_it)) {
 			ValaSwitchLabel* label;
-			label = gee_iterator_get (label_it);
+			label = ((ValaSwitchLabel*) gee_iterator_get (label_it));
 			{
 				if (vala_switch_label_get_expression (label) == NULL) {
 					gboolean _tmp0;
@@ -147,7 +151,7 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 		label_it = gee_iterable_iterator (GEE_ITERABLE (label_collection));
 		while (gee_iterator_next (label_it)) {
 			ValaSwitchLabel* label;
-			label = gee_iterator_get (label_it);
+			label = ((ValaSwitchLabel*) gee_iterator_get (label_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (label), visitor);
 				(label == NULL ? NULL : (label = (g_object_unref (label), NULL)));
@@ -162,7 +166,7 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 		st_it = gee_iterable_iterator (GEE_ITERABLE (st_collection));
 		while (gee_iterator_next (st_it)) {
 			ValaStatement* st;
-			st = gee_iterator_get (st_it);
+			st = ((ValaStatement*) gee_iterator_get (st_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (st), visitor);
 				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
