@@ -31,12 +31,23 @@
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
 #include <vala/valatypesymbol.h>
+#include <vala/valaunresolvedsymbol.h>
 #include <vala/valaunresolvedtype.h>
 #include <vala/valavoidtype.h>
-#include <vala/valatypeparameter.h>
 #include <vala/valainvalidtype.h>
+#include <vala/valatypeparameter.h>
+#include <vala/valatypeparametertype.h>
 #include <vala/valadelegatetype.h>
+#include <vala/valaerrortype.h>
+#include <vala/valaerrordomain.h>
+#include <vala/valaclasstype.h>
+#include <vala/valainterfacetype.h>
+#include <vala/valavaluetype.h>
 #include <vala/valapointertype.h>
+#include <vala/valaarraytype.h>
+
+
+
 
 struct _ValaSymbolResolverPrivate {
 	ValaSymbol* root_symbol;
@@ -65,23 +76,31 @@ static void vala_symbol_resolver_real_visit_constructor (ValaCodeVisitor* base,
 static void vala_symbol_resolver_real_visit_destructor (ValaCodeVisitor* base, ValaDestructor* d);
 static void vala_symbol_resolver_real_visit_block (ValaCodeVisitor* base, ValaBlock* b);
 static void vala_symbol_resolver_real_visit_namespace_reference (ValaCodeVisitor* base, ValaNamespaceReference* ns);
+static ValaSymbol* vala_symbol_resolver_resolve_symbol (ValaSymbolResolver* self, ValaUnresolvedSymbol* unresolved_symbol);
 static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self, ValaUnresolvedType* unresolved_type);
 static void vala_symbol_resolver_real_visit_data_type (ValaCodeVisitor* base, ValaDataType* data_type);
 static void vala_symbol_resolver_real_visit_variable_declarator (ValaCodeVisitor* base, ValaVariableDeclarator* decl);
 static void vala_symbol_resolver_real_visit_initializer_list (ValaCodeVisitor* base, ValaInitializerList* list);
+static void vala_symbol_resolver_real_visit_if_statement (ValaCodeVisitor* base, ValaIfStatement* stmt);
 static void vala_symbol_resolver_real_visit_switch_section (ValaCodeVisitor* base, ValaSwitchSection* section);
+static void vala_symbol_resolver_real_visit_while_statement (ValaCodeVisitor* base, ValaWhileStatement* stmt);
+static void vala_symbol_resolver_real_visit_do_statement (ValaCodeVisitor* base, ValaDoStatement* stmt);
+static void vala_symbol_resolver_real_visit_for_statement (ValaCodeVisitor* base, ValaForStatement* stmt);
 static void vala_symbol_resolver_real_visit_foreach_statement (ValaCodeVisitor* base, ValaForeachStatement* stmt);
 static void vala_symbol_resolver_real_visit_return_statement (ValaCodeVisitor* base, ValaReturnStatement* stmt);
 static void vala_symbol_resolver_real_visit_throw_statement (ValaCodeVisitor* base, ValaThrowStatement* stmt);
 static void vala_symbol_resolver_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt);
 static void vala_symbol_resolver_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause);
 static void vala_symbol_resolver_real_visit_array_creation_expression (ValaCodeVisitor* base, ValaArrayCreationExpression* e);
+static void vala_symbol_resolver_real_visit_parenthesized_expression (ValaCodeVisitor* base, ValaParenthesizedExpression* expr);
 static void vala_symbol_resolver_real_visit_invocation_expression (ValaCodeVisitor* base, ValaInvocationExpression* expr);
 static void vala_symbol_resolver_real_visit_object_creation_expression (ValaCodeVisitor* base, ValaObjectCreationExpression* expr);
 static void vala_symbol_resolver_real_visit_lambda_expression (ValaCodeVisitor* base, ValaLambdaExpression* l);
 static void vala_symbol_resolver_real_visit_assignment (ValaCodeVisitor* base, ValaAssignment* a);
 static gpointer vala_symbol_resolver_parent_class = NULL;
 static void vala_symbol_resolver_dispose (GObject * obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
+
 
 
 /**
@@ -144,7 +163,7 @@ static void vala_symbol_resolver_real_visit_class (ValaCodeVisitor* base, ValaCl
 		type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
 		while (gee_iterator_next (type_it)) {
 			ValaDataType* type;
-			type = gee_iterator_get (type_it);
+			type = ((ValaDataType*) gee_iterator_get (type_it));
 			{
 				if (VALA_IS_CLASS (vala_data_type_get_data_type (type))) {
 					if (vala_class_get_base_class (cl) != NULL) {
@@ -158,10 +177,10 @@ static void vala_symbol_resolver_real_visit_class (ValaCodeVisitor* base, ValaCl
 						_tmp3 = NULL;
 						_tmp2 = NULL;
 						vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (type)), (_tmp5 = g_strdup_printf ("%s: Classes cannot have multiple base classes (`%s' and `%s')", (_tmp2 = vala_symbol_get_full_name (VALA_SYMBOL (cl))), (_tmp3 = vala_symbol_get_full_name (VALA_SYMBOL (vala_class_get_base_class (cl)))), (_tmp4 = vala_symbol_get_full_name (VALA_SYMBOL (vala_data_type_get_data_type (type)))))));
-						(_tmp5 = (g_free (_tmp5), NULL));
-						(_tmp4 = (g_free (_tmp4), NULL));
-						(_tmp3 = (g_free (_tmp3), NULL));
-						(_tmp2 = (g_free (_tmp2), NULL));
+						_tmp5 = (g_free (_tmp5), NULL);
+						_tmp4 = (g_free (_tmp4), NULL);
+						_tmp3 = (g_free (_tmp3), NULL);
+						_tmp2 = (g_free (_tmp2), NULL);
 						(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
 						(type_collection == NULL ? NULL : (type_collection = (g_object_unref (type_collection), NULL)));
 						(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
@@ -177,9 +196,9 @@ static void vala_symbol_resolver_real_visit_class (ValaCodeVisitor* base, ValaCl
 						_tmp7 = NULL;
 						_tmp6 = NULL;
 						vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (type)), (_tmp8 = g_strdup_printf ("Base class cycle (`%s' and `%s')", (_tmp6 = vala_symbol_get_full_name (VALA_SYMBOL (cl))), (_tmp7 = vala_symbol_get_full_name (VALA_SYMBOL (vala_class_get_base_class (cl)))))));
-						(_tmp8 = (g_free (_tmp8), NULL));
-						(_tmp7 = (g_free (_tmp7), NULL));
-						(_tmp6 = (g_free (_tmp6), NULL));
+						_tmp8 = (g_free (_tmp8), NULL);
+						_tmp7 = (g_free (_tmp7), NULL);
+						_tmp6 = (g_free (_tmp6), NULL);
 						(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
 						(type_collection == NULL ? NULL : (type_collection = (g_object_unref (type_collection), NULL)));
 						(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
@@ -235,7 +254,7 @@ static void vala_symbol_resolver_real_visit_interface (ValaCodeVisitor* base, Va
 		type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
 		while (gee_iterator_next (type_it)) {
 			ValaDataType* type;
-			type = gee_iterator_get (type_it);
+			type = ((ValaDataType*) gee_iterator_get (type_it));
 			{
 				if (vala_data_type_get_data_type (type) != NULL && vala_typesymbol_is_subtype_of (vala_data_type_get_data_type (type), VALA_TYPESYMBOL (iface))) {
 					char* _tmp4;
@@ -246,9 +265,9 @@ static void vala_symbol_resolver_real_visit_interface (ValaCodeVisitor* base, Va
 					_tmp3 = NULL;
 					_tmp2 = NULL;
 					vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (type)), (_tmp4 = g_strdup_printf ("Prerequisite cycle (`%s' and `%s')", (_tmp2 = vala_symbol_get_full_name (VALA_SYMBOL (iface))), (_tmp3 = vala_symbol_get_full_name (VALA_SYMBOL (vala_data_type_get_data_type (type)))))));
-					(_tmp4 = (g_free (_tmp4), NULL));
-					(_tmp3 = (g_free (_tmp3), NULL));
-					(_tmp2 = (g_free (_tmp2), NULL));
+					_tmp4 = (g_free (_tmp4), NULL);
+					_tmp3 = (g_free (_tmp3), NULL);
+					_tmp2 = (g_free (_tmp2), NULL);
 					(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
 					(type_collection == NULL ? NULL : (type_collection = (g_object_unref (type_collection), NULL)));
 					(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
@@ -428,67 +447,32 @@ static void vala_symbol_resolver_real_visit_namespace_reference (ValaCodeVisitor
 		vala_code_node_set_error (VALA_CODE_NODE (ns), TRUE);
 		_tmp1 = NULL;
 		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (ns)), (_tmp1 = g_strdup_printf ("The namespace name `%s' could not be found", vala_namespace_reference_get_name (ns))));
-		(_tmp1 = (g_free (_tmp1), NULL));
+		_tmp1 = (g_free (_tmp1), NULL);
 		return;
 	}
 }
 
 
-static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self, ValaUnresolvedType* unresolved_type) {
-	ValaDataType* type;
+static ValaSymbol* vala_symbol_resolver_resolve_symbol (ValaSymbolResolver* self, ValaUnresolvedSymbol* unresolved_symbol) {
 	g_return_val_if_fail (VALA_IS_SYMBOL_RESOLVER (self), NULL);
-	g_return_val_if_fail (unresolved_type == NULL || VALA_IS_UNRESOLVED_TYPE (unresolved_type), NULL);
-	type = vala_data_type_new ();
-	vala_code_node_set_source_reference (VALA_CODE_NODE (type), vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)));
-	vala_data_type_set_takes_ownership (type, vala_unresolved_type_get_takes_ownership (unresolved_type));
-	vala_data_type_set_transfers_ownership (type, vala_unresolved_type_get_transfers_ownership (unresolved_type));
-	vala_data_type_set_is_ref (type, vala_unresolved_type_get_is_ref (unresolved_type));
-	vala_data_type_set_is_out (type, vala_unresolved_type_get_is_out (unresolved_type));
-	vala_data_type_set_nullable (type, vala_unresolved_type_get_nullable (unresolved_type));
-	{
-		GeeList* type_arg_collection;
-		GeeIterator* type_arg_it;
-		type_arg_collection = vala_data_type_get_type_arguments (VALA_DATA_TYPE (unresolved_type));
-		type_arg_it = gee_iterable_iterator (GEE_ITERABLE (type_arg_collection));
-		while (gee_iterator_next (type_arg_it)) {
-			ValaDataType* type_arg;
-			type_arg = gee_iterator_get (type_arg_it);
-			{
-				vala_data_type_add_type_argument (type, type_arg);
-				(type_arg == NULL ? NULL : (type_arg = (g_object_unref (type_arg), NULL)));
-			}
-		}
-		(type_arg_collection == NULL ? NULL : (type_arg_collection = (g_object_unref (type_arg_collection), NULL)));
-		(type_arg_it == NULL ? NULL : (type_arg_it = (g_object_unref (type_arg_it), NULL)));
-	}
-	/* still required for vapigen*/
-	if (g_utf8_collate (vala_unresolved_type_get_type_name (unresolved_type), "void") == 0) {
-		ValaVoidType* _tmp0;
-		_tmp0 = NULL;
-		return VALA_DATA_TYPE ((_tmp0 = vala_void_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp0));
-	}
-	if (vala_unresolved_type_get_namespace_name (unresolved_type) == NULL) {
+	g_return_val_if_fail (unresolved_symbol == NULL || VALA_IS_UNRESOLVED_SYMBOL (unresolved_symbol), NULL);
+	if (vala_unresolved_symbol_get_inner (unresolved_symbol) == NULL) {
 		ValaSymbol* sym;
-		ValaScope* _tmp1;
+		ValaScope* _tmp0;
 		ValaScope* scope;
+		ValaSymbol* _tmp10;
 		sym = NULL;
-		_tmp1 = NULL;
-		scope = (_tmp1 = self->priv->current_scope, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+		_tmp0 = NULL;
+		scope = (_tmp0 = self->priv->current_scope, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 		while (sym == NULL && scope != NULL) {
-			ValaSymbol* _tmp2;
-			ValaScope* _tmp4;
+			ValaSymbol* _tmp1;
 			ValaScope* _tmp3;
-			_tmp2 = NULL;
-			sym = (_tmp2 = vala_scope_lookup (scope, vala_unresolved_type_get_type_name (unresolved_type)), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp2);
-			_tmp4 = NULL;
+			ValaScope* _tmp2;
+			_tmp1 = NULL;
+			sym = (_tmp1 = vala_scope_lookup (scope, vala_unresolved_symbol_get_name (unresolved_symbol)), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp1);
 			_tmp3 = NULL;
-			scope = (_tmp4 = (_tmp3 = vala_scope_get_parent_scope (scope), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3))), (scope == NULL ? NULL : (scope = (g_object_unref (scope), NULL))), _tmp4);
-			if (sym != NULL && !(VALA_IS_TYPESYMBOL (sym)) && !(VALA_IS_TYPEPARAMETER (sym))) {
-				ValaSymbol* _tmp5;
-				/* ignore non-type symbols*/
-				_tmp5 = NULL;
-				sym = (_tmp5 = NULL, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp5);
-			}
+			_tmp2 = NULL;
+			scope = (_tmp3 = (_tmp2 = vala_scope_get_parent_scope (scope), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (scope == NULL ? NULL : (scope = (g_object_unref (scope), NULL))), _tmp3);
 		}
 		if (sym == NULL) {
 			{
@@ -498,35 +482,35 @@ static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self
 				ns_it = gee_iterable_iterator (GEE_ITERABLE (ns_collection));
 				while (gee_iterator_next (ns_it)) {
 					ValaNamespaceReference* ns;
-					ns = gee_iterator_get (ns_it);
+					ns = ((ValaNamespaceReference*) gee_iterator_get (ns_it));
 					{
 						ValaSymbol* local_sym;
 						if (vala_code_node_get_error (VALA_CODE_NODE (ns))) {
 							(ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL)));
 							continue;
 						}
-						local_sym = vala_scope_lookup (vala_symbol_get_scope (vala_namespace_reference_get_namespace_symbol (ns)), vala_unresolved_type_get_type_name (unresolved_type));
+						local_sym = vala_scope_lookup (vala_symbol_get_scope (vala_namespace_reference_get_namespace_symbol (ns)), vala_unresolved_symbol_get_name (unresolved_symbol));
 						if (local_sym != NULL) {
-							ValaSymbol* _tmp11;
-							ValaSymbol* _tmp10;
+							ValaSymbol* _tmp9;
+							ValaSymbol* _tmp8;
 							if (sym != NULL) {
-								char* _tmp8;
-								char* _tmp7;
 								char* _tmp6;
-								ValaInvalidType* _tmp9;
-								_tmp8 = NULL;
-								_tmp7 = NULL;
+								char* _tmp5;
+								char* _tmp4;
+								gpointer _tmp7;
+								vala_code_node_set_error (VALA_CODE_NODE (unresolved_symbol), TRUE);
 								_tmp6 = NULL;
-								vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (type)), (_tmp8 = g_strdup_printf ("`%s' is an ambiguous reference between `%s' and `%s'", vala_unresolved_type_get_type_name (unresolved_type), (_tmp6 = vala_symbol_get_full_name (sym)), (_tmp7 = vala_symbol_get_full_name (local_sym)))));
-								(_tmp8 = (g_free (_tmp8), NULL));
-								(_tmp7 = (g_free (_tmp7), NULL));
-								(_tmp6 = (g_free (_tmp6), NULL));
-								_tmp9 = NULL;
-								return VALA_DATA_TYPE ((_tmp9 = vala_invalid_type_new (), (ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL))), (local_sym == NULL ? NULL : (local_sym = (g_object_unref (local_sym), NULL))), (ns_it == NULL ? NULL : (ns_it = (g_object_unref (ns_it), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), (scope == NULL ? NULL : (scope = (g_object_unref (scope), NULL))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp9));
+								_tmp5 = NULL;
+								_tmp4 = NULL;
+								vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_symbol)), (_tmp6 = g_strdup_printf ("`%s' is an ambiguous reference between `%s' and `%s'", vala_unresolved_symbol_get_name (unresolved_symbol), (_tmp4 = vala_symbol_get_full_name (sym)), (_tmp5 = vala_symbol_get_full_name (local_sym)))));
+								_tmp6 = (g_free (_tmp6), NULL);
+								_tmp5 = (g_free (_tmp5), NULL);
+								_tmp4 = (g_free (_tmp4), NULL);
+								return (_tmp7 = NULL, (ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL))), (local_sym == NULL ? NULL : (local_sym = (g_object_unref (local_sym), NULL))), (ns_it == NULL ? NULL : (ns_it = (g_object_unref (ns_it), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), (scope == NULL ? NULL : (scope = (g_object_unref (scope), NULL))), _tmp7);
 							}
-							_tmp11 = NULL;
-							_tmp10 = NULL;
-							sym = (_tmp11 = (_tmp10 = local_sym, (_tmp10 == NULL ? NULL : g_object_ref (_tmp10))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp11);
+							_tmp9 = NULL;
+							_tmp8 = NULL;
+							sym = (_tmp9 = (_tmp8 = local_sym, (_tmp8 == NULL ? NULL : g_object_ref (_tmp8))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp9);
 						}
 						(ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL)));
 						(local_sym == NULL ? NULL : (local_sym = (g_object_unref (local_sym), NULL)));
@@ -535,148 +519,208 @@ static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self
 				(ns_it == NULL ? NULL : (ns_it = (g_object_unref (ns_it), NULL)));
 			}
 		}
-		if (sym == NULL) {
-			char* _tmp12;
-			ValaInvalidType* _tmp13;
-			_tmp12 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (type)), (_tmp12 = g_strdup_printf ("The type name `%s' could not be found", vala_unresolved_type_get_type_name (unresolved_type))));
-			(_tmp12 = (g_free (_tmp12), NULL));
-			_tmp13 = NULL;
-			return VALA_DATA_TYPE ((_tmp13 = vala_invalid_type_new (), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), (scope == NULL ? NULL : (scope = (g_object_unref (scope), NULL))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp13));
-		}
-		if (VALA_IS_TYPEPARAMETER (sym)) {
-			vala_data_type_set_type_parameter (type, VALA_TYPEPARAMETER (sym));
-		} else {
-			if (VALA_IS_TYPESYMBOL (sym)) {
-				if (VALA_IS_DELEGATE (sym)) {
-					ValaDataType* _tmp14;
-					_tmp14 = NULL;
-					type = (_tmp14 = VALA_DATA_TYPE (vala_delegate_type_new (VALA_DELEGATE (sym))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp14);
-				} else {
-					vala_data_type_set_data_type (type, VALA_TYPESYMBOL (sym));
-				}
-			} else {
-				char* _tmp16;
-				char* _tmp15;
-				ValaInvalidType* _tmp17;
-				_tmp16 = NULL;
-				_tmp15 = NULL;
-				vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (type)), (_tmp16 = g_strdup_printf ("`%s' is not a type", (_tmp15 = vala_symbol_get_full_name (sym)))));
-				(_tmp16 = (g_free (_tmp16), NULL));
-				(_tmp15 = (g_free (_tmp15), NULL));
-				_tmp17 = NULL;
-				return VALA_DATA_TYPE ((_tmp17 = vala_invalid_type_new (), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), (scope == NULL ? NULL : (scope = (g_object_unref (scope), NULL))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp17));
-			}
-		}
-		(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
-		(scope == NULL ? NULL : (scope = (g_object_unref (scope), NULL)));
+		_tmp10 = NULL;
+		return (_tmp10 = sym, (scope == NULL ? NULL : (scope = (g_object_unref (scope), NULL))), _tmp10);
 	} else {
-		ValaSymbol* ns_symbol;
-		ValaSymbol* sym;
-		ns_symbol = vala_scope_lookup (vala_symbol_get_scope (self->priv->root_symbol), vala_unresolved_type_get_namespace_name (unresolved_type));
-		if (ns_symbol == NULL) {
-			char* _tmp18;
-			ValaInvalidType* _tmp19;
-			vala_code_node_set_error (VALA_CODE_NODE (type), TRUE);
-			_tmp18 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (type)), (_tmp18 = g_strdup_printf ("The namespace name `%s' could not be found", vala_unresolved_type_get_namespace_name (unresolved_type))));
-			(_tmp18 = (g_free (_tmp18), NULL));
-			_tmp19 = NULL;
-			return VALA_DATA_TYPE ((_tmp19 = vala_invalid_type_new (), (ns_symbol == NULL ? NULL : (ns_symbol = (g_object_unref (ns_symbol), NULL))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp19));
+		ValaSymbol* parent_symbol;
+		ValaSymbol* _tmp13;
+		parent_symbol = vala_symbol_resolver_resolve_symbol (self, vala_unresolved_symbol_get_inner (unresolved_symbol));
+		if (parent_symbol == NULL) {
+			char* _tmp11;
+			gpointer _tmp12;
+			vala_code_node_set_error (VALA_CODE_NODE (unresolved_symbol), TRUE);
+			_tmp11 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (vala_unresolved_symbol_get_inner (unresolved_symbol))), (_tmp11 = g_strdup_printf ("The symbol `%s' could not be found", vala_unresolved_symbol_get_name (vala_unresolved_symbol_get_inner (unresolved_symbol)))));
+			_tmp11 = (g_free (_tmp11), NULL);
+			return (_tmp12 = NULL, (parent_symbol == NULL ? NULL : (parent_symbol = (g_object_unref (parent_symbol), NULL))), _tmp12);
 		}
-		sym = vala_scope_lookup (vala_symbol_get_scope (ns_symbol), vala_unresolved_type_get_type_name (unresolved_type));
-		if (sym == NULL) {
-			char* _tmp20;
-			ValaInvalidType* _tmp21;
-			_tmp20 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (type)), (_tmp20 = g_strdup_printf ("The type name `%s' does not exist in the namespace `%s'", vala_unresolved_type_get_type_name (unresolved_type), vala_unresolved_type_get_namespace_name (unresolved_type))));
-			(_tmp20 = (g_free (_tmp20), NULL));
-			_tmp21 = NULL;
-			return VALA_DATA_TYPE ((_tmp21 = vala_invalid_type_new (), (ns_symbol == NULL ? NULL : (ns_symbol = (g_object_unref (ns_symbol), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp21));
+		_tmp13 = NULL;
+		return (_tmp13 = vala_scope_lookup (vala_symbol_get_scope (parent_symbol), vala_unresolved_symbol_get_name (unresolved_symbol)), (parent_symbol == NULL ? NULL : (parent_symbol = (g_object_unref (parent_symbol), NULL))), _tmp13);
+	}
+}
+
+
+static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self, ValaUnresolvedType* unresolved_type) {
+	ValaDataType* type;
+	ValaSymbol* sym;
+	ValaDataType* _tmp23;
+	g_return_val_if_fail (VALA_IS_SYMBOL_RESOLVER (self), NULL);
+	g_return_val_if_fail (unresolved_type == NULL || VALA_IS_UNRESOLVED_TYPE (unresolved_type), NULL);
+	type = NULL;
+	/* still required for vapigen*/
+	if (_vala_strcmp0 (vala_unresolved_symbol_get_name (vala_unresolved_type_get_unresolved_symbol (unresolved_type)), "void") == 0) {
+		ValaVoidType* _tmp0;
+		_tmp0 = NULL;
+		return VALA_DATA_TYPE ((_tmp0 = vala_void_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp0));
+	}
+	sym = vala_symbol_resolver_resolve_symbol (self, vala_unresolved_type_get_unresolved_symbol (unresolved_type));
+	if (sym == NULL) {
+		ValaInvalidType* _tmp3;
+		/* don't report same error twice*/
+		if (!vala_code_node_get_error (VALA_CODE_NODE (vala_unresolved_type_get_unresolved_symbol (unresolved_type)))) {
+			char* _tmp2;
+			char* _tmp1;
+			_tmp2 = NULL;
+			_tmp1 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)), (_tmp2 = g_strdup_printf ("The type name `%s' could not be found", (_tmp1 = vala_code_node_to_string (VALA_CODE_NODE (vala_unresolved_type_get_unresolved_symbol (unresolved_type)))))));
+			_tmp2 = (g_free (_tmp2), NULL);
+			_tmp1 = (g_free (_tmp1), NULL);
 		}
+		_tmp3 = NULL;
+		return VALA_DATA_TYPE ((_tmp3 = vala_invalid_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp3));
+	}
+	if (VALA_IS_TYPEPARAMETER (sym)) {
+		ValaDataType* _tmp4;
+		_tmp4 = NULL;
+		type = (_tmp4 = VALA_DATA_TYPE (vala_typeparameter_type_new (VALA_TYPEPARAMETER (sym))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp4);
+	} else {
 		if (VALA_IS_TYPESYMBOL (sym)) {
 			if (VALA_IS_DELEGATE (sym)) {
-				ValaDataType* _tmp22;
-				_tmp22 = NULL;
-				type = (_tmp22 = VALA_DATA_TYPE (vala_delegate_type_new (VALA_DELEGATE (sym))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp22);
+				ValaDataType* _tmp5;
+				_tmp5 = NULL;
+				type = (_tmp5 = VALA_DATA_TYPE (vala_delegate_type_new (VALA_DELEGATE (sym))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp5);
 			} else {
-				vala_data_type_set_data_type (type, VALA_TYPESYMBOL (sym));
+				if (VALA_IS_CLASS (sym)) {
+					ValaClass* _tmp6;
+					ValaClass* cl;
+					_tmp6 = NULL;
+					cl = (_tmp6 = VALA_CLASS (sym), (_tmp6 == NULL ? NULL : g_object_ref (_tmp6)));
+					if (vala_class_get_is_error_base (cl)) {
+						ValaDataType* _tmp7;
+						_tmp7 = NULL;
+						type = (_tmp7 = VALA_DATA_TYPE (vala_error_type_new (NULL, vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp7);
+					} else {
+						ValaDataType* _tmp8;
+						_tmp8 = NULL;
+						type = (_tmp8 = VALA_DATA_TYPE (vala_class_type_new (cl)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp8);
+					}
+					(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
+				} else {
+					if (VALA_IS_INTERFACE (sym)) {
+						ValaDataType* _tmp9;
+						_tmp9 = NULL;
+						type = (_tmp9 = VALA_DATA_TYPE (vala_interface_type_new (VALA_INTERFACE (sym))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp9);
+					} else {
+						if (VALA_IS_STRUCT (sym)) {
+							ValaDataType* _tmp10;
+							_tmp10 = NULL;
+							type = (_tmp10 = VALA_DATA_TYPE (vala_value_type_new (VALA_TYPESYMBOL (VALA_STRUCT (sym)))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp10);
+						} else {
+							if (VALA_IS_ENUM (sym)) {
+								ValaDataType* _tmp11;
+								_tmp11 = NULL;
+								type = (_tmp11 = VALA_DATA_TYPE (vala_value_type_new (VALA_TYPESYMBOL (VALA_ENUM (sym)))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp11);
+							} else {
+								if (VALA_IS_ERROR_DOMAIN (sym)) {
+									ValaDataType* _tmp12;
+									_tmp12 = NULL;
+									type = (_tmp12 = VALA_DATA_TYPE (vala_error_type_new (VALA_ERROR_DOMAIN (sym), vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp12);
+								} else {
+									char* _tmp14;
+									char* _tmp13;
+									ValaInvalidType* _tmp15;
+									_tmp14 = NULL;
+									_tmp13 = NULL;
+									vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)), (_tmp14 = g_strdup_printf ("internal error: `%s' is not a supported type", (_tmp13 = vala_symbol_get_full_name (sym)))));
+									_tmp14 = (g_free (_tmp14), NULL);
+									_tmp13 = (g_free (_tmp13), NULL);
+									_tmp15 = NULL;
+									return VALA_DATA_TYPE ((_tmp15 = vala_invalid_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp15));
+								}
+							}
+						}
+					}
+				}
 			}
 		} else {
-			char* _tmp24;
-			char* _tmp23;
-			ValaInvalidType* _tmp25;
-			_tmp24 = NULL;
-			_tmp23 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (type)), (_tmp24 = g_strdup_printf ("`%s' is not a type", (_tmp23 = vala_symbol_get_full_name (sym)))));
-			(_tmp24 = (g_free (_tmp24), NULL));
-			(_tmp23 = (g_free (_tmp23), NULL));
-			_tmp25 = NULL;
-			return VALA_DATA_TYPE ((_tmp25 = vala_invalid_type_new (), (ns_symbol == NULL ? NULL : (ns_symbol = (g_object_unref (ns_symbol), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp25));
+			char* _tmp17;
+			char* _tmp16;
+			ValaInvalidType* _tmp18;
+			_tmp17 = NULL;
+			_tmp16 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)), (_tmp17 = g_strdup_printf ("`%s' is not a type", (_tmp16 = vala_symbol_get_full_name (sym)))));
+			_tmp17 = (g_free (_tmp17), NULL);
+			_tmp16 = (g_free (_tmp16), NULL);
+			_tmp18 = NULL;
+			return VALA_DATA_TYPE ((_tmp18 = vala_invalid_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp18));
 		}
-		(ns_symbol == NULL ? NULL : (ns_symbol = (g_object_unref (ns_symbol), NULL)));
-		(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+	}
+	vala_code_node_set_source_reference (VALA_CODE_NODE (type), vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)));
+	vala_data_type_set_takes_ownership (type, vala_data_type_get_takes_ownership (VALA_DATA_TYPE (unresolved_type)));
+	vala_data_type_set_transfers_ownership (type, vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (unresolved_type)));
+	vala_data_type_set_is_ref (type, vala_data_type_get_is_ref (VALA_DATA_TYPE (unresolved_type)));
+	vala_data_type_set_is_out (type, vala_data_type_get_is_out (VALA_DATA_TYPE (unresolved_type)));
+	vala_data_type_set_nullable (type, vala_data_type_get_nullable (VALA_DATA_TYPE (unresolved_type)));
+	vala_data_type_set_requires_null_check (type, vala_data_type_get_requires_null_check (VALA_DATA_TYPE (unresolved_type)));
+	{
+		GeeList* type_arg_collection;
+		GeeIterator* type_arg_it;
+		type_arg_collection = vala_data_type_get_type_arguments (VALA_DATA_TYPE (unresolved_type));
+		type_arg_it = gee_iterable_iterator (GEE_ITERABLE (type_arg_collection));
+		while (gee_iterator_next (type_arg_it)) {
+			ValaDataType* type_arg;
+			type_arg = ((ValaDataType*) gee_iterator_get (type_arg_it));
+			{
+				vala_data_type_add_type_argument (type, type_arg);
+				(type_arg == NULL ? NULL : (type_arg = (g_object_unref (type_arg), NULL)));
+			}
+		}
+		(type_arg_collection == NULL ? NULL : (type_arg_collection = (g_object_unref (type_arg_collection), NULL)));
+		(type_arg_it == NULL ? NULL : (type_arg_it = (g_object_unref (type_arg_it), NULL)));
 	}
 	{
 		gint pointer_level;
 		pointer_level = 0;
 		for (pointer_level = vala_unresolved_type_get_pointer_level (unresolved_type); pointer_level > 0; pointer_level--) {
-			ValaDataType* _tmp26;
-			_tmp26 = NULL;
-			type = (_tmp26 = VALA_DATA_TYPE (vala_pointer_type_new (type)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp26);
+			ValaDataType* _tmp19;
+			ValaDataType* base_type;
+			ValaDataType* _tmp20;
+			_tmp19 = NULL;
+			base_type = (_tmp19 = type, (_tmp19 == NULL ? NULL : g_object_ref (_tmp19)));
+			vala_data_type_set_takes_ownership (base_type, FALSE);
+			vala_data_type_set_transfers_ownership (base_type, FALSE);
+			vala_data_type_set_is_ref (base_type, FALSE);
+			vala_data_type_set_is_out (base_type, FALSE);
+			_tmp20 = NULL;
+			type = (_tmp20 = VALA_DATA_TYPE (vala_pointer_type_new (base_type)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp20);
+			(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
 		}
 	}
-	/* check for array */
-	if (vala_unresolved_type_get_array_rank (unresolved_type) > 0) {
-		ValaDataType* element_type;
-		element_type = vala_data_type_new ();
-		vala_data_type_set_data_type (element_type, vala_data_type_get_data_type (type));
-		vala_data_type_set_type_parameter (element_type, vala_data_type_get_type_parameter (type));
-		{
-			GeeList* type_arg_collection;
-			GeeIterator* type_arg_it;
-			type_arg_collection = vala_data_type_get_type_arguments (type);
-			type_arg_it = gee_iterable_iterator (GEE_ITERABLE (type_arg_collection));
-			while (gee_iterator_next (type_arg_it)) {
-				ValaDataType* type_arg;
-				type_arg = gee_iterator_get (type_arg_it);
-				{
-					vala_data_type_add_type_argument (element_type, type_arg);
-					(type_arg == NULL ? NULL : (type_arg = (g_object_unref (type_arg), NULL)));
-				}
-			}
-			(type_arg_collection == NULL ? NULL : (type_arg_collection = (g_object_unref (type_arg_collection), NULL)));
-			(type_arg_it == NULL ? NULL : (type_arg_it = (g_object_unref (type_arg_it), NULL)));
-		}
-		vala_data_type_remove_all_type_arguments (type);
-		if (vala_data_type_get_data_type (type) != NULL) {
-			ValaArray* _tmp27;
-			if (vala_typesymbol_is_reference_type (vala_data_type_get_data_type (type))) {
-				vala_data_type_set_takes_ownership (element_type, vala_data_type_get_takes_ownership (type));
-			}
-			_tmp27 = NULL;
-			vala_data_type_set_data_type (type, VALA_TYPESYMBOL ((_tmp27 = vala_typesymbol_get_array (vala_data_type_get_data_type (element_type), vala_unresolved_type_get_array_rank (unresolved_type)))));
-			(_tmp27 == NULL ? NULL : (_tmp27 = (g_object_unref (_tmp27), NULL)));
-		} else {
-			ValaArray* _tmp28;
-			vala_data_type_set_takes_ownership (element_type, vala_data_type_get_takes_ownership (type));
-			_tmp28 = NULL;
-			vala_data_type_set_data_type (type, VALA_TYPESYMBOL ((_tmp28 = vala_typeparameter_get_array (vala_data_type_get_type_parameter (element_type), vala_unresolved_type_get_array_rank (unresolved_type)))));
-			(_tmp28 == NULL ? NULL : (_tmp28 = (g_object_unref (_tmp28), NULL)));
-			vala_data_type_set_type_parameter (type, NULL);
-		}
-		vala_data_type_add_type_argument (type, element_type);
-		(element_type == NULL ? NULL : (element_type = (g_object_unref (element_type), NULL)));
-	}
-	if (vala_data_type_get_data_type (type) != NULL && !vala_typesymbol_is_reference_type (vala_data_type_get_data_type (type))) {
+	if (!vala_data_type_is_reference_type_or_type_parameter (type)) {
 		/* reset takes_ownership and transfers_ownership of
 		 * value-types for contexts where types are ref by
 		 * default (field declarations and method return types)
 		 */
 		vala_data_type_set_takes_ownership (type, FALSE);
 		vala_data_type_set_transfers_ownership (type, FALSE);
+		/* reset nullable of value-types for local variables */
+		if (vala_data_type_get_nullable (type) && !vala_data_type_get_requires_null_check (type)) {
+			vala_data_type_set_nullable (type, FALSE);
+		}
 	}
-	return type;
+	/* check for array */
+	if (vala_unresolved_type_get_array_rank (unresolved_type) > 0) {
+		ValaDataType* _tmp21;
+		ValaDataType* element_type;
+		ValaDataType* _tmp22;
+		_tmp21 = NULL;
+		element_type = (_tmp21 = type, (_tmp21 == NULL ? NULL : g_object_ref (_tmp21)));
+		vala_data_type_set_transfers_ownership (element_type, FALSE);
+		vala_data_type_set_is_ref (element_type, FALSE);
+		vala_data_type_set_is_out (element_type, FALSE);
+		_tmp22 = NULL;
+		type = (_tmp22 = VALA_DATA_TYPE (vala_array_type_new (element_type, vala_unresolved_type_get_array_rank (unresolved_type), vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp22);
+		vala_data_type_add_type_argument (type, element_type);
+		vala_data_type_set_takes_ownership (type, vala_data_type_get_takes_ownership (VALA_DATA_TYPE (unresolved_type)));
+		vala_data_type_set_transfers_ownership (type, vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (unresolved_type)));
+		vala_data_type_set_is_ref (type, vala_data_type_get_is_ref (VALA_DATA_TYPE (unresolved_type)));
+		vala_data_type_set_is_out (type, vala_data_type_get_is_out (VALA_DATA_TYPE (unresolved_type)));
+		vala_data_type_set_nullable (type, vala_data_type_get_nullable (VALA_DATA_TYPE (unresolved_type)));
+		vala_data_type_set_requires_null_check (type, vala_data_type_get_nullable (VALA_DATA_TYPE (unresolved_type)));
+		(element_type == NULL ? NULL : (element_type = (g_object_unref (element_type), NULL)));
+	}
+	_tmp23 = NULL;
+	return (_tmp23 = type, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp23);
 }
 
 
@@ -715,6 +759,14 @@ static void vala_symbol_resolver_real_visit_initializer_list (ValaCodeVisitor* b
 }
 
 
+static void vala_symbol_resolver_real_visit_if_statement (ValaCodeVisitor* base, ValaIfStatement* stmt) {
+	ValaSymbolResolver * self;
+	self = VALA_SYMBOL_RESOLVER (base);
+	g_return_if_fail (stmt == NULL || VALA_IS_IF_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_symbol_resolver_real_visit_switch_section (ValaCodeVisitor* base, ValaSwitchSection* section) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
@@ -723,6 +775,30 @@ static void vala_symbol_resolver_real_visit_switch_section (ValaCodeVisitor* bas
 }
 
 
+static void vala_symbol_resolver_real_visit_while_statement (ValaCodeVisitor* base, ValaWhileStatement* stmt) {
+	ValaSymbolResolver * self;
+	self = VALA_SYMBOL_RESOLVER (base);
+	g_return_if_fail (stmt == NULL || VALA_IS_WHILE_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_symbol_resolver_real_visit_do_statement (ValaCodeVisitor* base, ValaDoStatement* stmt) {
+	ValaSymbolResolver * self;
+	self = VALA_SYMBOL_RESOLVER (base);
+	g_return_if_fail (stmt == NULL || VALA_IS_DO_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_symbol_resolver_real_visit_for_statement (ValaCodeVisitor* base, ValaForStatement* stmt) {
+	ValaSymbolResolver * self;
+	self = VALA_SYMBOL_RESOLVER (base);
+	g_return_if_fail (stmt == NULL || VALA_IS_FOR_STATEMENT (stmt));
+	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_symbol_resolver_real_visit_foreach_statement (ValaCodeVisitor* base, ValaForeachStatement* stmt) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
@@ -771,6 +847,14 @@ static void vala_symbol_resolver_real_visit_array_creation_expression (ValaCodeV
 }
 
 
+static void vala_symbol_resolver_real_visit_parenthesized_expression (ValaCodeVisitor* base, ValaParenthesizedExpression* expr) {
+	ValaSymbolResolver * self;
+	self = VALA_SYMBOL_RESOLVER (base);
+	g_return_if_fail (expr == NULL || VALA_IS_PARENTHESIZED_EXPRESSION (expr));
+	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_symbol_resolver_real_visit_invocation_expression (ValaCodeVisitor* base, ValaInvocationExpression* expr) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
@@ -838,13 +922,18 @@ static void vala_symbol_resolver_class_init (ValaSymbolResolverClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_data_type = vala_symbol_resolver_real_visit_data_type;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_variable_declarator = vala_symbol_resolver_real_visit_variable_declarator;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_initializer_list = vala_symbol_resolver_real_visit_initializer_list;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_if_statement = vala_symbol_resolver_real_visit_if_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_switch_section = vala_symbol_resolver_real_visit_switch_section;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_while_statement = vala_symbol_resolver_real_visit_while_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_do_statement = vala_symbol_resolver_real_visit_do_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_for_statement = vala_symbol_resolver_real_visit_for_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_foreach_statement = vala_symbol_resolver_real_visit_foreach_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_return_statement = vala_symbol_resolver_real_visit_return_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_throw_statement = vala_symbol_resolver_real_visit_throw_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_try_statement = vala_symbol_resolver_real_visit_try_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_catch_clause = vala_symbol_resolver_real_visit_catch_clause;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_array_creation_expression = vala_symbol_resolver_real_visit_array_creation_expression;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_parenthesized_expression = vala_symbol_resolver_real_visit_parenthesized_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_invocation_expression = vala_symbol_resolver_real_visit_invocation_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_object_creation_expression = vala_symbol_resolver_real_visit_object_creation_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_lambda_expression = vala_symbol_resolver_real_visit_lambda_expression;
@@ -877,5 +966,16 @@ GType vala_symbol_resolver_get_type (void) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
