@@ -1,8 +1,4 @@
-/* FIXME check whether the corresponding data type of one of the
-       parameters is a base type of the corresponding data
-       type of the other parameter and check along the path
-       whether one parameter maps to the other
- valatype.vala
+/* valatype.vala
  *
  * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
  *
@@ -22,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <vala/valatypesymbol.h>
@@ -30,11 +26,12 @@
 #include <gee/list.h>
 #include <gee/map.h>
 #include <gee/readonlycollection.h>
-#include <gee/hashmap.h>
+#include <vala/valacodenode.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasourcefile.h>
-#include <vala/valaarray.h>
-#include <vala/valascope.h>
+
+
+
 
 struct _ValaTypesymbolPrivate {
 	GeeList* cheader_filenames;
@@ -63,15 +60,14 @@ static gpointer vala_typesymbol_parent_class = NULL;
 static void vala_typesymbol_dispose (GObject * obj);
 
 
+
 /**
  * Returns the name of this data type as it is used in C code.
  *
  * @return the name to be used in C code
  */
 char* vala_typesymbol_get_cname (ValaTypesymbol* self, gboolean const_type) {
-	char* result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_cname (self, const_type);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_cname (self, const_type);
 }
 
 
@@ -87,9 +83,7 @@ static gboolean vala_typesymbol_real_is_reference_type (ValaTypesymbol* self) {
 
 
 gboolean vala_typesymbol_is_reference_type (ValaTypesymbol* self) {
-	gboolean result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->is_reference_type (self);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->is_reference_type (self);
 }
 
 
@@ -108,9 +102,7 @@ static char* vala_typesymbol_real_get_dup_function (ValaTypesymbol* self) {
 
 
 char* vala_typesymbol_get_dup_function (ValaTypesymbol* self) {
-	char* result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_dup_function (self);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_dup_function (self);
 }
 
 
@@ -130,9 +122,7 @@ static char* vala_typesymbol_real_get_free_function (ValaTypesymbol* self) {
 
 
 char* vala_typesymbol_get_free_function (ValaTypesymbol* self) {
-	char* result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_free_function (self);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_free_function (self);
 }
 
 
@@ -149,9 +139,7 @@ static gboolean vala_typesymbol_real_is_reference_counting (ValaTypesymbol* self
 
 
 gboolean vala_typesymbol_is_reference_counting (ValaTypesymbol* self) {
-	gboolean result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->is_reference_counting (self);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->is_reference_counting (self);
 }
 
 
@@ -172,9 +160,7 @@ static char* vala_typesymbol_real_get_ref_function (ValaTypesymbol* self) {
 
 
 char* vala_typesymbol_get_ref_function (ValaTypesymbol* self) {
-	char* result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_ref_function (self);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_ref_function (self);
 }
 
 
@@ -194,9 +180,7 @@ static char* vala_typesymbol_real_get_unref_function (ValaTypesymbol* self) {
 
 
 char* vala_typesymbol_get_unref_function (ValaTypesymbol* self) {
-	char* result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_unref_function (self);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_unref_function (self);
 }
 
 
@@ -214,9 +198,7 @@ static char* vala_typesymbol_real_get_type_id (ValaTypesymbol* self) {
 
 
 char* vala_typesymbol_get_type_id (ValaTypesymbol* self) {
-	char* result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_type_id (self);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_type_id (self);
 }
 
 
@@ -232,9 +214,7 @@ static char* vala_typesymbol_real_get_marshaller_type_name (ValaTypesymbol* self
 
 
 char* vala_typesymbol_get_marshaller_type_name (ValaTypesymbol* self) {
-	char* result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_marshaller_type_name (self);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_marshaller_type_name (self);
 }
 
 
@@ -248,9 +228,7 @@ static char* vala_typesymbol_real_get_get_value_function (ValaTypesymbol* self)
 
 
 char* vala_typesymbol_get_get_value_function (ValaTypesymbol* self) {
-	char* result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_get_value_function (self);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_get_value_function (self);
 }
 
 
@@ -264,9 +242,7 @@ static char* vala_typesymbol_real_get_set_value_function (ValaTypesymbol* self)
 
 
 char* vala_typesymbol_get_set_value_function (ValaTypesymbol* self) {
-	char* result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_set_value_function (self);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_set_value_function (self);
 }
 
 
@@ -286,9 +262,7 @@ static char* vala_typesymbol_real_get_upper_case_cname (ValaTypesymbol* self, co
 
 
 char* vala_typesymbol_get_upper_case_cname (ValaTypesymbol* self, const char* infix) {
-	char* result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_upper_case_cname (self, infix);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_upper_case_cname (self, infix);
 }
 
 
@@ -305,9 +279,7 @@ static char* vala_typesymbol_real_get_default_value (ValaTypesymbol* self) {
 
 
 char* vala_typesymbol_get_default_value (ValaTypesymbol* self) {
-	char* result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_default_value (self);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_default_value (self);
 }
 
 
@@ -322,11 +294,11 @@ static GeeCollection* vala_typesymbol_real_get_cheader_filenames (ValaSymbol* ba
 			filename_it = gee_iterable_iterator (GEE_ITERABLE (filename_collection));
 			while (gee_iterator_next (filename_it)) {
 				char* filename;
-				filename = gee_iterator_get (filename_it);
+				filename = ((char*) gee_iterator_get (filename_it));
 				{
 					/* default to header filenames of the namespace */
 					vala_typesymbol_add_cheader_filename (self, filename);
-					(filename = (g_free (filename), NULL));
+					filename = (g_free (filename), NULL);
 				}
 			}
 			(filename_collection == NULL ? NULL : (filename_collection = (g_object_unref (filename_collection), NULL)));
@@ -337,7 +309,7 @@ static GeeCollection* vala_typesymbol_real_get_cheader_filenames (ValaSymbol* ba
 			/* don't add default include directives for VAPI files*/
 			_tmp0 = NULL;
 			gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), (_tmp0 = vala_source_file_get_cinclude_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))));
-			(_tmp0 = (g_free (_tmp0), NULL));
+			_tmp0 = (g_free (_tmp0), NULL);
 		}
 	}
 	return GEE_COLLECTION (gee_read_only_collection_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, GEE_COLLECTION (self->priv->cheader_filenames)));
@@ -356,68 +328,6 @@ void vala_typesymbol_add_cheader_filename (ValaTypesymbol* self, const char* fil
 }
 
 
-/**
- * Returns the array type for elements of this data type.
- *
- * @param rank the rank the array should be of
- * @return array type for this data type
- */
-ValaArray* vala_typesymbol_get_array (ValaTypesymbol* self, gint rank) {
-	ValaArray* array_type;
-	g_return_val_if_fail (VALA_IS_TYPESYMBOL (self), NULL);
-	array_type = NULL;
-	if (self->priv->array_types != NULL) {
-		ValaArray* _tmp0;
-		_tmp0 = NULL;
-		array_type = (_tmp0 = gee_map_get (((GeeMap*) self->priv->array_types), GINT_TO_POINTER (rank)), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), _tmp0);
-	}
-	if (array_type == NULL) {
-		ValaArray* new_array_type;
-		ValaArrayLengthField* _tmp3;
-		ValaArrayLengthField* _tmp2;
-		ValaArrayResizeMethod* _tmp5;
-		ValaArrayResizeMethod* _tmp4;
-		ValaArrayMoveMethod* _tmp7;
-		ValaArrayMoveMethod* _tmp6;
-		ValaArray* _tmp9;
-		ValaArray* _tmp8;
-		if (self->priv->array_types == NULL) {
-			GeeMap* _tmp1;
-			_tmp1 = NULL;
-			self->priv->array_types = (_tmp1 = GEE_MAP (gee_hash_map_new (G_TYPE_INT, NULL, NULL, VALA_TYPE_ARRAY, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_hash, g_direct_equal, g_direct_equal)), (self->priv->array_types == NULL ? NULL : (self->priv->array_types = (g_object_unref (self->priv->array_types), NULL))), _tmp1);
-		}
-		new_array_type = vala_array_new (self, rank, vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
-		vala_scope_add (vala_symbol_get_scope (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))), vala_symbol_get_name (VALA_SYMBOL (new_array_type)), VALA_SYMBOL (new_array_type));
-		/* add internal length field */
-		_tmp3 = NULL;
-		_tmp2 = NULL;
-		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (new_array_type)), vala_symbol_get_name (VALA_SYMBOL ((_tmp2 = vala_array_get_length_field (new_array_type)))), VALA_SYMBOL ((_tmp3 = vala_array_get_length_field (new_array_type))));
-		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
-		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
-		/* add internal resize method */
-		_tmp5 = NULL;
-		_tmp4 = NULL;
-		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (new_array_type)), vala_symbol_get_name (VALA_SYMBOL ((_tmp4 = vala_array_get_resize_method (new_array_type)))), VALA_SYMBOL ((_tmp5 = vala_array_get_resize_method (new_array_type))));
-		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
-		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
-		/* add internal move method */
-		_tmp7 = NULL;
-		_tmp6 = NULL;
-		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (new_array_type)), vala_symbol_get_name (VALA_SYMBOL ((_tmp6 = vala_array_get_move_method (new_array_type)))), VALA_SYMBOL ((_tmp7 = vala_array_get_move_method (new_array_type))));
-		(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
-		(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
-		/* link the array type to the same source as the container type */
-		vala_code_node_set_source_reference (VALA_CODE_NODE (new_array_type), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
-		gee_map_set (((GeeMap*) self->priv->array_types), GINT_TO_POINTER (rank), new_array_type);
-		_tmp9 = NULL;
-		_tmp8 = NULL;
-		array_type = (_tmp9 = (_tmp8 = new_array_type, (_tmp8 == NULL ? NULL : g_object_ref (_tmp8))), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), _tmp9);
-		(new_array_type == NULL ? NULL : (new_array_type = (g_object_unref (new_array_type), NULL)));
-	}
-	return array_type;
-}
-
-
 /**
  * Checks whether this data type is equal to or a subtype of the
  * specified data type.
@@ -433,9 +343,7 @@ static gboolean vala_typesymbol_real_is_subtype_of (ValaTypesymbol* self, ValaTy
 
 
 gboolean vala_typesymbol_is_subtype_of (ValaTypesymbol* self, ValaTypesymbol* t) {
-	gboolean result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->is_subtype_of (self, t);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->is_subtype_of (self, t);
 }
 
 
@@ -449,9 +357,7 @@ static gint vala_typesymbol_real_get_type_parameter_index (ValaTypesymbol* self,
 
 
 gint vala_typesymbol_get_type_parameter_index (ValaTypesymbol* self, const char* name) {
-	gint result;
-	result = VALA_TYPESYMBOL_GET_CLASS (self)->get_type_parameter_index (self, name);
-	return result;
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_type_parameter_index (self, name);
 }
 
 
