@@ -1,6 +1,6 @@
 /* valaunaryexpression.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -42,6 +42,8 @@ G_BEGIN_DECLS
 
 typedef struct _ValaUnaryExpressionPrivate ValaUnaryExpressionPrivate;
 
+#define VALA_TYPE_UNARY_OPERATOR (vala_unary_operator_get_type ())
+
 /**
  * Represents an expression with one operand in the source code.
  *
@@ -65,13 +67,15 @@ typedef enum  {
 	VALA_UNARY_OPERATOR_OUT
 } ValaUnaryOperator;
 
+
 ValaUnaryExpression* vala_unary_expression_new (ValaUnaryOperator op, ValaExpression* _inner, ValaSourceReference* source);
 ValaUnaryOperator vala_unary_expression_get_operator (ValaUnaryExpression* self);
 void vala_unary_expression_set_operator (ValaUnaryExpression* self, ValaUnaryOperator value);
 ValaExpression* vala_unary_expression_get_inner (ValaUnaryExpression* self);
 void vala_unary_expression_set_inner (ValaUnaryExpression* self, ValaExpression* value);
-char* vala_unary_expression_get_operator_string (ValaUnaryExpression* self);
 GType vala_unary_expression_get_type (void);
+GType vala_unary_operator_get_type (void);
+
 
 G_END_DECLS
 
