@@ -18,46 +18,40 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <vala/valaunresolvedtype.h>
+#include <stdlib.h>
+#include <string.h>
 #include <gee/collection.h>
 #include <vala/valacodenode.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valareport.h>
 
+
+
+
 struct _ValaUnresolvedTypePrivate {
-	char* _namespace_name;
-	char* _type_name;
+	ValaUnresolvedSymbol* _unresolved_symbol;
 	gint _array_rank;
 	gint _pointer_level;
-	gboolean _transfers_ownership;
-	gboolean _takes_ownership;
 	gboolean _is_weak;
-	gboolean _is_ref;
-	gboolean _is_out;
-	gboolean _nullable;
 };
 #define VALA_UNRESOLVED_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_UNRESOLVED_TYPE, ValaUnresolvedTypePrivate))
 enum  {
 	VALA_UNRESOLVED_TYPE_DUMMY_PROPERTY,
-	VALA_UNRESOLVED_TYPE_NAMESPACE_NAME,
-	VALA_UNRESOLVED_TYPE_TYPE_NAME,
+	VALA_UNRESOLVED_TYPE_UNRESOLVED_SYMBOL,
 	VALA_UNRESOLVED_TYPE_ARRAY_RANK,
 	VALA_UNRESOLVED_TYPE_POINTER_LEVEL,
-	VALA_UNRESOLVED_TYPE_TRANSFERS_OWNERSHIP,
-	VALA_UNRESOLVED_TYPE_TAKES_OWNERSHIP,
-	VALA_UNRESOLVED_TYPE_IS_WEAK,
-	VALA_UNRESOLVED_TYPE_IS_REF,
-	VALA_UNRESOLVED_TYPE_IS_OUT,
-	VALA_UNRESOLVED_TYPE_NULLABLE
+	VALA_UNRESOLVED_TYPE_IS_WEAK
 };
 static ValaDataType* vala_unresolved_type_real_copy (ValaDataType* base);
 static gpointer vala_unresolved_type_parent_class = NULL;
 static void vala_unresolved_type_dispose (GObject * obj);
 
 
+
 ValaUnresolvedType* vala_unresolved_type_new (void) {
 	ValaUnresolvedType * self;
 	self = g_object_newv (VALA_TYPE_UNRESOLVED_TYPE, 0, NULL);
@@ -68,17 +62,16 @@ ValaUnresolvedType* vala_unresolved_type_new (void) {
 /**
  * Creates a new type reference.
  *
- * @param ns        optional namespace name
- * @param type_name type symbol name
+ * @param symbol    unresolved type symbol
  * @param source    reference to source code
  * @return          newly created type reference
  */
-ValaUnresolvedType* vala_unresolved_type_new_from_name (const char* ns, const char* type, ValaSourceReference* source) {
+ValaUnresolvedType* vala_unresolved_type_new_from_symbol (ValaUnresolvedSymbol* symbol, ValaSourceReference* source) {
 	ValaUnresolvedType * self;
+	g_return_val_if_fail (symbol == NULL || VALA_IS_UNRESOLVED_SYMBOL (symbol), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_UNRESOLVED_TYPE, 0, NULL);
-	vala_unresolved_type_set_namespace_name (self, ns);
-	vala_unresolved_type_set_type_name (self, type);
+	vala_unresolved_type_set_unresolved_symbol (self, symbol);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
@@ -94,7 +87,7 @@ ValaUnresolvedType* vala_unresolved_type_new_from_name (const char* ns, const ch
 ValaUnresolvedType* vala_unresolved_type_new_from_expression (ValaExpression* expr) {
 	char* ns;
 	char* type_name;
-	gpointer _tmp5;
+	gpointer _tmp8;
 	g_return_val_if_fail (expr == NULL || VALA_IS_EXPRESSION (expr), NULL);
 	ns = NULL;
 	type_name = NULL;
@@ -109,21 +102,30 @@ ValaUnresolvedType* vala_unresolved_type_new_from_expression (ValaExpression* ex
 			if (VALA_IS_MEMBER_ACCESS (vala_member_access_get_inner (ma))) {
 				ValaMemberAccess* _tmp1;
 				ValaMemberAccess* simple;
-				ValaUnresolvedType* _tmp2;
+				ValaUnresolvedType* _tmp4;
+				ValaUnresolvedSymbol* _tmp3;
+				ValaUnresolvedSymbol* _tmp2;
 				_tmp1 = NULL;
 				simple = (_tmp1 = VALA_MEMBER_ACCESS (vala_member_access_get_inner (ma)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+				_tmp4 = NULL;
+				_tmp3 = NULL;
 				_tmp2 = NULL;
-				type_ref = (_tmp2 = vala_unresolved_type_new_from_name (vala_member_access_get_member_name (simple), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), _tmp2);
+				type_ref = (_tmp4 = vala_unresolved_type_new_from_symbol ((_tmp3 = vala_unresolved_symbol_new ((_tmp2 = vala_unresolved_symbol_new (NULL, vala_member_access_get_member_name (simple), vala_code_node_get_source_reference (VALA_CODE_NODE (ma)))), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma)))), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), _tmp4);
+				(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
+				(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
 				(simple == NULL ? NULL : (simple = (g_object_unref (simple), NULL)));
 			}
 		} else {
-			ValaUnresolvedType* _tmp3;
-			_tmp3 = NULL;
-			type_ref = (_tmp3 = vala_unresolved_type_new_from_name (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), _tmp3);
+			ValaUnresolvedType* _tmp6;
+			ValaUnresolvedSymbol* _tmp5;
+			_tmp6 = NULL;
+			_tmp5 = NULL;
+			type_ref = (_tmp6 = vala_unresolved_type_new_from_symbol ((_tmp5 = vala_unresolved_symbol_new (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma)))), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), _tmp6);
+			(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
 		}
 		if (type_ref != NULL) {
 			GeeCollection* type_args;
-			ValaUnresolvedType* _tmp4;
+			ValaUnresolvedType* _tmp7;
 			type_args = vala_member_access_get_type_arguments (ma);
 			{
 				GeeCollection* arg_collection;
@@ -132,7 +134,7 @@ ValaUnresolvedType* vala_unresolved_type_new_from_expression (ValaExpression* ex
 				arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
 				while (gee_iterator_next (arg_it)) {
 					ValaDataType* arg;
-					arg = gee_iterator_get (arg_it);
+					arg = ((ValaDataType*) gee_iterator_get (arg_it));
 					{
 						vala_data_type_add_type_argument (VALA_DATA_TYPE (type_ref), arg);
 						(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
@@ -140,33 +142,36 @@ ValaUnresolvedType* vala_unresolved_type_new_from_expression (ValaExpression* ex
 				}
 				(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 			}
-			_tmp4 = NULL;
-			return (_tmp4 = type_ref, (type_args == NULL ? NULL : (type_args = (g_object_unref (type_args), NULL))), (ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL))), (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), _tmp4);
+			_tmp7 = NULL;
+			return (_tmp7 = type_ref, (type_args == NULL ? NULL : (type_args = (g_object_unref (type_args), NULL))), (ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL))), (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), _tmp7);
 		}
 		(type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL)));
 		(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
 	}
 	vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (expr)), "Type reference must be simple name or member access expression");
-	return (_tmp5 = NULL, (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), _tmp5);
+	return (_tmp8 = NULL, (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), _tmp8);
 }
 
 
 static ValaDataType* vala_unresolved_type_real_copy (ValaDataType* base) {
 	ValaUnresolvedType * self;
 	ValaUnresolvedType* result;
+	ValaUnresolvedSymbol* _tmp0;
 	self = VALA_UNRESOLVED_TYPE (base);
 	result = vala_unresolved_type_new ();
 	vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
-	vala_unresolved_type_set_transfers_ownership (result, vala_unresolved_type_get_transfers_ownership (self));
-	vala_unresolved_type_set_takes_ownership (result, vala_unresolved_type_get_takes_ownership (self));
-	vala_unresolved_type_set_is_out (result, vala_unresolved_type_get_is_out (self));
-	vala_unresolved_type_set_nullable (result, vala_unresolved_type_get_nullable (self));
-	vala_unresolved_type_set_namespace_name (result, vala_unresolved_type_get_namespace_name (self));
-	vala_unresolved_type_set_type_name (result, vala_unresolved_type_get_type_name (self));
-	vala_unresolved_type_set_array_rank (result, vala_unresolved_type_get_array_rank (self));
-	vala_unresolved_type_set_pointer_level (result, vala_unresolved_type_get_pointer_level (self));
-	vala_unresolved_type_set_is_ref (result, vala_unresolved_type_get_is_ref (self));
-	vala_unresolved_type_set_is_weak (result, vala_unresolved_type_get_is_weak (self));
+	vala_data_type_set_transfers_ownership (VALA_DATA_TYPE (result), vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (self)));
+	vala_data_type_set_takes_ownership (VALA_DATA_TYPE (result), vala_data_type_get_takes_ownership (VALA_DATA_TYPE (self)));
+	vala_data_type_set_is_out (VALA_DATA_TYPE (result), vala_data_type_get_is_out (VALA_DATA_TYPE (self)));
+	vala_data_type_set_nullable (VALA_DATA_TYPE (result), vala_data_type_get_nullable (VALA_DATA_TYPE (self)));
+	vala_data_type_set_requires_null_check (VALA_DATA_TYPE (result), vala_data_type_get_requires_null_check (VALA_DATA_TYPE (self)));
+	_tmp0 = NULL;
+	vala_unresolved_type_set_unresolved_symbol (result, (_tmp0 = vala_unresolved_symbol_copy (self->priv->_unresolved_symbol)));
+	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+	vala_unresolved_type_set_array_rank (result, self->priv->_array_rank);
+	vala_unresolved_type_set_pointer_level (result, self->priv->_pointer_level);
+	vala_data_type_set_is_ref (VALA_DATA_TYPE (result), vala_data_type_get_is_ref (VALA_DATA_TYPE (self)));
+	vala_unresolved_type_set_is_weak (result, self->priv->_is_weak);
 	{
 		GeeList* arg_collection;
 		GeeIterator* arg_it;
@@ -174,12 +179,12 @@ static ValaDataType* vala_unresolved_type_real_copy (ValaDataType* base) {
 		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
 		while (gee_iterator_next (arg_it)) {
 			ValaDataType* arg;
-			arg = gee_iterator_get (arg_it);
+			arg = ((ValaDataType*) gee_iterator_get (arg_it));
 			{
-				ValaDataType* _tmp0;
-				_tmp0 = NULL;
-				vala_data_type_add_type_argument (VALA_DATA_TYPE (result), (_tmp0 = vala_data_type_copy (arg)));
-				(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+				ValaDataType* _tmp1;
+				_tmp1 = NULL;
+				vala_data_type_add_type_argument (VALA_DATA_TYPE (result), (_tmp1 = vala_data_type_copy (arg)));
+				(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
@@ -190,35 +195,19 @@ static ValaDataType* vala_unresolved_type_real_copy (ValaDataType* base) {
 }
 
 
-char* vala_unresolved_type_get_namespace_name (ValaUnresolvedType* self) {
+ValaUnresolvedSymbol* vala_unresolved_type_get_unresolved_symbol (ValaUnresolvedType* self) {
 	g_return_val_if_fail (VALA_IS_UNRESOLVED_TYPE (self), NULL);
-	return self->priv->_namespace_name;
+	return self->priv->_unresolved_symbol;
 }
 
 
-void vala_unresolved_type_set_namespace_name (ValaUnresolvedType* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+void vala_unresolved_type_set_unresolved_symbol (ValaUnresolvedType* self, ValaUnresolvedSymbol* value) {
+	ValaUnresolvedSymbol* _tmp2;
+	ValaUnresolvedSymbol* _tmp1;
 	g_return_if_fail (VALA_IS_UNRESOLVED_TYPE (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_namespace_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_namespace_name = (g_free (self->priv->_namespace_name), NULL)), _tmp2);
-}
-
-
-char* vala_unresolved_type_get_type_name (ValaUnresolvedType* self) {
-	g_return_val_if_fail (VALA_IS_UNRESOLVED_TYPE (self), NULL);
-	return self->priv->_type_name;
-}
-
-
-void vala_unresolved_type_set_type_name (ValaUnresolvedType* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
-	g_return_if_fail (VALA_IS_UNRESOLVED_TYPE (self));
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp2);
+	self->priv->_unresolved_symbol = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_unresolved_symbol == NULL ? NULL : (self->priv->_unresolved_symbol = (g_object_unref (self->priv->_unresolved_symbol), NULL))), _tmp2);
 }
 
 
@@ -246,30 +235,6 @@ void vala_unresolved_type_set_pointer_level (ValaUnresolvedType* self, gint valu
 }
 
 
-gboolean vala_unresolved_type_get_transfers_ownership (ValaUnresolvedType* self) {
-	g_return_val_if_fail (VALA_IS_UNRESOLVED_TYPE (self), FALSE);
-	return self->priv->_transfers_ownership;
-}
-
-
-void vala_unresolved_type_set_transfers_ownership (ValaUnresolvedType* self, gboolean value) {
-	g_return_if_fail (VALA_IS_UNRESOLVED_TYPE (self));
-	self->priv->_transfers_ownership = value;
-}
-
-
-gboolean vala_unresolved_type_get_takes_ownership (ValaUnresolvedType* self) {
-	g_return_val_if_fail (VALA_IS_UNRESOLVED_TYPE (self), FALSE);
-	return self->priv->_takes_ownership;
-}
-
-
-void vala_unresolved_type_set_takes_ownership (ValaUnresolvedType* self, gboolean value) {
-	g_return_if_fail (VALA_IS_UNRESOLVED_TYPE (self));
-	self->priv->_takes_ownership = value;
-}
-
-
 gboolean vala_unresolved_type_get_is_weak (ValaUnresolvedType* self) {
 	g_return_val_if_fail (VALA_IS_UNRESOLVED_TYPE (self), FALSE);
 	return self->priv->_is_weak;
@@ -282,51 +247,12 @@ void vala_unresolved_type_set_is_weak (ValaUnresolvedType* self, gboolean value)
 }
 
 
-gboolean vala_unresolved_type_get_is_ref (ValaUnresolvedType* self) {
-	g_return_val_if_fail (VALA_IS_UNRESOLVED_TYPE (self), FALSE);
-	return self->priv->_is_ref;
-}
-
-
-void vala_unresolved_type_set_is_ref (ValaUnresolvedType* self, gboolean value) {
-	g_return_if_fail (VALA_IS_UNRESOLVED_TYPE (self));
-	self->priv->_is_ref = value;
-}
-
-
-gboolean vala_unresolved_type_get_is_out (ValaUnresolvedType* self) {
-	g_return_val_if_fail (VALA_IS_UNRESOLVED_TYPE (self), FALSE);
-	return self->priv->_is_out;
-}
-
-
-void vala_unresolved_type_set_is_out (ValaUnresolvedType* self, gboolean value) {
-	g_return_if_fail (VALA_IS_UNRESOLVED_TYPE (self));
-	self->priv->_is_out = value;
-}
-
-
-gboolean vala_unresolved_type_get_nullable (ValaUnresolvedType* self) {
-	g_return_val_if_fail (VALA_IS_UNRESOLVED_TYPE (self), FALSE);
-	return self->priv->_nullable;
-}
-
-
-void vala_unresolved_type_set_nullable (ValaUnresolvedType* self, gboolean value) {
-	g_return_if_fail (VALA_IS_UNRESOLVED_TYPE (self));
-	self->priv->_nullable = value;
-}
-
-
 static void vala_unresolved_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaUnresolvedType * self;
 	self = VALA_UNRESOLVED_TYPE (object);
 	switch (property_id) {
-		case VALA_UNRESOLVED_TYPE_NAMESPACE_NAME:
-		g_value_set_string (value, vala_unresolved_type_get_namespace_name (self));
-		break;
-		case VALA_UNRESOLVED_TYPE_TYPE_NAME:
-		g_value_set_string (value, vala_unresolved_type_get_type_name (self));
+		case VALA_UNRESOLVED_TYPE_UNRESOLVED_SYMBOL:
+		g_value_set_object (value, vala_unresolved_type_get_unresolved_symbol (self));
 		break;
 		case VALA_UNRESOLVED_TYPE_ARRAY_RANK:
 		g_value_set_int (value, vala_unresolved_type_get_array_rank (self));
@@ -334,24 +260,9 @@ static void vala_unresolved_type_get_property (GObject * object, guint property_
 		case VALA_UNRESOLVED_TYPE_POINTER_LEVEL:
 		g_value_set_int (value, vala_unresolved_type_get_pointer_level (self));
 		break;
-		case VALA_UNRESOLVED_TYPE_TRANSFERS_OWNERSHIP:
-		g_value_set_boolean (value, vala_unresolved_type_get_transfers_ownership (self));
-		break;
-		case VALA_UNRESOLVED_TYPE_TAKES_OWNERSHIP:
-		g_value_set_boolean (value, vala_unresolved_type_get_takes_ownership (self));
-		break;
 		case VALA_UNRESOLVED_TYPE_IS_WEAK:
 		g_value_set_boolean (value, vala_unresolved_type_get_is_weak (self));
 		break;
-		case VALA_UNRESOLVED_TYPE_IS_REF:
-		g_value_set_boolean (value, vala_unresolved_type_get_is_ref (self));
-		break;
-		case VALA_UNRESOLVED_TYPE_IS_OUT:
-		g_value_set_boolean (value, vala_unresolved_type_get_is_out (self));
-		break;
-		case VALA_UNRESOLVED_TYPE_NULLABLE:
-		g_value_set_boolean (value, vala_unresolved_type_get_nullable (self));
-		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -363,11 +274,8 @@ static void vala_unresolved_type_set_property (GObject * object, guint property_
 	ValaUnresolvedType * self;
 	self = VALA_UNRESOLVED_TYPE (object);
 	switch (property_id) {
-		case VALA_UNRESOLVED_TYPE_NAMESPACE_NAME:
-		vala_unresolved_type_set_namespace_name (self, g_value_get_string (value));
-		break;
-		case VALA_UNRESOLVED_TYPE_TYPE_NAME:
-		vala_unresolved_type_set_type_name (self, g_value_get_string (value));
+		case VALA_UNRESOLVED_TYPE_UNRESOLVED_SYMBOL:
+		vala_unresolved_type_set_unresolved_symbol (self, g_value_get_object (value));
 		break;
 		case VALA_UNRESOLVED_TYPE_ARRAY_RANK:
 		vala_unresolved_type_set_array_rank (self, g_value_get_int (value));
@@ -375,24 +283,9 @@ static void vala_unresolved_type_set_property (GObject * object, guint property_
 		case VALA_UNRESOLVED_TYPE_POINTER_LEVEL:
 		vala_unresolved_type_set_pointer_level (self, g_value_get_int (value));
 		break;
-		case VALA_UNRESOLVED_TYPE_TRANSFERS_OWNERSHIP:
-		vala_unresolved_type_set_transfers_ownership (self, g_value_get_boolean (value));
-		break;
-		case VALA_UNRESOLVED_TYPE_TAKES_OWNERSHIP:
-		vala_unresolved_type_set_takes_ownership (self, g_value_get_boolean (value));
-		break;
 		case VALA_UNRESOLVED_TYPE_IS_WEAK:
 		vala_unresolved_type_set_is_weak (self, g_value_get_boolean (value));
 		break;
-		case VALA_UNRESOLVED_TYPE_IS_REF:
-		vala_unresolved_type_set_is_ref (self, g_value_get_boolean (value));
-		break;
-		case VALA_UNRESOLVED_TYPE_IS_OUT:
-		vala_unresolved_type_set_is_out (self, g_value_get_boolean (value));
-		break;
-		case VALA_UNRESOLVED_TYPE_NULLABLE:
-		vala_unresolved_type_set_nullable (self, g_value_get_boolean (value));
-		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -407,16 +300,10 @@ static void vala_unresolved_type_class_init (ValaUnresolvedTypeClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = vala_unresolved_type_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_unresolved_type_dispose;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_unresolved_type_real_copy;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_NAMESPACE_NAME, g_param_spec_string ("namespace-name", "namespace-name", "namespace-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_TYPE_NAME, g_param_spec_string ("type-name", "type-name", "type-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_UNRESOLVED_SYMBOL, g_param_spec_object ("unresolved-symbol", "unresolved-symbol", "unresolved-symbol", VALA_TYPE_UNRESOLVED_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_ARRAY_RANK, g_param_spec_int ("array-rank", "array-rank", "array-rank", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_POINTER_LEVEL, g_param_spec_int ("pointer-level", "pointer-level", "pointer-level", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_TRANSFERS_OWNERSHIP, g_param_spec_boolean ("transfers-ownership", "transfers-ownership", "transfers-ownership", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_TAKES_OWNERSHIP, g_param_spec_boolean ("takes-ownership", "takes-ownership", "takes-ownership", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_IS_WEAK, g_param_spec_boolean ("is-weak", "is-weak", "is-weak", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_IS_REF, g_param_spec_boolean ("is-ref", "is-ref", "is-ref", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_IS_OUT, g_param_spec_boolean ("is-out", "is-out", "is-out", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_NULLABLE, g_param_spec_boolean ("nullable", "nullable", "nullable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -428,8 +315,7 @@ static void vala_unresolved_type_init (ValaUnresolvedType * self) {
 static void vala_unresolved_type_dispose (GObject * obj) {
 	ValaUnresolvedType * self;
 	self = VALA_UNRESOLVED_TYPE (obj);
-	(self->priv->_namespace_name = (g_free (self->priv->_namespace_name), NULL));
-	(self->priv->_type_name = (g_free (self->priv->_type_name), NULL));
+	(self->priv->_unresolved_symbol == NULL ? NULL : (self->priv->_unresolved_symbol = (g_object_unref (self->priv->_unresolved_symbol), NULL)));
 	G_OBJECT_CLASS (vala_unresolved_type_parent_class)->dispose (obj);
 }
 
