@@ -1,6 +1,6 @@
 /* valawhilestatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,6 +26,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaWhileStatementPrivate {
 	ValaExpression* _condition;
 	ValaBlock* _body;
@@ -37,12 +40,14 @@ enum  {
 	VALA_WHILE_STATEMENT_BODY
 };
 static void vala_while_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_while_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_while_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_while_statement_parent_class = NULL;
 static ValaStatementIface* vala_while_statement_vala_statement_parent_iface = NULL;
 static void vala_while_statement_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new while statement.
  *
@@ -60,7 +65,10 @@ ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlo
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "condition", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, condition), __params_it++);
+	__params_it->name = "condition";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, condition);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_WHILE_STATEMENT, __params_it - __params, __params);
 	vala_while_statement_set_body (self, body);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -74,13 +82,20 @@ ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlo
 
 
 static void vala_while_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
+	ValaWhileStatement * self;
+	self = VALA_WHILE_STATEMENT (base);
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_while_statement (visitor, self);
+}
+
+
+static void vala_while_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaWhileStatement * self;
 	self = VALA_WHILE_STATEMENT (base);
 	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_while_statement_get_condition (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_while_statement_get_condition (self));
 	vala_code_node_accept (VALA_CODE_NODE (vala_while_statement_get_body (self)), visitor);
-	vala_code_visitor_visit_while_statement (visitor, self);
 }
 
 
@@ -170,6 +185,7 @@ static void vala_while_statement_class_init (ValaWhileStatementClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = vala_while_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_while_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_while_statement_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_while_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_while_statement_real_replace_expression;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_WHILE_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_WHILE_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
