@@ -38,9 +38,6 @@
 #include <vala/valareport.h>
 #include <glib/gstdio.h>
 
-typedef struct _ValaVAPICheck ValaVAPICheck;
-typedef struct _ValaVAPICheckClass ValaVAPICheckClass;
-typedef struct _ValaVAPICheckPrivate ValaVAPICheckPrivate;
 
 #define VALA_TYPE_VAPI_CHECK (vala_vapi_check_get_type ())
 #define VALA_VAPI_CHECK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VAPI_CHECK, ValaVAPICheck))
@@ -49,6 +46,10 @@ typedef struct _ValaVAPICheckPrivate ValaVAPICheckPrivate;
 #define VALA_IS_VAPI_CHECK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VAPI_CHECK))
 #define VALA_VAPI_CHECK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VAPI_CHECK, ValaVAPICheckClass))
 
+typedef struct _ValaVAPICheck ValaVAPICheck;
+typedef struct _ValaVAPICheckClass ValaVAPICheckClass;
+typedef struct _ValaVAPICheckPrivate ValaVAPICheckPrivate;
+
 struct _ValaVAPICheck {
 	GObject parent_instance;
 	ValaVAPICheckPrivate * priv;
@@ -56,6 +57,8 @@ struct _ValaVAPICheck {
 struct _ValaVAPICheckClass {
 	GObjectClass parent_class;
 };
+
+
 struct _ValaVAPICheckPrivate {
 	ValaCodeContext* _context;
 	ValaSourceFile* _gidl;
@@ -79,7 +82,7 @@ static void vala_vapi_check_leave_scope (ValaVAPICheck* self);
 static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name, GList* members);
 static gint vala_vapi_check_check_metadata (ValaVAPICheck* self);
 static gint vala_vapi_check_run (ValaVAPICheck* self);
-static gint vala_vapi_check_main (int args_length1, char** args);
+static gint vala_vapi_check_main (char** args, int args_length1);
 static ValaCodeContext* vala_vapi_check_get_context (ValaVAPICheck* self);
 static void vala_vapi_check_set_context (ValaVAPICheck* self, ValaCodeContext* value);
 static ValaSourceFile* vala_vapi_check_get_gidl (ValaVAPICheck* self);
@@ -92,6 +95,7 @@ static GType vala_vapi_check_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
+
 static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context) {
 	GParameter * __params;
 	GParameter * __params_it;
@@ -105,17 +109,26 @@ static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
 	_tmp0 = NULL;
-	(__params_it->name = "gidl", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE), g_value_set_object (&__params_it->value, (_tmp0 = vala_source_file_new (context, gidlname, FALSE))), __params_it++);
+	__params_it->name = "gidl";
+	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
+	g_value_set_object (&__params_it->value, (_tmp0 = vala_source_file_new (context, gidlname, FALSE)));
+	__params_it++;
 	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 	_tmp4 = NULL;
 	_tmp3 = NULL;
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	(__params_it->name = "metadata", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE), g_value_set_object (&__params_it->value, (_tmp4 = vala_source_file_new (context, (_tmp3 = g_strconcat ((_tmp2 = g_utf8_offset_to_pointer (gidlname, 0), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (gidlname, -1) - 5) - _tmp2)), ".metadata", NULL)), FALSE))), __params_it++);
+	__params_it->name = "metadata";
+	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
+	g_value_set_object (&__params_it->value, (_tmp4 = vala_source_file_new (context, (_tmp3 = g_strconcat ((_tmp2 = g_utf8_offset_to_pointer (gidlname, ((glong) 0)), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (gidlname, -1) - 5) - _tmp2)), ".metadata", NULL)), FALSE)));
+	__params_it++;
 	(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
-	(_tmp3 = (g_free (_tmp3), NULL));
-	(_tmp1 = (g_free (_tmp1), NULL));
-	(__params_it->name = "context", g_value_init (&__params_it->value, VALA_TYPE_CODE_CONTEXT), g_value_set_object (&__params_it->value, context), __params_it++);
+	_tmp3 = (g_free (_tmp3), NULL);
+	_tmp1 = (g_free (_tmp1), NULL);
+	__params_it->name = "context";
+	g_value_init (&__params_it->value, VALA_TYPE_CODE_CONTEXT);
+	g_value_set_object (&__params_it->value, context);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_VAPI_CHECK, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -140,7 +153,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 		{
 			GList* module_collection;
 			GList* module_it;
-			module_collection = g_idl_parse_file (vala_source_file_get_filename (vala_vapi_check_get_gidl (self)), &inner_error);
+			module_collection = g_idl_parse_file (vala_source_file_get_filename (self->priv->_gidl), &inner_error);
 			if (inner_error != NULL) {
 				if (inner_error->domain == G_MARKUP_ERROR) {
 					goto __catch0_g_markup_error;
@@ -150,7 +163,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 			}
 			for (module_it = module_collection; module_it != NULL; module_it = module_it->next) {
 				GIdlModule* module;
-				module = module_it->data;
+				module = ((GIdlModule*) module_it->data);
 				{
 					vala_vapi_check_parse_members (self, module->name, module->entries);
 				}
@@ -165,7 +178,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 		e = inner_error;
 		inner_error = NULL;
 		{
-			fprintf (stderr, "%s: %s\n", vala_source_file_get_filename (vala_vapi_check_get_gidl (self)), e->message);
+			fprintf (stderr, "%s: %s\n", vala_source_file_get_filename (self->priv->_gidl), e->message);
 		}
 	}
 	__finally0:
@@ -185,7 +198,7 @@ static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, c
 		_tmp2 = NULL;
 		fullname = (_tmp2 = g_strconcat ((_tmp1 = g_strconcat ((_tmp0 = vala_vapi_check_get_scope (self)), separator, NULL)), name, NULL), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
 		gee_collection_add (GEE_COLLECTION (self->priv->_symbols), fullname);
-		(fullname = (g_free (fullname), NULL));
+		fullname = (g_free (fullname), NULL);
 	} else {
 		gee_collection_add (GEE_COLLECTION (self->priv->_symbols), name);
 	}
@@ -194,7 +207,7 @@ static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, c
 
 static char* vala_vapi_check_get_scope (ValaVAPICheck* self) {
 	g_return_val_if_fail (VALA_IS_VAPI_CHECK (self), NULL);
-	return gee_list_get (((GeeList*) self->priv->_scope), gee_collection_get_size (GEE_COLLECTION (self->priv->_scope)) - 1);
+	return ((char*) gee_list_get (((GeeList*) self->priv->_scope), gee_collection_get_size (GEE_COLLECTION (self->priv->_scope)) - 1));
 }
 
 
@@ -220,7 +233,7 @@ static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name
 		node_collection = members;
 		for (node_it = node_collection; node_it != NULL; node_it = node_it->next) {
 			GIdlNode* node;
-			node = node_it->data;
+			node = ((GIdlNode*) node_it->data);
 			{
 				GIdlNodeTypeId _tmp0;
 				_tmp0 = node->type;
@@ -278,7 +291,7 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 		GIOStatus _tmp1;
 		char* _tmp0;
 		gint _tmp5;
-		metafile = g_io_channel_new_file (vala_source_file_get_filename (vala_vapi_check_get_metadata (self)), "r", &inner_error);
+		metafile = g_io_channel_new_file (vala_source_file_get_filename (self->priv->_metadata), "r", &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
 				goto __catch1_g_file_error;
@@ -302,15 +315,15 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 			if (strlen (symbol) > 0 && !gee_collection_contains (GEE_COLLECTION (self->priv->_symbols), symbol)) {
 				ValaSourceReference* src;
 				char* _tmp4;
-				src = vala_source_reference_new (vala_vapi_check_get_metadata (self), lineno, 1, lineno, ((gint) g_utf8_strlen (symbol, -1)));
+				src = vala_source_reference_new (self->priv->_metadata, lineno, 1, lineno, ((gint) g_utf8_strlen (symbol, -1)));
 				_tmp4 = NULL;
 				vala_report_error (src, (_tmp4 = g_strdup_printf ("Symbol `%s' not found", symbol)));
-				(_tmp4 = (g_free (_tmp4), NULL));
+				_tmp4 = (g_free (_tmp4), NULL);
 				(src == NULL ? NULL : (src = (g_object_unref (src), NULL)));
 			}
 			lineno = lineno + (1);
-			(tokens = (_vala_array_free (tokens, tokens_length1, ((GDestroyNotify) g_free)), NULL));
-			(symbol = (g_free (symbol), NULL));
+			tokens = (_vala_array_free (tokens, tokens_length1, ((GDestroyNotify) g_free)), NULL);
+			symbol = (g_free (symbol), NULL);
 		}
 		return (_tmp5 = 0, (metafile == NULL ? NULL : (metafile = (g_io_channel_unref (metafile), NULL))), (line = (g_free (line), NULL)), _tmp5);
 	}
@@ -323,8 +336,8 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 		{
 			char* _tmp6;
 			_tmp6 = NULL;
-			vala_report_error (NULL, (_tmp6 = g_strdup_printf ("%s: %s", vala_source_file_get_filename (vala_vapi_check_get_metadata (self)), error->message)));
-			(_tmp6 = (g_free (_tmp6), NULL));
+			vala_report_error (NULL, (_tmp6 = g_strdup_printf ("%s: %s", vala_source_file_get_filename (self->priv->_metadata), error->message)));
+			_tmp6 = (g_free (_tmp6), NULL);
 			return 1;
 		}
 	}
@@ -335,18 +348,18 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 
 static gint vala_vapi_check_run (ValaVAPICheck* self) {
 	g_return_val_if_fail (VALA_IS_VAPI_CHECK (self), 0);
-	if (!g_file_test (vala_source_file_get_filename (vala_vapi_check_get_gidl (self)), G_FILE_TEST_IS_REGULAR)) {
+	if (!g_file_test (vala_source_file_get_filename (self->priv->_gidl), G_FILE_TEST_IS_REGULAR)) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		vala_report_error (NULL, (_tmp0 = g_strdup_printf ("%s not found", vala_source_file_get_filename (vala_vapi_check_get_gidl (self)))));
-		(_tmp0 = (g_free (_tmp0), NULL));
+		vala_report_error (NULL, (_tmp0 = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_gidl))));
+		_tmp0 = (g_free (_tmp0), NULL);
 		return 2;
 	}
-	if (!g_file_test (vala_source_file_get_filename (vala_vapi_check_get_metadata (self)), G_FILE_TEST_IS_REGULAR)) {
+	if (!g_file_test (vala_source_file_get_filename (self->priv->_metadata), G_FILE_TEST_IS_REGULAR)) {
 		char* _tmp2;
 		_tmp2 = NULL;
-		vala_report_error (NULL, (_tmp2 = g_strdup_printf ("%s not found", vala_source_file_get_filename (vala_vapi_check_get_metadata (self)))));
-		(_tmp2 = (g_free (_tmp2), NULL));
+		vala_report_error (NULL, (_tmp2 = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_metadata))));
+		_tmp2 = (g_free (_tmp2), NULL);
 		return 2;
 	}
 	vala_vapi_check_parse_gidl (self);
@@ -354,14 +367,14 @@ static gint vala_vapi_check_run (ValaVAPICheck* self) {
 }
 
 
-static gint vala_vapi_check_main (int args_length1, char** args) {
+static gint vala_vapi_check_main (char** args, int args_length1) {
 	ValaVAPICheck* vapicheck;
 	gint _tmp2;
 	if (2 != args_length1 || !g_str_has_suffix (args[1], ".gidl")) {
 		char* _tmp0;
 		_tmp0 = NULL;
 		fprintf (stdout, "Usage: %s library.gidl\n", (_tmp0 = g_path_get_basename (args[0])));
-		(_tmp0 = (g_free (_tmp0), NULL));
+		_tmp0 = (g_free (_tmp0), NULL);
 		return 2;
 	}
 	vapicheck = vala_vapi_check_new (args[1], vala_code_context_new ());
@@ -371,7 +384,7 @@ static gint vala_vapi_check_main (int args_length1, char** args) {
 
 int main (int argc, char ** argv) {
 	g_type_init ();
-	return vala_vapi_check_main (argc, argv);
+	return vala_vapi_check_main (argv, argc);
 }
 
 
