@@ -26,8 +26,8 @@
 #include <vala/valacodecontext.h>
 #include <vala/valareport.h>
 #include <stdio.h>
-#include <glib/gstdio.h>
 #include <vala/valasourcefile.h>
+#include <glib/gstdio.h>
 #include <vala/valasourcereference.h>
 #include <vala/valaparser.h>
 #include <vala/valaattributeprocessor.h>
@@ -36,9 +36,6 @@
 #include <config.h>
 #include "vapigen/valagidlparser.h"
 
-typedef struct _ValaVAPIGen ValaVAPIGen;
-typedef struct _ValaVAPIGenClass ValaVAPIGenClass;
-typedef struct _ValaVAPIGenPrivate ValaVAPIGenPrivate;
 
 #define VALA_TYPE_VAPI_GEN (vala_vapi_gen_get_type ())
 #define VALA_VAPI_GEN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VAPI_GEN, ValaVAPIGen))
@@ -47,6 +44,10 @@ typedef struct _ValaVAPIGenPrivate ValaVAPIGenPrivate;
 #define VALA_IS_VAPI_GEN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VAPI_GEN))
 #define VALA_VAPI_GEN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VAPI_GEN, ValaVAPIGenClass))
 
+typedef struct _ValaVAPIGen ValaVAPIGen;
+typedef struct _ValaVAPIGenClass ValaVAPIGenClass;
+typedef struct _ValaVAPIGenPrivate ValaVAPIGenPrivate;
+
 struct _ValaVAPIGen {
 	GObject parent_instance;
 	ValaVAPIGenPrivate * priv;
@@ -54,6 +55,8 @@ struct _ValaVAPIGen {
 struct _ValaVAPIGenClass {
 	GObjectClass parent_class;
 };
+
+
 struct _ValaVAPIGenPrivate {
 	ValaCodeContext* context;
 };
@@ -63,86 +66,41 @@ enum  {
 };
 static char* vala_vapi_gen_directory;
 static gboolean vala_vapi_gen_version;
+static gboolean vala_vapi_gen_quiet_mode;
 static char** vala_vapi_gen_sources;
 static char** vala_vapi_gen_vapi_directories;
 static char* vala_vapi_gen_library;
 static char** vala_vapi_gen_packages;
-static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_vapi_directories, "Look for package bindings in DIRECTORY", "DIRECTORY..."}, {"pkg", 0, 0, G_OPTION_ARG_STRING_ARRAY, &vala_vapi_gen_packages, "Include binding for PACKAGE", "PACKAGE..."}, {"library", 0, 0, G_OPTION_ARG_STRING, &vala_vapi_gen_library, "Library name", "NAME"}, {"directory", 'd', 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_directory, "Output directory", "DIRECTORY"}, {"version", 0, 0, G_OPTION_ARG_NONE, &vala_vapi_gen_version, "Display version number", NULL}, {"", 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_sources, NULL, "FILE..."}, {NULL}};
 static gint vala_vapi_gen_quit (ValaVAPIGen* self);
-static char* vala_vapi_gen_get_package_path (ValaVAPIGen* self, const char* pkg);
 static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg);
 static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1);
 static gint vala_vapi_gen_run (ValaVAPIGen* self);
-static gint vala_vapi_gen_main (int args_length1, char** args);
+static gint vala_vapi_gen_main (char** args, int args_length1);
 static ValaVAPIGen* vala_vapi_gen_new (void);
 static gpointer vala_vapi_gen_parent_class = NULL;
 static void vala_vapi_gen_dispose (GObject * obj);
 static GType vala_vapi_gen_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
+static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", ((gchar) 0), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_vapi_directories, "Look for package bindings in DIRECTORY", "DIRECTORY..."}, {"pkg", ((gchar) 0), 0, G_OPTION_ARG_STRING_ARRAY, &vala_vapi_gen_packages, "Include binding for PACKAGE", "PACKAGE..."}, {"library", ((gchar) 0), 0, G_OPTION_ARG_STRING, &vala_vapi_gen_library, "Library name", "NAME"}, {"directory", 'd', 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_directory, "Output directory", "DIRECTORY"}, {"version", ((gchar) 0), 0, G_OPTION_ARG_NONE, &vala_vapi_gen_version, "Display version number", NULL}, {"quiet", 'q', 0, G_OPTION_ARG_NONE, &vala_vapi_gen_quiet_mode, "Do not print messages to the console", NULL}, {"", ((gchar) 0), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_sources, NULL, "FILE..."}, {NULL}};
+
 
 static gint vala_vapi_gen_quit (ValaVAPIGen* self) {
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), 0);
 	if (vala_report_get_errors () == 0) {
-		fprintf (stdout, "Generation succeeded - %d warning(s)\n", vala_report_get_warnings ());
+		if (!vala_vapi_gen_quiet_mode) {
+			fprintf (stdout, "Generation succeeded - %d warning(s)\n", vala_report_get_warnings ());
+		}
 		return 0;
 	} else {
-		fprintf (stdout, "Generation failed: %d error(s), %d warning(s)\n", vala_report_get_errors (), vala_report_get_warnings ());
+		if (!vala_vapi_gen_quiet_mode) {
+			fprintf (stdout, "Generation failed: %d error(s), %d warning(s)\n", vala_report_get_errors (), vala_report_get_warnings ());
+		}
 		return 1;
 	}
 }
 
 
-static char* vala_vapi_gen_get_package_path (ValaVAPIGen* self, const char* pkg) {
-	char* basename;
-	char* filename;
-	char* _tmp3;
-	gpointer _tmp5;
-	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), NULL);
-	basename = g_strdup_printf ("%s.vapi", pkg);
-	if (vala_vapi_gen_vapi_directories != NULL) {
-		{
-			char** vapidir_collection;
-			char** vapidir_it;
-			int vapidir_collection_length1;
-			vapidir_collection = vala_vapi_gen_vapi_directories;
-			vapidir_collection_length1 = -1;
-			for (vapidir_it = vapidir_collection; *vapidir_it != NULL; vapidir_it = vapidir_it + 1) {
-				const char* _tmp1;
-				char* vapidir;
-				_tmp1 = NULL;
-				vapidir = (_tmp1 = *vapidir_it, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
-				{
-					char* filename;
-					filename = g_build_filename (vapidir, basename, NULL, NULL);
-					if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-						char* _tmp0;
-						_tmp0 = NULL;
-						return (_tmp0 = filename, (vapidir = (g_free (vapidir), NULL)), (basename = (g_free (basename), NULL)), _tmp0);
-					}
-					(vapidir = (g_free (vapidir), NULL));
-					(filename = (g_free (filename), NULL));
-				}
-			}
-		}
-	}
-	filename = g_build_filename ("/usr/local/share/vala/vapi", basename, NULL, NULL);
-	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		char* _tmp2;
-		_tmp2 = NULL;
-		return (_tmp2 = filename, (basename = (g_free (basename), NULL)), _tmp2);
-	}
-	_tmp3 = NULL;
-	filename = (_tmp3 = g_build_filename ("/usr/share/vala/vapi", basename, NULL, NULL), (filename = (g_free (filename), NULL)), _tmp3);
-	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		char* _tmp4;
-		_tmp4 = NULL;
-		return (_tmp4 = filename, (basename = (g_free (basename), NULL)), _tmp4);
-	}
-	return (_tmp5 = NULL, (basename = (g_free (basename), NULL)), (filename = (g_free (filename), NULL)), _tmp5);
-}
-
-
 static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg) {
 	char* package_path;
 	ValaSourceFile* _tmp2;
@@ -152,11 +110,12 @@ static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg) {
 		return TRUE;
 	}
 	/* ignore multiple occurences of the same package*/
-	package_path = vala_vapi_gen_get_package_path (self, pkg);
+	package_path = vala_code_context_get_package_path (self->priv->context, pkg, -1, vala_vapi_gen_vapi_directories);
 	if (package_path == NULL) {
 		gboolean _tmp1;
 		return (_tmp1 = FALSE, (package_path = (g_free (package_path), NULL)), _tmp1);
 	}
+	vala_code_context_add_package (self->priv->context, pkg);
 	_tmp2 = NULL;
 	vala_code_context_add_source_file (self->priv->context, (_tmp2 = vala_source_file_new (self->priv->context, package_path, TRUE)));
 	(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
@@ -181,7 +140,7 @@ static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, in
 		_tmp3 = NULL;
 		return (_tmp3 = (_tmp2 = g_strsplit (g_strstrip (contents), "\n", 0), *result_length1 = -1, _tmp2), (contents = (g_free (contents), NULL)), _tmp3);
 	}
-	return (_tmp5 = (_tmp4 = NULL, *result_length1 = -1, _tmp4), (contents = (g_free (contents), NULL)), _tmp5);
+	return (_tmp5 = (_tmp4 = NULL, *result_length1 = 0, _tmp4), (contents = (g_free (contents), NULL)), _tmp5);
 }
 
 
@@ -222,16 +181,16 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 				char** deps;
 				/* load packages from .deps file */
 				if (!g_str_has_suffix (source, ".gi")) {
-					(source = (g_free (source), NULL));
+					source = (g_free (source), NULL);
 					continue;
 				}
 				_tmp2 = NULL;
 				_tmp1 = NULL;
 				_tmp3 = NULL;
-				depsfile = (_tmp3 = g_strconcat ((_tmp2 = g_utf8_offset_to_pointer (source, 0), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (source, -1) - g_utf8_strlen ("gi", -1)) - _tmp2)), "deps", NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp3);
+				depsfile = (_tmp3 = g_strconcat ((_tmp2 = g_utf8_offset_to_pointer (source, ((glong) 0)), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (source, -1) - g_utf8_strlen ("gi", -1)) - _tmp2)), "deps", NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp3);
 				if (!g_file_test (depsfile, G_FILE_TEST_EXISTS)) {
-					(source = (g_free (source), NULL));
-					(depsfile = (g_free (depsfile), NULL));
+					source = (g_free (source), NULL);
+					depsfile = (g_free (depsfile), NULL);
 					continue;
 				}
 				_tmp5 = NULL;
@@ -250,15 +209,15 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 								char* _tmp6;
 								_tmp6 = NULL;
 								vala_report_error (NULL, (_tmp6 = g_strdup_printf ("%s not found in specified Vala API directories", dep)));
-								(_tmp6 = (g_free (_tmp6), NULL));
+								_tmp6 = (g_free (_tmp6), NULL);
 							}
-							(dep = (g_free (dep), NULL));
+							dep = (g_free (dep), NULL);
 						}
 					}
 				}
-				(source = (g_free (source), NULL));
-				(depsfile = (g_free (depsfile), NULL));
-				(deps = (_vala_array_free (deps, deps_length1, ((GDestroyNotify) g_free)), NULL));
+				source = (g_free (source), NULL);
+				depsfile = (g_free (depsfile), NULL);
+				deps = (_vala_array_free (deps, deps_length1, ((GDestroyNotify) g_free)), NULL);
 			}
 		}
 	}
@@ -280,9 +239,9 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 						char* _tmp9;
 						_tmp9 = NULL;
 						vala_report_error (NULL, (_tmp9 = g_strdup_printf ("%s not found in specified Vala API directories", package)));
-						(_tmp9 = (g_free (_tmp9), NULL));
+						_tmp9 = (g_free (_tmp9), NULL);
 					}
-					(package = (g_free (package), NULL));
+					package = (g_free (package), NULL);
 				}
 			}
 		}
@@ -313,9 +272,9 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 					char* _tmp14;
 					_tmp14 = NULL;
 					vala_report_error (NULL, (_tmp14 = g_strdup_printf ("%s not found", source)));
-					(_tmp14 = (g_free (_tmp14), NULL));
+					_tmp14 = (g_free (_tmp14), NULL);
 				}
-				(source = (g_free (source), NULL));
+				source = (g_free (source), NULL);
 			}
 		}
 	}
@@ -355,7 +314,7 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 		interface_writer = vala_interface_writer_new ();
 		_tmp22 = NULL;
 		vala_interface_writer_write_file (interface_writer, self->priv->context, (_tmp22 = g_strdup_printf ("%s.vapi", vala_vapi_gen_library)));
-		(_tmp22 = (g_free (_tmp22), NULL));
+		_tmp22 = (g_free (_tmp22), NULL);
 		_tmp23 = NULL;
 		vala_vapi_gen_library = (_tmp23 = NULL, (vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL)), _tmp23);
 		(interface_writer == NULL ? NULL : (interface_writer = (g_object_unref (interface_writer), NULL)));
@@ -364,7 +323,7 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 }
 
 
-static gint vala_vapi_gen_main (int args_length1, char** args) {
+static gint vala_vapi_gen_main (char** args, int args_length1) {
 	GError * inner_error;
 	ValaVAPIGen* vapigen;
 	gint _tmp3;
@@ -413,7 +372,7 @@ static gint vala_vapi_gen_main (int args_length1, char** args) {
 
 int main (int argc, char ** argv) {
 	g_type_init ();
-	return vala_vapi_gen_main (argc, argv);
+	return vala_vapi_gen_main (argv, argc);
 }
 
 
